@@ -18,7 +18,10 @@ password =
 dbname =
 tables_prefix =
 port = 3306
-adapter = PDO_MYSQL
+adapter = PDO\MYSQL
+type = InnoDB
+schema = Mysql
+
 ; if charset is set to utf8, Piwik will ensure that it is storing its data using UTF8 charset.
 ; it will add a sql query SET at each page view.
 ; Piwik should work correctly without this setting.
@@ -31,11 +34,9 @@ password =
 dbname = piwik_tests
 tables_prefix = piwiktests_
 port = 3306
-adapter = PDO_MYSQL
-
-[superuser]
-login = 
-password =
+adapter = PDO\MYSQL
+type = InnoDB
+schema = Mysql
 
 [log]
 ; possible values for log: screen, database, file
@@ -46,7 +47,7 @@ log_writers[] = screen
 ; NONE, ERROR, WARN, INFO, DEBUG, VERBOSE
 log_level = WARN
 
-; if set to 1, only requests done in CLI mode (eg. the archive.php cron run) will be logged
+; if set to 1, only requests done in CLI mode (eg. the ./console core:archive cron run) will be logged
 ; NOTE: log_only_when_debug_parameter will also be checked for
 log_only_when_cli = 0
 
@@ -71,12 +72,13 @@ always_archive_data_range = 0;
 ; NOTE: you must also set [log] log_writers[] = "screen" to enable the profiler to print on screen
 enable_sql_profiler = 0
 
-; if set to 1, a Piwik tracking code will be included in the Piwik UI footer and will track visits, pages, etc. to idsite = 1
+; if set to > 0, a Piwik tracking code will be included in the Piwik UI footer and will track visits, pages, etc.
+; data will be stored for idSite = enable_measure_piwik_usage_in_idsite
 ; this is useful for Piwik developers as an easy way to create data in their local Piwik
-track_visits_inside_piwik_ui = 0
+enable_measure_piwik_usage_in_idsite = 0
 
-; if set to 1, javascript and css files will be included individually
-; this option must be set to 1 when adding, removing or modifying javascript and css files
+; if set to 1, javascript files will be included individually and neither merged nor minified.
+; this option must be set to 1 when adding, removing or modifying javascript files
 disable_merged_assets = 0
 
 ; If set to 1, all requests to piwik.php will be forced to be 'new visitors'
@@ -85,6 +87,11 @@ tracker_always_new_visitor = 0
 ; Allow automatic upgrades to Beta or RC releases
 allow_upgrades_to_beta = 0
 
+[DebugTests]
+; When set to 1, standalone plugins (those with their own git repositories)
+; will be loaded when executing tests.
+enable_load_standalone_plugins_during_tests = 0
+
 [General]
 ; the following settings control whether Unique Visitors will be processed for different period types.
 ; year and range periods are disabled by default, to ensure optimal performance for high traffic Piwik instances
@@ -96,6 +103,12 @@ enable_processing_unique_visitors_month = 1
 enable_processing_unique_visitors_year = 0
 enable_processing_unique_visitors_range = 0
 
+; The list of periods that are available in the Piwik calendar
+; Example use case: custom date range requests are processed in real time,
+; so they may take a few minutes on very high traffic website: you may remove "range" below to disable this period
+enabled_periods_UI = "day,week,month,year,range"
+enabled_periods_API = "day,week,month,year,range"
+
 ; when set to 1, all requests to Piwik will return a maintenance message without connecting to the DB
 ; this is useful when upgrading using the shell command, to prevent other users from accessing the UI while Upgrade is in progress
 maintenance_mode = 0
@@ -130,10 +143,27 @@ all_websites_website_per_page = 50
 anonymous_user_enable_use_segments_API = 1
 
 ; if browser trigger archiving is disabled, API requests with a &segment= parameter will still trigger archiving.
-; You can force the browser archiving to be disabled in most cases by setting this setting to 0
+; You can force the browser archiving to be disabled in most cases by setting this setting to 1
 ; The only time that the browser will still trigger archiving is when requesting a custom date range that is not pre-processed yet
 browser_archiving_disabled_enforce = 0
 
+; By default, users can create Segments which are to be processed in Real-time.
+; Setting this to 0 will force all newly created Custom Segments to be "Pre-processed (faster, requires archive.php cron)"
+; This can be useful if you want to prevent users from adding much load on the server.
+; Note: any existing Segment set to "processed in Real time", will still be set to Real-time.
+;       this will only affect custom segments added or modified after this setting is changed.
+enable_create_realtime_segments = 1
+
+; Whether to enable the "Suggest values for segment" in the Segment Editor panel.
+; Set this to 0 in case your Piwik database is very big, and suggested values may not appear in time
+enable_segment_suggested_values = 1
+
+; By default, any user with a "view" access for a website can create segment assigned to this website.
+; Set this to "admin" or "superuser" to require that users should have at least this access to create new segments.
+; Note: anonymous user (even if it has view access) is not allowed to create or edit segment.
+; Possible values are "view", "admin", "superuser"
+adding_segment_requires_access = "view"
+
 ; this action name is used when the URL ends with a slash /
 ; it is useful to have an actual string to write in the UI
 action_default_name = index
@@ -145,9 +175,20 @@ default_language = en
 ; default number of elements in the datatable
 datatable_default_limit = 10
 
+; Each datatable report has a Row Limit selector at the bottom right.
+; By default you can select from 5 to 500 rows. You may customise the values below:
+datatable_row_limits = "5,10,25,50,100,250,500"
+
 ; default number of rows returned in API responses
+; this value is overwritten by the '# Rows to display' selector.
+; if set to -1, a click on 'Export as' will export all rows independently of the current '# Rows to display'.
 API_datatable_default_limit = 100
 
+; When period=range, below the datatables, when user clicks on "export", the data will be aggregate of the range.
+; Here you can specify the comma separated list of formats for which the data will be exported aggregated by day
+; (ie. there will be a new "date" column). For example set to: "rss,tsv,csv"
+datatable_export_range_as_day = "rss"
+
 ; This setting is overriden in the UI, under "User Settings".
 ; The date and period loaded by Piwik uses the defaults below. Possible values: yesterday, today.
 default_day = yesterday
@@ -157,11 +198,12 @@ default_period = day
 ; Time in seconds after which an archive will be computed again. This setting is used only for today's statistics.
 ; Defaults to 10 seconds so that by default, Piwik provides real time reporting.
 ; This setting is overriden in the UI, under "General Settings".
-; This is the default value used if the setting hasn't been overriden via the UI.
+; This setting is only used if it hasn't been overriden via the UI yet, or if enable_general_settings_admin=0
 time_before_today_archive_considered_outdated = 10
 
-; This setting is overriden in the UI, under "General Settings". The default value is to allow browsers
-; to trigger the Piwik archiving process.
+; This setting is overriden in the UI, under "General Settings".
+; The default value is to allow browsers to trigger the Piwik archiving process.
+; This setting is only used if it hasn't been overriden via the UI yet, or if enable_general_settings_admin=0
 enable_browser_archiving_triggering = 1
 
 ; By default Piwik runs OPTIMIZE TABLE SQL queries to free spaces after deleting some data.
@@ -179,7 +221,7 @@ minimum_pgsql_version = 8.3
 ; Minimum adviced memory limit in php.ini file (see memory_limit value)
 minimum_memory_limit = 128
 
-; Minimum memory limit enforced when archived via misc/cron/archive.php
+; Minimum memory limit enforced when archived via ./console core:archive
 minimum_memory_limit_when_archiving = 768
 
 ; Piwik will check that usernames and password have a minimum length, and will check that characters are "allowed"
@@ -194,11 +236,6 @@ hash_algorithm = whirlpool
 ; For clusters, use dbtable.
 session_save_handler = files
 
-; by default, Piwik uses relative URLs, so you can login using http:// or https://
-; (the latter assumes you have a valid SSL certificate).
-; If set to 1, Piwik redirects the login form to use a secure connection (i.e., https).
-force_ssl_login = 0
-
 ; If set to 1, Piwik will automatically redirect all http:// requests to https://
 ; If SSL / https is not correctly configured on the server, this will break Piwik
 ; If you set this to 1, and your SSL configuration breaks later on, you can always edit this back to 0 
@@ -221,6 +258,12 @@ login_password_recovery_email_address = "password-recovery@{DOMAIN}"
 ; name that appears as a Sender in the password recovery email
 login_password_recovery_email_name = Piwik
 
+; email address that appears as a Repy-to in the password recovery email
+; if specified, {DOMAIN} will be replaced by the current Piwik domain
+login_password_recovery_replyto_email_address = "no-reply@{DOMAIN}"
+; name that appears as a Reply-to in the password recovery email
+login_password_recovery_replyto_email_name = "No-reply"
+
 ; By default when user logs out he is redirected to Piwik "homepage" usually the Login form.
 ; Uncomment the next line to set a URL to redirect the user to after he logs out of Piwik.
 ; login_logout_url = http://...
@@ -241,7 +284,10 @@ noreply_email_address = "noreply@{DOMAIN}"
 
 ; feedback email address;
 ; when testing, use your own email address or "nobody"
-feedback_email_address = "hello@piwik.org"
+feedback_email_address = "feedback@piwik.org"
+
+; using to set reply_to in reports e-mail to login of report creator
+scheduled_reports_replyto_is_user_email_and_alias = 0
 
 ; during archiving, Piwik will limit the number of results recorded, for performance reasons
 ; maximum number of rows for any of the Referrers tables (keywords, search engines, campaigns, etc.)
@@ -250,7 +296,7 @@ datatable_archiving_maximum_rows_referrers = 1000
 datatable_archiving_maximum_rows_subtable_referrers = 50
 
 ; maximum number of rows for the Custom Variables names report
-; also used to process Ecommerce conversion rates (should be large enough to hold all unique Ecommerce items)
+; Note: if the website is Ecommerce enabled, the two values below will be automatically set to 50000
 datatable_archiving_maximum_rows_custom_variables = 1000
 ; maximum number of rows for the Custom Variables values reports
 datatable_archiving_maximum_rows_subtable_custom_variables = 1000
@@ -262,6 +308,11 @@ datatable_archiving_maximum_rows_actions = 500
 ; because each subdirectory doesn't have paging at the bottom, so all data should be displayed if possible.
 datatable_archiving_maximum_rows_subtable_actions = 100
 
+; maximum number of rows for any of the Events tables (Categories, Actions, Names)
+datatable_archiving_maximum_rows_events = 500
+; maximum number of rows for sub-tables of the Events tables (eg. for the subtables Categories>Actions or Categories>Names).
+datatable_archiving_maximum_rows_subtable_events = 100
+
 ; maximum number of rows for other tables (Providers, User settings configurations)
 datatable_archiving_maximum_rows_standard = 500
 
@@ -326,9 +377,14 @@ enable_trusted_host_check = 1
 ;trusted_hosts[] = example.com
 ;trusted_hosts[] = stats.example.com
 
+; If you use this Piwik instance over multiple hostnames, Piwik will need to know
+; a unique instance_id for this instance, so that Piwik can serve the right custom logo and tmp/* assets,
+; independantly of the hostname Piwik is currently running under.
+; instance_id = stats.example.com
+
 ; The release server is an essential part of the Piwik infrastructure/ecosystem
 ; to provide the latest software version.
-latest_version_url = http://builds.piwik.org/latest.zip
+latest_version_url = http://builds.piwik.org/piwik.zip
 
 ; The API server is an essential part of the Piwik infrastructure/ecosystem to
 ; provide services to Piwik installations, e.g., getLatestVersion and
@@ -348,6 +404,9 @@ overlay_following_pages_limit = 300
 ; With this option, you can disable the framed mode of the Overlay plugin. Use it if your website contains a framebuster.
 overlay_disable_framed_mode = 0
 
+; By default we check whether the Custom logo is writable or not, before we display the Custom logo file uploader
+enable_custom_logo_check = 1
+
 ; If php is running in a chroot environment, when trying to import CSV files with createTableFromCSVFile(),
 ; Mysql will try to load the chrooted path (which is imcomplete). To prevent an error, here you can specify the
 ; absolute path to the chroot environment. eg. '/path/to/piwik/chrooted/'
@@ -375,12 +434,18 @@ enable_geolocation_admin = 1
 enable_delete_old_data_settings_admin = 1
 
 ; By setting this option to 0, the following settings will be hidden and disabled from being set in the UI:
-; - "General Settings"
+; - "Archiving Settings"
+; - "Update settings"
 ; - "Email server settings"
 enable_general_settings_admin = 1
 
 ; By setting this option to 0, it will disable the "Auto update" feature
-enable_auto_update = 1
+enable_auto_update = 0
+
+; By setting this option to 0, no emails will be sent in case of an available core.
+; If set to 0 it also disables the "sent plugin update emails" feature in general and the related setting in the UI.
+enable_update_communication = 0
+
 
 [Tracker]
 ; Piwik uses first party cookies by default. If set to 1,
@@ -388,6 +453,10 @@ enable_auto_update = 1
 ; this is useful when you want to do cross websites analysis
 use_third_party_id_cookie = 0
 
+; If tracking does not work for you or you are stuck finding an issue, you might want to enable the tracker debug mode.
+; Once enabled (set to 1) messages will be logged to all loggers defined in "[log] log_writers" config.
+debug = 0
+
 ; There is a feature in the Tracking API that lets you create new visit at any given time, for example if you know that a different user/customer is using
 ; the app then you would want to tell Piwik to create a new visit (even though both users are using the same browser/computer).
 ; To prevent abuse and easy creation of fake visits, this feature requires admin token_auth by default
@@ -433,7 +502,7 @@ default_time_one_page_visit = 0
 ; The mapping is defined in core/DataFiles/LanguageToCountry.php,
 enable_language_to_country_guess = 1
 
-; When the misc/cron/archive.php cron hasn't been setup, we still need to regularly run some maintenance tasks.
+; When the `./console core:archive` cron hasn't been setup, we still need to regularly run some maintenance tasks.
 ; Visits to the Tracker will try to trigger Scheduled Tasks (eg. scheduled PDF/HTML reports by email).
 ; Scheduled tasks will only run if 'Enable Piwik Archiving from Browser' is enabled in the General Settings.
 ; Tasks run once every hour maximum, they might not run every hour if traffic is low.
@@ -457,22 +526,22 @@ campaign_keyword_var_name = "pk_kwd,piwik_kwd,pk_keyword,utm_term"
 ; maximum length of a Page Title or a Page URL recorded in the log_action.name table
 page_maximum_length = 1024;
 
-; Anonymize a visitor's IP address after testing for "Ip exclude"
-; This value is the level of anonymization Piwik will use; if the IP anonymization is deactivated, this value is ignored.
-; For IPv4/IPv6 addresses, valid values are the number of octets in IP address to mask (from 0 to 4).
-; For IPv6 addresses 0..4 means that 0, 64, 80, 104 or all bits are masked.
-ip_address_mask_length = 1
-
-
-; Set this setting to 0 to let plugins use the full non-anonymized IP address when enriching visitor information.
-; When set to 1, by default, Geo Location via geoip and Provider reverse name lookups
-; will use the anonymized IP address when anonymization is enabled.
-use_anonymized_ip_for_visit_enrichment = 1
-
 ; Tracker cache files are the simple caching layer for Tracking.
 ; TTL: Time to live for cache files, in seconds. Default to 5 minutes.
 tracker_cache_file_ttl = 300
 
+; Whether Bulk tracking requests to the Tracking API requires the token_auth to be set.
+bulk_requests_require_authentication = 0
+
+; Whether Bulk tracking requests will be wrapped within a DB Transaction.
+; This greatly increases performance of Log Analytics and in general any Bulk Tracking API requests.
+bulk_requests_use_transaction = 1
+
+; Comma separated list of known Referrer Spammers, ie. bot visits that set a fake Referrer field.
+; All Visits with a Referrer URL host set to one of these will be excluded.
+; If you find new spam entries in Referrers>Websites, please report them here: https://github.com/piwik/piwik/issues/5099
+referrer_urls_spam = "semalt.com"
+
 ; DO NOT USE THIS SETTING ON PUBLICLY AVAILABLE PIWIK SERVER
 ; !!! Security risk: if set to 0, it would allow anyone to push data to Piwik with custom dates in the past/future and even with fake IPs!
 ; When using the Tracking API, to override either the datetime and/or the visitor IP, 
@@ -480,6 +549,7 @@ tracker_cache_file_ttl = 300
 ; DO NOT USE THIS SETTING ON PUBLIC PIWIK SERVERS
 tracking_requests_require_authentication = 1
 
+
 [Segments]
 ; Reports with segmentation in API requests are processed in real time.
 ; On high traffic websites it is recommended to pre-process the data
@@ -501,12 +571,19 @@ tracking_requests_require_authentication = 1
 delete_logs_enable = 0
 delete_logs_schedule_lowest_interval = 7
 delete_logs_older_than = 180
+delete_logs_max_rows_per_query = 100000
 enable_auto_database_size_estimate = 1
 
-[branding]
-; custom logo
-; if 1, custom logo is being displayed instead of piwik logo
-use_custom_logo = 0
+[Deletereports]
+delete_reports_enable                = 0
+delete_reports_older_than            = 12
+delete_reports_keep_basic_metrics    = 1
+delete_reports_keep_day_reports      = 0
+delete_reports_keep_week_reports     = 0
+delete_reports_keep_month_reports    = 1
+delete_reports_keep_year_reports     = 1
+delete_reports_keep_range_reports    = 0
+delete_reports_keep_segment_reports  = 0
 
 [mail]
 defaultHostnameIfEmpty = defaultHostnameIfEmpty.example.org ; default Email @hostname, if current host can't be read from system variables
@@ -541,6 +618,7 @@ Plugins[] = Dashboard
 Plugins[] = MultiSites
 Plugins[] = Referrers
 Plugins[] = UserSettings
+Plugins[] = DevicesDetection
 Plugins[] = Goals
 Plugins[] = SEO
 Plugins[] = Events
@@ -570,7 +648,9 @@ Plugins[] = Annotations
 Plugins[] = MobileMessaging
 Plugins[] = Overlay
 Plugins[] = SegmentEditor
-
+Plugins[] = Insights
+Plugins[] = ZenMode
+Plugins[] = LeftMenu
 Plugins[] = Morpheus
 
 [PluginsInstalled]
@@ -585,6 +665,7 @@ Plugins_Tracker[] = Provider
 Plugins_Tracker[] = Goals
 Plugins_Tracker[] = PrivacyManager
 Plugins_Tracker[] = UserCountry
+Plugins_Tracker[] = Login
 
 [APISettings]
 ; Any key/value pair can be added in this section, they will be available via the REST call
