@@ -1,27 +1,26 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik\API;
 
 use Exception;
 use Piwik\Common;
-use Piwik\DataTable;
 use Piwik\DataTable\Filter\AddColumnsProcessedMetricsGoal;
+use Piwik\DataTable;
 
-/**
- * @package Piwik
- * @subpackage Piwik_API
- */
 class DataTableGenericFilter
 {
-    private static $genericFiltersInfo = null;
+    /**
+     * List of filter names not to run.
+     *
+     * @var string[]
+     */
+    private $disabledFilters = array();
 
     /**
      * Constructor
@@ -43,6 +42,16 @@ class DataTableGenericFilter
         $this->applyGenericFilters($table);
     }
 
+    /**
+     * Makes sure a set of filters are not run.
+     *
+     * @param string[] $filterNames The name of each filter to disable.
+     */
+    public function disableFilters($filterNames)
+    {
+        $this->disabledFilters = array_unique(array_merge($this->disabledFilters, $filterNames));
+    }
+
     /**
      * Returns an array containing the information of the generic Filter
      * to be applied automatically to the data resulting from the API calls.
@@ -57,43 +66,47 @@ class DataTableGenericFilter
      */
     public static function getGenericFiltersInformation()
     {
-        if (is_null(self::$genericFiltersInfo)) {
-            self::$genericFiltersInfo = array(
-                'Pattern'                        => array(
-                    'filter_column'  => array('string', 'label'),
-                    'filter_pattern' => array('string'),
-                ),
-                'PatternRecursive'               => array(
-                    'filter_column_recursive'  => array('string', 'label'),
-                    'filter_pattern_recursive' => array('string'),
-                ),
-                'ExcludeLowPopulation'           => array(
-                    'filter_excludelowpop'       => array('string'),
-                    'filter_excludelowpop_value' => array('float', '0'),
-                ),
-                'AddColumnsProcessedMetrics'     => array(
-                    'filter_add_columns_when_show_all_columns' => array('integer')
-                ),
-                'AddColumnsProcessedMetricsGoal' => array(
-                    'filter_update_columns_when_show_all_goals' => array('integer'),
-                    'idGoal'                                    => array('string', AddColumnsProcessedMetricsGoal::GOALS_OVERVIEW),
-                ),
-                'Sort'                           => array(
-                    'filter_sort_column' => array('string'),
-                    'filter_sort_order'  => array('string', 'desc'),
-                ),
-                'Truncate'                       => array(
-                    'filter_truncate' => array('integer'),
-                ),
-                'Limit'                          => array(
-                    'filter_offset'    => array('integer', '0'),
-                    'filter_limit'     => array('integer'),
-                    'keep_summary_row' => array('integer', '0'),
-                ),
-            );
-        }
-
-        return self::$genericFiltersInfo;
+        return array(
+            array('Pattern',
+                  array(
+                      'filter_column'  => array('string', 'label'),
+                      'filter_pattern' => array('string')
+                  )),
+            array('PatternRecursive',
+                  array(
+                      'filter_column_recursive'  => array('string', 'label'),
+                      'filter_pattern_recursive' => array('string'),
+                  )),
+            array('ExcludeLowPopulation',
+                  array(
+                      'filter_excludelowpop'       => array('string'),
+                      'filter_excludelowpop_value' => array('float', '0'),
+                  )),
+            array('AddColumnsProcessedMetrics',
+                  array(
+                      'filter_add_columns_when_show_all_columns' => array('integer')
+                  )),
+            array('AddColumnsProcessedMetricsGoal',
+                  array(
+                      'filter_update_columns_when_show_all_goals' => array('integer'),
+                      'idGoal'                                    => array('string', AddColumnsProcessedMetricsGoal::GOALS_OVERVIEW),
+                  )),
+            array('Sort',
+                  array(
+                      'filter_sort_column' => array('string'),
+                      'filter_sort_order'  => array('string', 'desc'),
+                  )),
+            array('Truncate',
+                  array(
+                      'filter_truncate' => array('integer'),
+                  )),
+            array('Limit',
+                  array(
+                      'filter_offset'    => array('integer', '0'),
+                      'filter_limit'     => array('integer'),
+                      'keep_summary_row' => array('integer', '0'),
+                  )),
+        );
     }
 
     /**
@@ -116,10 +129,17 @@ class DataTableGenericFilter
         $genericFilters = self::getGenericFiltersInformation();
 
         $filterApplied = false;
-        foreach ($genericFilters as $filterName => $parameters) {
+        foreach ($genericFilters as $filterMeta) {
+            $filterName = $filterMeta[0];
+            $filterParams = $filterMeta[1];
             $filterParameters = array();
             $exceptionRaised = false;
-            foreach ($parameters as $name => $info) {
+
+            if (in_array($filterName, $this->disabledFilters)) {
+                continue;
+            }
+
+            foreach ($filterParams as $name => $info) {
                 // parameter type to cast to
                 $type = $info[0];
 
