@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik\API;
 
@@ -21,13 +19,9 @@ use Piwik\DataTable\Simple;
 use Piwik\DataTable;
 
 /**
- * @package Piwik
- * @subpackage Piwik_API
  */
 class ResponseBuilder
 {
-    const DISPLAY_BACKTRACE_DEBUG = false;
-
     private $request = null;
     private $outputFormat = null;
 
@@ -76,6 +70,50 @@ class ResponseBuilder
         $this->apiModule = $apiModule;
         $this->apiMethod = $apiMethod;
 
+        if($this->outputFormat == 'original') {
+            @header('Content-Type: text/plain; charset=utf-8');
+        }
+        return $this->renderValue($value);
+    }
+
+    /**
+     * Returns an error $message in the requested $format
+     *
+     * @param Exception $e
+     * @throws Exception
+     * @return string
+     */
+    public function getResponseException(Exception $e)
+    {
+        $format = strtolower($this->outputFormat);
+
+        if ($format == 'original') {
+            throw $e;
+        }
+
+        try {
+            $renderer = Renderer::factory($format);
+        } catch (Exception $exceptionRenderer) {
+            return "Error: " . $e->getMessage() . " and: " . $exceptionRenderer->getMessage();
+        }
+
+        $e = $this->decorateExceptionWithDebugTrace($e);
+
+        $renderer->setException($e);
+
+        if ($format == 'php') {
+            $renderer->setSerialize($this->caseRendererPHPSerialize());
+        }
+
+        return $renderer->renderException();
+    }
+
+    /**
+     * @param $value
+     * @return string
+     */
+    protected function renderValue($value)
+    {
         // when null or void is returned from the api call, we handle it as a successful operation
         if (!isset($value)) {
             return $this->handleSuccess();
@@ -114,38 +152,6 @@ class ResponseBuilder
         return $this->handleScalar($value);
     }
 
-    /**
-     * Returns an error $message in the requested $format
-     *
-     * @param Exception $e
-     * @throws Exception
-     * @return string
-     */
-    public function getResponseException(Exception $e)
-    {
-        $format = strtolower($this->outputFormat);
-
-        if ($format == 'original') {
-            throw $e;
-        }
-
-        try {
-            $renderer = Renderer::factory($format);
-        } catch (Exception $exceptionRenderer) {
-            return "Error: " . $e->getMessage() . " and: " . $exceptionRenderer->getMessage();
-        }
-
-        $e = $this->decorateExceptionWithDebugTrace($e);
-
-        $renderer->setException($e);
-
-        if ($format == 'php') {
-            $renderer->setSerialize($this->caseRendererPHPSerialize());
-        }
-
-        return $renderer->renderException();
-    }
-
     /**
      * @param Exception $e
      * @return Exception
@@ -154,12 +160,10 @@ class ResponseBuilder
     {
         // If we are in tests, show full backtrace
         if (defined('PIWIK_PATH_TEST_TO_ROOT')) {
-            if (self::DISPLAY_BACKTRACE_DEBUG
-                || \Piwik_ShouldPrintBackTraceWithMessage()
-            ) {
+            if (\Piwik_ShouldPrintBackTraceWithMessage()) {
                 $message = $e->getMessage() . " in \n " . $e->getFile() . ":" . $e->getLine() . " \n " . $e->getTraceAsString();
             } else {
-                $message = $e->getMessage() . "\n \n --> To temporarily debug this error further, set const DISPLAY_BACKTRACE_DEBUG=true; in " . basename(__FILE__);
+                $message = $e->getMessage() . "\n \n --> To temporarily debug this error further, set const PIWIK_PRINT_ERROR_BACKTRACE=true; in index.php";
             }
             return new Exception($message);
         }
@@ -291,6 +295,9 @@ class ResponseBuilder
      */
     protected function handleDataTable($datatable)
     {
+        // process request
+        $label = $this->getLabelFromRequest($this->request);
+
         // if requested, flatten nested tables
         if (Common::getRequestVar('flat', '0', 'string', $this->request) == '1') {
             $flattener = new Flattener($this->apiModule, $this->apiMethod, $this->request);
@@ -308,6 +315,10 @@ class ResponseBuilder
         // if the flag disable_generic_filters is defined we skip the generic filters
         if (0 == Common::getRequestVar('disable_generic_filters', '0', 'string', $this->request)) {
             $genericFilter = new DataTableGenericFilter($this->request);
+            if (!empty($label)) {
+                $genericFilter->disableFilters(array('Limit', 'Truncate'));
+            }
+
             $genericFilter->filter($datatable);
         }
 
@@ -328,7 +339,6 @@ class ResponseBuilder
         }
 
         // apply label filter: only return rows matching the label parameter (more than one if more than one label)
-        $label = $this->getLabelFromRequest($this->request);
         if (!empty($label)) {
             $addLabelIndex = Common::getRequestVar('labelFilterAddLabelIndex', 0, 'int', $this->request) == 1;
 
