@@ -1,21 +1,16 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik\DataAccess;
 
-use PDOStatement;
 use Piwik\ArchiveProcessor\Parameters;
-use Piwik\Common;
 use Piwik\DataArray;
 use Piwik\Db;
-
 use Piwik\Metrics;
 use Piwik\Tracker\GoalManager;
 
@@ -91,8 +86,8 @@ use Piwik\Tracker\GoalManager;
  *         $country = $row['location_country'];
  *         $numEcommerceSales = $row[Metrics::INDEX_GOAL_NB_CONVERSIONS];
  *         $numVisitsWithEcommerceSales = $row[Metrics::INDEX_GOAL_NB_VISITS_CONVERTED];
- *         $avgTaxForCountry = $country['avg_tax'];
- *         $maxShippingForCountry = $country['max_shipping'];
+ *         $avgTaxForCountry = $row['avg_tax'];
+ *         $maxShippingForCountry = $row['max_shipping'];
  *
  *         // ... do something with aggregated data ...
  *     }
@@ -502,6 +497,7 @@ class LogAggregator
                 ', ',
                 array(
                     "log_action.name AS label",
+                    sprintf("log_conversion_item.%s AS labelIdAction", $dimension),
                     sprintf(
                         '%s AS `%d`',
                         self::getSqlRevenue('SUM(log_conversion_item.quantity * log_conversion_item.price)'),
@@ -878,4 +874,4 @@ class LogAggregator
     {
         return Db::get();
     }
-}
\ No newline at end of file
+}
