@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package DataFiles
  */
 
 /**
@@ -88,6 +86,9 @@ if (!isset($GLOBALS['Piwik_SearchEngines'])) {
         // Acoon
         'www.acoon.de'                   => array('Acoon', 'begriff', 'cgi-bin/search.exe?begriff={k}'),
 
+        // Aguea
+        'chercherfr.aguea.com'           => array('Aguea', 'q', 's.py?q={k}'),
+
         // Alexa
         'alexa.com'                      => array('Alexa', 'q', 'search?q={k}'),
         'search.toolbars.alexa.com'      => array('Alexa'),
@@ -185,15 +186,19 @@ if (!isset($GLOBALS['Piwik_SearchEngines'])) {
         '{}.search.ask.com'              => array('Ask'),
         'avira-int.ask.com'              => array('Ask'),
         'searchqu.com'                   => array('Ask'),
+        'search.tb.ask.com'              => array('Ask'),
 
         // Atlas
         'searchatlas.centrum.cz'         => array('Atlas', 'q', '?q={k}'),
 
+        // auone
+        'search.auone.jp'                => array('auone', 'q', '?q={k}'),
+
         // Austronaut
         'www2.austronaut.at'             => array('Austronaut', 'q'),
         'www1.austronaut.at'             => array('Austronaut'),
 
-        // Babylon (Enhanced by Google)
+        // Babylon (Enhanced by Google),
         'search.babylon.com'             => array('Babylon', array('q', '/\/web\/(.*)/'), '?q={k}'),
         'searchassist.babylon.com'       => array('Babylon'),
 
@@ -207,6 +212,7 @@ if (!isset($GLOBALS['Piwik_SearchEngines'])) {
 
         // Biglobe
         'cgi.search.biglobe.ne.jp'       => array('Biglobe', 'q', 'cgi-bin/search-st?q={k}'),
+        'images.search.biglobe.ne.jp'    => array('Biglobe Images', 'q', 'cgi-bin/search-st?q={k}'),
 
         // Bing
         'bing.com'                       => array('Bing', array('q', 'Q'), 'search?q={k}'),
@@ -297,6 +303,7 @@ if (!isset($GLOBALS['Piwik_SearchEngines'])) {
 
         // DuckDuckGo
         'duckduckgo.com'                 => array('DuckDuckGo', 'q', '?q={k}'),
+        'r.duckduckgo.com'               => array('DuckDuckGo'),
 
         // earthlink
         'search.earthlink.net'           => array('Earthlink', 'q', 'search?q={k}'),
@@ -442,6 +449,7 @@ if (!isset($GLOBALS['Piwik_SearchEngines'])) {
         '{}.wow.com'                     => array('Google'),
         'search.leonardo.it'             => array('Google'),
         'www.optuszoo.com.au'            => array('Google'),
+        'search.dolphin-browser.jp'      => array('Google'),
         'search.smt.docomo.ne.jp'        => array('Google', 'MT'),
         'image.search.smt.docomo.ne.jp'     => array('Google', 'MT'),
 
@@ -619,6 +627,9 @@ if (!isset($GLOBALS['Piwik_SearchEngines'])) {
         'www.toile.com'                  => array('La Toile Du Québec (Google)', 'q', 'search?q={k}'),
         'web.toile.com'                  => array('La Toile Du Québec (Google)'),
 
+        // LookAny
+        'www.lookany.com'                => array('LookAny', '/(?:search|images|videos)\/([^\/]+)/'),
+
         // Looksmart
         'www.looksmart.com'              => array('Looksmart', 'key'),
 
@@ -701,7 +712,8 @@ if (!isset($GLOBALS['Piwik_SearchEngines'])) {
         'www.neti.ee'                    => array('Neti', 'query', 'cgi-bin/otsing?query={k}', 'iso-8859-1'),
 
         // Nifty
-        'search.nifty.com'               => array('Nifty', 'q', 'websearch/search?q={k}'),
+        'search.nifty.com'               => array('Nifty', array('q', 'Text'), 'websearch/search?q={k}'),
+        'videosearch.nifty.com'          => array('Nifty Videos', 'kw', 'search?kw={k}'),
 
         // Nigma
         'nigma.ru'                       => array('Nigma', 's', 'index.php?s={k}'),
@@ -805,6 +817,13 @@ if (!isset($GLOBALS['Piwik_SearchEngines'])) {
         // Snap.do
         'search.snap.do'                 => array('Snap.do', 'q', '?q={k}'),
 
+        // SeeSaa
+        'search.seesaa.jp'               => array('SeeSaa', '/\/([^\/]+)\/index\.html/', '{k}/index.html'),
+
+        // So-net
+        'www.so-net.ne.jp'               => array('So-net', 'query', 'search/web/?query={k}'),
+        'video.so-net.ne.jp'             => array('So-net Videos', 'kw', 'search/?kw={k}'),
+
         // Sogou
         'www.sogou.com'                  => array('Sogou', 'query', 'web?query={k}', 'gb2312'),
 
@@ -939,12 +958,22 @@ if (!isset($GLOBALS['Piwik_SearchEngines'])) {
         // Wirtualna Polska
         'szukaj.wp.pl'                   => array('Wirtualna Polska', 'szukaj', 'http://szukaj.wp.pl/szukaj.html?szukaj={k}'),
 
+        // Woopie
+        'www.woopie.jp'                  => array('Woopie', 'kw', 'search?kw={k}'),
+
         // WWW
         'search.www.ee'                  => array('www värav', 'query'),
 
         // X-recherche
         'www.x-recherche.com'            => array('X-Recherche', 'MOTS', 'cgi-bin/websearch?MOTS={k}'),
 
+        // Yahoo! Japan
+        'search.yahoo.co.jp'             => array('Yahoo! Japan', 'p', 'search?p={k}'),
+        'jp.hao123.com'                  => array('Yahoo! Japan', 'query'),
+        'video.search.yahoo.co.jp'       => array('Yahoo! Japan Videos', 'p', 'search?p={k}'),
+        'image.search.yahoo.co.jp'       => array('Yahoo! Japan Images', 'p', 'search?p={k}'),
+
+
         // Yahoo
         'search.yahoo.com'               => array('Yahoo!', array('p', 'q'), 'search?p={k}'),
 //		'*.search.yahoo.com'		=> array('Yahoo!'), // see built-in helper in Common.php
@@ -955,8 +984,6 @@ if (!isset($GLOBALS['Piwik_SearchEngines'])) {
         'espanol.yahoo.com'              => array('Yahoo!'),
         'qc.yahoo.com'                   => array('Yahoo!'),
         'one.cn.yahoo.com'               => array('Yahoo!'),
-        'video.search.yahoo.co.jp'       => array('Yahoo!'),
-        'image.search.yahoo.co.jp'       => array('Yahoo!'),
 
         // Powered by Yahoo APIs
         'www.cercato.it'                 => array('Yahoo!', 'q'),
@@ -1032,11 +1059,4 @@ if (!isset($GLOBALS['Piwik_SearchEngines'])) {
         // Zoznam
         'www.zoznam.sk'                  => array('Zoznam', 's', 'hladaj.fcgi?s={k}&co=svet'),
     );
-
-    $GLOBALS['Piwik_SearchEngines_NameToUrl'] = array();
-    foreach ($GLOBALS['Piwik_SearchEngines'] as $url => $info) {
-        if (!isset($GLOBALS['Piwik_SearchEngines_NameToUrl'][$info[0]])) {
-            $GLOBALS['Piwik_SearchEngines_NameToUrl'][$info[0]] = $url;
-        }
-    }
 }
