@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package DataFiles
  */
 
 if (!isset($GLOBALS['Piwik_socialUrl'])) {
@@ -105,7 +103,7 @@ if (!isset($GLOBALS['Piwik_socialUrl'])) {
         'lastfm.pl'            => 'Last.fm',
         'lastfm.com.br'        => 'Last.fm',
         'lastfm.se'            => 'Last.fm',
-        'lastfm.com.tr'            => 'Last.fm',
+        'lastfm.com.tr'        => 'Last.fm',
 
         // MyHeritage
         'myheritage.com'       => 'MyHeritage',
@@ -200,7 +198,7 @@ if (!isset($GLOBALS['Piwik_socialUrl'])) {
         'my.mail.ru'           => 'my.mail.ru',
 
         //MoiKrug.ru
-        'moikrug.ru'           => 'my.mail.ru',
+        'moikrug.ru'           => 'moikrug.ru',
 
         // Reddit
         'reddit.com'           => 'reddit',
@@ -216,8 +214,8 @@ if (!isset($GLOBALS['Piwik_socialUrl'])) {
         't.cn'                 => 'Weibo',
 
         // YouTube
-        'youtu.be'             => 'YouTube',
         'youtube.com'          => 'YouTube',
+        'youtu.be'             => 'YouTube',
 
         // Vimeo
         'vimeo.com'            => 'Vimeo',
