@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik\DataTable\Renderer;
 
@@ -16,9 +14,6 @@ use Piwik\DataTable\Renderer;
 
 /**
  * Simple output
- *
- * @package Piwik
- * @subpackage Piwik_DataTable_Renderer_ConsoleDataTable
  */
 class Console extends Renderer
 {
@@ -157,11 +152,13 @@ class Console extends Renderer
         $metadata = $table->getAllTableMetadata();
         if (!empty($metadata)) {
             $output .= "<hr />Metadata<br />";
-            foreach ($metadata as $id => $metadata) {
+            foreach ($metadata as $id => $metadataIn) {
                 $output .= "<br />";
                 $output .= $prefix . " <b>$id</b><br />";
-                foreach ($metadata as $name => $value) {
-                    $output .= $prefix . $prefix . "$name => $value";
+                if(is_array($metadataIn)) {
+                    foreach ($metadataIn as $name => $value) {
+                        $output .= $prefix . $prefix . "$name => $value";
+                    }
                 }
             }
         }
