@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik\DataTable\Renderer;
 
@@ -19,8 +17,6 @@ use Piwik\ProxyHttp;
  * JSON export.
  * Works with recursive DataTable (when a row can be associated with a subDataTable).
  *
- * @package Piwik
- * @subpackage DataTable
  */
 class Json extends Renderer
 {
@@ -108,7 +104,7 @@ class Json extends Renderer
         if (($jsonCallback = Common::getRequestVar('callback', false)) === false)
             $jsonCallback = Common::getRequestVar('jsoncallback', false);
         if ($jsonCallback !== false) {
-            if (preg_match('/^[0-9a-zA-Z_]*$/D', $jsonCallback) > 0) {
+            if (preg_match('/^[0-9a-zA-Z_.]*$/D', $jsonCallback) > 0) {
                 $str = $jsonCallback . "(" . $str . ")";
             }
         }
