@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik\Db;
 
@@ -15,8 +13,6 @@ use Piwik\Loader;
 use Zend_Db_Table;
 
 /**
- * @package Piwik
- * @subpackage Piwik_Db
  */
 class Adapter
 {
@@ -46,15 +42,7 @@ class Adapter
         $className = self::getAdapterClassName($adapterName);
         Loader::loadClass($className);
 
-        /*
-         * 5.2.1 fixes various bugs with references that caused PDO_MYSQL getConnection()
-         * to clobber $dbInfos. (#33282, #35106, #39944)
-         */
-        if (version_compare(PHP_VERSION, '5.2.1') < 0) {
-            $adapter = new $className(array_map('trim', $dbInfos));
-        } else {
-            $adapter = new $className($dbInfos);
-        }
+        $adapter = new $className($dbInfos);
 
         if ($connect) {
             $adapter->getConnection();
