@@ -1,22 +1,20 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik;
 
+use Piwik\Plugins\CoreAdminHome\CustomLogo;
 use Zend_Mail;
 
 /**
  * Class for sending mails, for more information see:
  * {@link http://framework.zend.com/manual/en/zend.mail.html}
  *
- * @package Piwik
  * @see Zend_Mail, libs/Zend/Mail.php
  * @api
  */
@@ -33,6 +31,16 @@ class Mail extends Zend_Mail
         $this->initSmtpTransport();
     }
 
+    public function setDefaultFromPiwik()
+    {
+        $customLogo = new CustomLogo();
+        $fromEmailName = $customLogo->isEnabled()
+            ? Piwik::translate('CoreHome_WebAnalyticsReports')
+            : Piwik::translate('ScheduledReports_PiwikReports');
+        $fromEmailAddress = Config::getInstance()->General['noreply_email_address'];
+        $this->setFrom($fromEmailAddress, $fromEmailName);
+    }
+
     /**
      * Sets the sender.
      *
@@ -42,20 +50,25 @@ class Mail extends Zend_Mail
      */
     public function setFrom($email, $name = null)
     {
-        $hostname = Config::getInstance()->mail['defaultHostnameIfEmpty'];
-        $piwikHost = Url::getCurrentHost($hostname);
+        return parent::setFrom(
+            $this->parseDomainPlaceholderAsPiwikHostName($email),
+            $name
+        );
+    }
 
-        // If known Piwik URL, use it instead of "localhost"
-        $piwikUrl = SettingsPiwik::getPiwikUrl();
-        $url = parse_url($piwikUrl);
-        if (isset($url['host'])
-            && $url['host'] != 'localhost'
-            && $url['host'] != '127.0.0.1'
-        ) {
-            $piwikHost = $url['host'];
-        }
-        $email = str_replace('{DOMAIN}', $piwikHost, $email);
-        return parent::setFrom($email, $name);
+    /**
+     * Set Reply-To Header
+     *
+     * @param string $email
+     * @param null|string $name
+     * @return Zend_Mail
+     */
+    public function setReplyTo($email, $name = null)
+    {
+        return parent::setReplyTo(
+            $this->parseDomainPlaceholderAsPiwikHostName($email),
+            $name
+        );
     }
 
     /**
@@ -83,4 +96,41 @@ class Mail extends Zend_Mail
         Mail::setDefaultTransport($tr);
         ini_set("smtp_port", $mailConfig['port']);
     }
-}
\ No newline at end of file
+
+    public function send($transport = NULL)
+    {
+        if (defined('PIWIK_TEST_MODE')) { // hack
+            Piwik::postTestEvent("Test.Mail.send", array($this));
+        } else {
+            return parent::send($transport);
+        }
+    }
+
+    /**
+     * @param string $email
+     * @return string
+     */
+    protected function parseDomainPlaceholderAsPiwikHostName($email)
+    {
+        $hostname = Config::getInstance()->mail['defaultHostnameIfEmpty'];
+        $piwikHost = Url::getCurrentHost($hostname);
+
+        // If known Piwik URL, use it instead of "localhost"
+        $piwikUrl = SettingsPiwik::getPiwikUrl();
+        $url = parse_url($piwikUrl);
+        if ($this->isHostDefinedAndNotLocal($url)) {
+            $piwikHost = $url['host'];
+        }
+
+        return str_replace('{DOMAIN}', $piwikHost, $email);
+    }
+
+    /**
+     * @param array $url
+     * @return bool
+     */
+    protected function isHostDefinedAndNotLocal($url)
+    {
+        return isset($url['host']) && !in_array($url['host'], array('localhost', '127.0.0.1'), true);
+    }
+}
