@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik\Plugin;
 
@@ -16,19 +14,22 @@ use Piwik\API\Proxy;
 use Piwik\API\Request;
 use Piwik\Common;
 use Piwik\Config as PiwikConfig;
+use Piwik\Config;
 use Piwik\DataTable\Filter\CalculateEvolutionFilter;
 use Piwik\Date;
 use Piwik\FrontController;
 use Piwik\Menu\MenuTop;
+use Piwik\Menu\MenuUser;
 use Piwik\NoAccessException;
 use Piwik\Notification\Manager as NotificationManager;
 use Piwik\Period\Month;
 use Piwik\Period;
 use Piwik\Period\Range;
 use Piwik\Piwik;
+use Piwik\Plugins\CoreAdminHome\CustomLogo;
+use Piwik\Plugins\CoreVisualizations\Visualizations\JqplotGraph\Evolution;
 use Piwik\Plugins\LanguagesManager\LanguagesManager;
-use Piwik\Plugins\SitesManager\API as APISitesManager;
-use Piwik\Plugins\UsersManager\API as APIUsersManager;
+use Piwik\Plugins\UsersManager\UserPreferences;
 use Piwik\Registry;
 use Piwik\SettingsPiwik;
 use Piwik\Site;
@@ -65,7 +66,6 @@ use Piwik\ViewDataTable\Factory as ViewDataTableFactory;
  *
  *     <a href="?module=MyPlugin&action=index&idSite=1&period=day&date=2013-10-10">Link</a>
  * 
- * @package Piwik
  */
 abstract class Controller
 {
@@ -179,6 +179,52 @@ abstract class Controller
         $this->strDate = $date->toString();
     }
 
+    /**
+     * Returns values that are enabled for the parameter &period=
+     * @return array eg. array('day', 'week', 'month', 'year', 'range')
+     */
+    protected static function getEnabledPeriodsInUI()
+    {
+        $periods = Config::getInstance()->General['enabled_periods_UI'];
+        $periods = explode(",", $periods);
+        $periods = array_map('trim', $periods);
+        return $periods;
+    }
+
+    /**
+     * @return array
+     */
+    private static function getEnabledPeriodsNames()
+    {
+        $availablePeriods = self::getEnabledPeriodsInUI();
+        $periodNames = array(
+            'day'   => array(
+                'singular' => Piwik::translate('CoreHome_PeriodDay'),
+                'plural' => Piwik::translate('CoreHome_PeriodDays')
+            ),
+            'week'  => array(
+                'singular' => Piwik::translate('CoreHome_PeriodWeek'),
+                'plural' => Piwik::translate('CoreHome_PeriodWeeks')
+            ),
+            'month' => array(
+                'singular' => Piwik::translate('CoreHome_PeriodMonth'),
+                'plural' => Piwik::translate('CoreHome_PeriodMonths')
+            ),
+            'year'  => array(
+                'singular' => Piwik::translate('CoreHome_PeriodYear'),
+                'plural' => Piwik::translate('CoreHome_PeriodYears')
+            ),
+            // Note: plural is not used for date range
+            'range' => array(
+                'singular' => Piwik::translate('General_DateRangeInPeriodList'),
+                'plural' => Piwik::translate('General_DateRangeInPeriodList')
+            ),
+        );
+
+        $periodNames = array_intersect_key($periodNames, array_fill_keys($availablePeriods, true));
+        return $periodNames;
+    }
+
     /**
      * Returns the name of the default method that will be called
      * when visiting: index.php?module=PluginName without the action parameter.
@@ -205,15 +251,16 @@ abstract class Controller
     /**
      * Convenience method that creates and renders a ViewDataTable for a API method.
      *
-     * @param string $pluginName The name of the plugin (eg, `'UserSettings'`).
      * @param string $apiAction The name of the API action (eg, `'getResolution'`).
+     * @param bool $controllerAction The name of the Controller action name  that is rendering the report. Defaults
+     *                               to the `$apiAction`.
      * @param bool $fetch If `true`, the rendered string is returned, if `false` it is `echo`'d.
      * @throws \Exception if `$pluginName` is not an existing plugin or if `$apiAction` is not an
      *                    existing method of the plugin's API.
      * @return string|void See `$fetch`.
      * @api
      */
-    protected function renderReport($apiAction)
+    protected function renderReport($apiAction, $controllerAction = false)
     {
         $pluginName = $this->pluginName;
 
@@ -226,7 +273,11 @@ abstract class Controller
 
         $apiAction = $apiProxy->buildApiActionName($pluginName, $apiAction);
 
-        $view      = ViewDataTableFactory::build(null, $apiAction);
+        if ($controllerAction !== false) {
+            $controllerAction = $pluginName . '.' . $controllerAction;
+        }
+
+        $view      = ViewDataTableFactory::build(null, $apiAction, $controllerAction);
         $rendered  = $view->render();
 
         return $rendered;
@@ -247,7 +298,7 @@ abstract class Controller
     protected function getLastUnitGraph($currentModuleName, $currentControllerAction, $apiMethod)
     {
         $view = ViewDataTableFactory::build(
-            'graphEvolution', $apiMethod, $currentModuleName . '.' . $currentControllerAction, $forceDefault = true);
+            Evolution::ID, $apiMethod, $currentModuleName . '.' . $currentControllerAction, $forceDefault = true);
         $view->config->show_goals = false;
         return $view;
     }
@@ -279,7 +330,7 @@ abstract class Controller
         $date = Common::getRequestVar('date');
         $meta = \Piwik\Plugins\API\API::getInstance()->getReportMetadata($idSite, $period, $date);
 
-        $columns = array_merge($columnsToDisplay, $selectableColumns);
+        $columns = array_merge($columnsToDisplay ? $columnsToDisplay : array(), $selectableColumns);
         $translations = array_combine($columns, $columns);
         foreach ($meta as $reportMeta) {
             if ($reportMeta['action'] == 'get' && !isset($reportMeta['parameters'])) {
@@ -293,6 +344,7 @@ abstract class Controller
 
         // initialize the graph and load the data
         $view = $this->getLastUnitGraph($currentModuleName, $currentControllerAction, $apiMethod);
+
         if ($columnsToDisplay !== false) {
             $view->config->columns_to_display = $columnsToDisplay;
         }
@@ -476,7 +528,7 @@ abstract class Controller
             $periodStr = Common::getRequestVar('period');
             if ($periodStr != 'range') {
                 $date = Date::factory($this->strDate);
-                $period = Period::factory($periodStr, $date);
+                $period = Period\Factory::build($periodStr, $date);
             } else {
                 $period = new Range($periodStr, $rawDate, $this->site->getTimezone());
             }
@@ -509,13 +561,17 @@ abstract class Controller
             $language = LanguagesManager::getLanguageForSession();
             $view->language = !empty($language) ? $language : LanguagesManager::getLanguageCodeForCurrentUser();
 
-            $view->config_action_url_category_delimiter = PiwikConfig::getInstance()->General['action_url_category_delimiter'];
-
             $this->setBasicVariablesView($view);
 
-            $view->topMenu       = MenuTop::getInstance()->getMenu();
-            $view->notifications = NotificationManager::getAllNotificationsToDisplay();
-            NotificationManager::cancelAllNonPersistent();
+            $view->topMenu  = MenuTop::getInstance()->getMenu();
+            $view->userMenu = MenuUser::getInstance()->getMenu();
+
+            $notifications = $view->notifications;
+            if (empty($notifications)) {
+                $view->notifications = NotificationManager::getAllNotificationsToDisplay();
+                NotificationManager::cancelAllNonPersistent();
+            }
+
         } catch (Exception $e) {
             Piwik_ExitWithMessage($e->getMessage(), $e->getTraceAsString());
         }
@@ -526,12 +582,12 @@ abstract class Controller
      * 
      * The following variables assigned:
      * 
-     * **debugTrackVisitsInsidePiwikUI** - The value of the `[Debug] track_visits_inside_piwik_ui`
+     * **enableMeasurePiwikForSiteId** - The value of the `[Debug] enable_measure_piwik_usage_in_idsite`
      *                                     INI config option.
-     * **isSuperUser** - True if the current user is the super user, false if otherwise.
+     * **isSuperUser** - True if the current user is the Super User, false if otherwise.
      * **hasSomeAdminAccess** - True if the current user has admin access to at least one site,
      *                          false if otherwise.
-     * **isCustomLogo** - The value of the `[branding] use_custom_logo` INI config option.
+     * **isCustomLogo** - The value of the `branding_use_custom_logo` option.
      * **logoHeader** - The header logo URL to use.
      * **logoLarge** - The large logo URL to use.
      * **logoSVG** - The SVG logo URL to use.
@@ -546,15 +602,21 @@ abstract class Controller
      */
     protected function setBasicVariablesView($view)
     {
-        $view->debugTrackVisitsInsidePiwikUI = PiwikConfig::getInstance()->Debug['track_visits_inside_piwik_ui'];
-        $view->isSuperUser = Access::getInstance()->isSuperUser();
+        $view->clientSideConfig = PiwikConfig::getInstance()->getClientSideOptions();
+        $view->enableMeasurePiwikForSiteId = PiwikConfig::getInstance()->Debug['enable_measure_piwik_usage_in_idsite'];
+        $view->isSuperUser = Access::getInstance()->hasSuperUserAccess();
         $view->hasSomeAdminAccess = Piwik::isUserHasSomeAdminAccess();
-        $view->isCustomLogo = PiwikConfig::getInstance()->branding['use_custom_logo'];
+        $view->hasSomeViewAccess  = Piwik::isUserHasSomeViewAccess();
+        $view->isUserIsAnonymous  = Piwik::isUserIsAnonymous();
+        $view->hasSuperUserAccess = Piwik::hasUserSuperUserAccess();
+
+        $this->addCustomLogoInfo($view);
 
         $view->logoHeader = \Piwik\Plugins\API\API::getInstance()->getHeaderLogoUrl();
         $view->logoLarge = \Piwik\Plugins\API\API::getInstance()->getLogoUrl();
         $view->logoSVG = \Piwik\Plugins\API\API::getInstance()->getSVGLogoUrl();
         $view->hasSVGLogo = \Piwik\Plugins\API\API::getInstance()->hasSVGLogo();
+        $view->superUserEmails = implode(',', Piwik::getAllSuperUserAccessEmailAddresses());
 
         $general = PiwikConfig::getInstance()->General;
         $view->enableFrames = $general['enable_framed_pages']
@@ -566,13 +628,20 @@ abstract class Controller
         self::setHostValidationVariablesView($view);
     }
 
+    protected function addCustomLogoInfo($view)
+    {
+        $customLogo = new CustomLogo();
+        $view->isCustomLogo  = $customLogo->isEnabled();
+        $view->customFavicon = $customLogo->getPathUserFavicon();
+    }
+
     /**
      * Checks if the current host is valid and sets variables on the given view, including:
      *
      * - **isValidHost** - true if host is valid, false if otherwise
      * - **invalidHostMessage** - message to display if host is invalid (only set if host is invalid)
      * - **invalidHost** - the invalid hostname (only set if host is invalid)
-     * - **mailLinkStart** - the open tag of a link to email the super user of this problem (only set
+     * - **mailLinkStart** - the open tag of a link to email the Super User of this problem (only set
      *                       if host is invalid)
      *
      * @param View $view
@@ -584,12 +653,13 @@ abstract class Controller
         $view->isValidHost = Url::isValidHost();
         if (!$view->isValidHost) {
             // invalid host, so display warning to user
-            $validHost = PiwikConfig::getInstance()->General['trusted_hosts'][0];
+            $validHosts = Url::getTrustedHostsFromConfig();
+            $validHost = $validHosts[0];
             $invalidHost = Common::sanitizeInputValue($_SERVER['HTTP_HOST']);
 
             $emailSubject = rawurlencode(Piwik::translate('CoreHome_InjectedHostEmailSubject', $invalidHost));
             $emailBody = rawurlencode(Piwik::translate('CoreHome_InjectedHostEmailBody'));
-            $superUserEmail = Piwik::getSuperUserEmail();
+            $superUserEmail = implode(',', Piwik::getAllSuperUserAccessEmailAddresses());
 
             $mailToUrl = "mailto:$superUserEmail?subject=$emailSubject&body=$emailBody";
             $mailLinkStart = "<a href=\"$mailToUrl\">";
@@ -612,7 +682,7 @@ abstract class Controller
                                                                                       '<strong>' . $validUrl . '</strong>'
                                                                                  )) . ' <br/>';
 
-            if (Piwik::isUserIsSuperUser()) {
+            if (Piwik::hasUserSuperUserAccess()) {
                 $view->invalidHostMessage = $warningStart . ' '
                     . Piwik::translate('CoreHome_InjectedHostSuperUserWarning', array(
                                                                                     "<a href=\"$changeTrustedHostsUrl\">",
@@ -622,6 +692,14 @@ abstract class Controller
                                                                                     $validHost,
                                                                                     '</a>'
                                                                                ));
+            } else if (Piwik::isUserIsAnonymous()) {
+                $view->invalidHostMessage = $warningStart . ' '
+                    . Piwik::translate('CoreHome_InjectedHostNonSuperUserWarning', array(
+                        "<br/><a href=\"$validUrl\">",
+                        '</a>',
+                        '<span style="display:none">',
+                        '</span>'
+                    ));
             } else {
                 $view->invalidHostMessage = $warningStart . ' '
                     . Piwik::translate('CoreHome_InjectedHostNonSuperUserWarning', array(
@@ -662,26 +740,16 @@ abstract class Controller
 
         $currentPeriod = Common::getRequestVar('period');
         $view->displayUniqueVisitors = SettingsPiwik::isUniqueVisitorsEnabled($currentPeriod);
-        $availablePeriods = array('day', 'week', 'month', 'year', 'range');
+        $availablePeriods = self::getEnabledPeriodsInUI();
         if (!in_array($currentPeriod, $availablePeriods)) {
-            throw new Exception("Period must be one of: " . implode(",", $availablePeriods));
+            throw new Exception("Period must be one of: " . implode(", ", $availablePeriods));
         }
-        $periodNames = array(
-            'day'   => array('singular' => Piwik::translate('CoreHome_PeriodDay'), 'plural' => Piwik::translate('CoreHome_PeriodDays')),
-            'week'  => array('singular' => Piwik::translate('CoreHome_PeriodWeek'), 'plural' => Piwik::translate('CoreHome_PeriodWeeks')),
-            'month' => array('singular' => Piwik::translate('CoreHome_PeriodMonth'), 'plural' => Piwik::translate('CoreHome_PeriodMonths')),
-            'year'  => array('singular' => Piwik::translate('CoreHome_PeriodYear'), 'plural' => Piwik::translate('CoreHome_PeriodYears')),
-            // Note: plural is not used for date range
-            'range' => array('singular' => Piwik::translate('General_DateRangeInPeriodList'), 'plural' => Piwik::translate('General_DateRangeInPeriodList')),
-        );
-
         $found = array_search($currentPeriod, $availablePeriods);
-        if ($found !== false) {
-            unset($availablePeriods[$found]);
-        }
+        unset($availablePeriods[$found]);
+
         $view->period = $currentPeriod;
         $view->otherPeriods = $availablePeriods;
-        $view->periodsNames = $periodNames;
+        $view->periodsNames = self::getEnabledPeriodsNames();
     }
 
     /**
@@ -700,14 +768,17 @@ abstract class Controller
     public function redirectToIndex($moduleToRedirect, $actionToRedirect, $websiteId = null, $defaultPeriod = null,
                                     $defaultDate = null, $parameters = array())
     {
+
+        $userPreferences = new UserPreferences();
+
         if (empty($websiteId)) {
-            $websiteId = $this->getDefaultWebsiteId();
+            $websiteId = $userPreferences->getDefaultWebsiteId();
         }
         if (empty($defaultDate)) {
-            $defaultDate = $this->getDefaultDate();
+            $defaultDate = $userPreferences->getDefaultDate();
         }
         if (empty($defaultPeriod)) {
-            $defaultPeriod = $this->getDefaultPeriod();
+            $defaultPeriod = $userPreferences->getDefaultPeriod();
         }
         $parametersString = '';
         if (!empty($parameters)) {
@@ -715,17 +786,17 @@ abstract class Controller
         }
 
         if ($websiteId) {
-            $url = "Location: index.php?module=" . $moduleToRedirect
+            $url = "index.php?module=" . $moduleToRedirect
                 . "&action=" . $actionToRedirect
                 . "&idSite=" . $websiteId
                 . "&period=" . $defaultPeriod
                 . "&date=" . $defaultDate
                 . $parametersString;
-            header($url);
+            Url::redirectToUrl($url);
             exit;
         }
 
-        if (Piwik::isUserIsSuperUser()) {
+        if (Piwik::hasUserSuperUserAccess()) {
             Piwik_ExitWithMessage("Error: no website was found in this Piwik installation.
 			<br />Check the table '" . Common::prefixTable('site') . "' in your database, it should contain your Piwik websites.", false, true);
         }
@@ -734,7 +805,8 @@ abstract class Controller
         if (!empty($currentLogin)
             && $currentLogin != 'anonymous'
         ) {
-            $errorMessage = sprintf(Piwik::translate('CoreHome_NoPrivilegesAskPiwikAdmin'), $currentLogin, "<br/><a href='mailto:" . Piwik::getSuperUserEmail() . "?subject=Access to Piwik for user $currentLogin'>", "</a>");
+            $emails = implode(',', Piwik::getAllSuperUserAccessEmailAddresses());
+            $errorMessage = sprintf(Piwik::translate('CoreHome_NoPrivilegesAskPiwikAdmin'), $currentLogin, "<br/><a href='mailto:" . $emails . "?subject=Access to Piwik for user $currentLogin'>", "</a>");
             $errorMessage .= "<br /><br />&nbsp;&nbsp;&nbsp;<b><a href='index.php?module=" . Registry::get('auth')->getName() . "&amp;action=logout'>&rsaquo; " . Piwik::translate('General_Logout') . "</a></b><br />";
             Piwik_ExitWithMessage($errorMessage, false, true);
         }
@@ -743,84 +815,6 @@ abstract class Controller
         exit;
     }
 
-    /**
-     * Returns default site ID that Piwik should load.
-     * 
-     * _Note: This value is a Piwik setting set by each user._
-     *
-     * @return bool|int
-     * @api
-     */
-    protected function getDefaultWebsiteId()
-    {
-        $defaultWebsiteId = false;
-
-        // User preference: default website ID to load
-        $defaultReport = APIUsersManager::getInstance()->getUserPreference(Piwik::getCurrentUserLogin(), APIUsersManager::PREFERENCE_DEFAULT_REPORT);
-        if (is_numeric($defaultReport)) {
-            $defaultWebsiteId = $defaultReport;
-        }
-
-        ;
-
-        if ($defaultWebsiteId && Piwik::isUserHasViewAccess($defaultWebsiteId)) {
-            return $defaultWebsiteId;
-        }
-
-        $sitesId = APISitesManager::getInstance()->getSitesIdWithAtLeastViewAccess();
-        if (!empty($sitesId)) {
-            return $sitesId[0];
-        }
-        return false;
-    }
-
-    /**
-     * Returns default date for Piwik reports.
-     *
-     * _Note: This value is a Piwik setting set by each user._
-     * 
-     * @return string `'today'`, `'2010-01-01'`, etc.
-     * @api
-     */
-    protected function getDefaultDate()
-    {
-        // NOTE: a change in this function might mean a change in plugins/UsersManager/javascripts/usersSettings.js as well
-        $userSettingsDate = APIUsersManager::getInstance()->getUserPreference(Piwik::getCurrentUserLogin(), APIUsersManager::PREFERENCE_DEFAULT_REPORT_DATE);
-        if ($userSettingsDate == 'yesterday') {
-            return $userSettingsDate;
-        }
-        // if last7, last30, etc.
-        if (strpos($userSettingsDate, 'last') === 0
-            || strpos($userSettingsDate, 'previous') === 0
-        ) {
-            return $userSettingsDate;
-        }
-        return 'today';
-    }
-
-    /**
-     * Returns default period type for Piwik reports.
-     *
-     * @return string `'day'`, `'week'`, `'month'`, `'year'` or `'range'`
-     * @api
-     */
-    protected function getDefaultPeriod()
-    {
-        $userSettingsDate = APIUsersManager::getInstance()->getUserPreference(Piwik::getCurrentUserLogin(), APIUsersManager::PREFERENCE_DEFAULT_REPORT_DATE);
-        if ($userSettingsDate === false) {
-            return PiwikConfig::getInstance()->General['default_period'];
-        }
-        if (in_array($userSettingsDate, array('today', 'yesterday'))) {
-            return 'day';
-        }
-        if (strpos($userSettingsDate, 'last') === 0
-            || strpos($userSettingsDate, 'previous') === 0
-        ) {
-            return 'range';
-        }
-        return $userSettingsDate;
-    }
-
     /**
      * Checks that the token_auth in the URL matches the currently logged-in user's token_auth.
      * 
@@ -834,7 +828,14 @@ abstract class Controller
      */
     protected function checkTokenInUrl()
     {
-        if (Common::getRequestVar('token_auth', false) != Piwik::getCurrentUserTokenAuth()) {
+        $tokenRequest = Common::getRequestVar('token_auth', false);
+        $tokenUser = Piwik::getCurrentUserTokenAuth();
+
+        if(empty($tokenRequest) && empty($tokenUser)) {
+            return; // UI tests
+        }
+
+        if ($tokenRequest !== $tokenUser) {
             throw new NoAccessException(Piwik::translate('General_ExceptionInvalidToken'));
         }
     }
@@ -865,7 +866,7 @@ abstract class Controller
      */
     public static function getPrettyDate($date, $period)
     {
-        return self::getCalendarPrettyDate(Period::factory($period, Date::factory($date)));
+        return self::getCalendarPrettyDate(Period\Factory::build($period, Date::factory($date)));
     }
 
     /**
@@ -925,4 +926,4 @@ abstract class Controller
 
         return $result;
     }
-}
\ No newline at end of file
+}
