@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 
 namespace Piwik\Plugin;
@@ -146,7 +144,7 @@ class Visualization extends ViewDataTable
     private $reportLastUpdatedMessage = null;
     private $metadata = null;
 
-    final public function __construct($controllerAction, $apiMethodToRequestDataTable)
+    final public function __construct($controllerAction, $apiMethodToRequestDataTable, $params = array())
     {
         $templateFile = static::TEMPLATE_FILE;
 
@@ -154,7 +152,7 @@ class Visualization extends ViewDataTable
             throw new \Exception('You have not defined a constant named TEMPLATE_FILE in your visualization class.');
         }
 
-        parent::__construct($controllerAction, $apiMethodToRequestDataTable);
+        parent::__construct($controllerAction, $apiMethodToRequestDataTable, $params);
     }
 
     protected function buildView()
@@ -181,7 +179,12 @@ class Visualization extends ViewDataTable
         } catch (\Exception $e) {
             Log::warning("Failed to get data from API: " . $e->getMessage() . "\n" . $e->getTraceAsString());
 
-            $loadingError = array('message' => $e->getMessage());
+            $message = $e->getMessage();
+            if (\Piwik_ShouldPrintBackTraceWithMessage()) {
+                $message .= "\n" . $e->getTraceAsString();
+            }
+
+            $loadingError = array('message' => $message);
         }
 
         $view = new View("@CoreHome/_dataTable");
@@ -257,7 +260,7 @@ class Visualization extends ViewDataTable
      */
     protected function isThereDataToDisplay()
     {
-        return true;
+        return !empty($this->dataTable) && 0 < $this->dataTable->getRowsCount();
     }
 
     /**
@@ -307,6 +310,11 @@ class Visualization extends ViewDataTable
 
         $this->beforeGenericFiltersAreAppliedToLoadedDataTable();
 
+        if (!in_array($this->requestConfig->filter_sort_column, $this->config->columns_to_display)) {
+            $hasNbUniqVisitors = in_array('nb_uniq_visitors', $this->config->columns_to_display);
+            $this->requestConfig->setDefaultSort($this->config->columns_to_display, $hasNbUniqVisitors);
+        }
+
         if (!$this->requestConfig->areGenericFiltersDisabled()) {
             $this->applyGenericFilters();
         }
@@ -422,7 +430,7 @@ class Visualization extends ViewDataTable
      * - etc.
      *
      * The values are loaded:
-     * - from the generic filters that are applied by default @see Piwik_API_DataTableGenericFilter.php::getGenericFiltersInformation()
+     * - from the generic filters that are applied by default @see Piwik\API\DataTableGenericFilter::getGenericFiltersInformation()
      * - from the values already available in the GET array
      * - from the values set using methods from this class (eg. setSearchPattern(), setLimit(), etc.)
      *
@@ -502,6 +510,8 @@ class Visualization extends ViewDataTable
      * 
      * Use this method to change the request parameters that is sent to the API when requesting
      * data.
+     *
+     * @api
      */
     public function beforeLoadDataTable()
     {
@@ -512,6 +522,8 @@ class Visualization extends ViewDataTable
      * 
      * Use this method if you need access to the entire dataset (since generic filters will
      * limit and truncate reports).
+     *
+     * @api
      */
     public function beforeGenericFiltersAreAppliedToLoadedDataTable()
     {
@@ -519,6 +531,8 @@ class Visualization extends ViewDataTable
 
     /**
      * Hook that is executed after generic filters are applied.
+     *
+     * @api
      */
     public function afterGenericFiltersAreAppliedToLoadedDataTable()
     {
@@ -527,6 +541,8 @@ class Visualization extends ViewDataTable
     /**
      * Hook that is executed after the report data is loaded and after all filters have been applied.
      * Use this method to format the report data before the view is rendered.
+     *
+     * @api
      */
     public function afterAllFiltersAreApplied()
     {
@@ -535,6 +551,8 @@ class Visualization extends ViewDataTable
     /**
      * Hook that is executed directly before rendering. Use this hook to force display properties to
      * be a certain value, despite changes from plugins and query parameters.
+     *
+     * @api
      */
     public function beforeRender()
     {
@@ -565,6 +583,15 @@ class Visualization extends ViewDataTable
         $diff = array_diff_assoc($this->makeSureArrayContainsOnlyStrings($requestProperties),
                                  $this->makeSureArrayContainsOnlyStrings($requestPropertiesBefore));
 
+        if (!empty($diff['filter_sort_column'])) {
+            // this here might be ok as it can be changed after data loaded but before filters applied
+            unset($diff['filter_sort_column']);
+        }
+        if (!empty($diff['filter_sort_order'])) {
+            // this here might be ok as it can be changed after data loaded but before filters applied
+            unset($diff['filter_sort_order']);
+        }
+
         if (empty($diff)) {
             return;
         }
@@ -594,4 +621,4 @@ class Visualization extends ViewDataTable
 
         return $result;
     }
-}
\ No newline at end of file
+}
