@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik;
 
@@ -21,7 +19,6 @@ namespace Piwik;
  *   log_writers[] = file
  *   log_level=debug
  *
- * @package Piwik
  */
 class Profiler
 {
@@ -55,7 +52,8 @@ class Profiler
         $profiler = Db::get()->getProfiler();
 
         if (!$profiler->getEnabled()) {
-            throw new \Exception("To display the profiler you should enable enable_sql_profiler on your config/config.ini.php file");
+            // To display the profiler you should enable enable_sql_profiler on your config/config.ini.php file
+            return;
         }
 
         $infoIndexedByQuery = array();
@@ -136,7 +134,9 @@ class Profiler
     {
         $totalTime = self::getDbElapsedSecs();
         $queryCount = Profiler::getQueryCount();
-        Log::debug(sprintf("Total queries = %d (total sql time = %.2fs)", $queryCount, $totalTime));
+        if($queryCount > 0) {
+            Log::debug(sprintf("Total queries = %d (total sql time = %.2fs)", $queryCount, $totalTime));
+        }
     }
 
     /**
@@ -189,7 +189,7 @@ class Profiler
      */
     public static function setupProfilerXHProf($mainRun = false)
     {
-        if(!empty($GLOBALS['PIWIK_TRACKER_MODE'])) {
+        if(SettingsServer::isTrackerApiRequest()) {
             // do not profile Tracker
             return;
         }
@@ -290,4 +290,4 @@ class Profiler
     {
         return PIWIK_INCLUDE_PATH . '/tmp/cache/tests-xhprof-runs';
     }
-}
\ No newline at end of file
+}
