@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik;
 
@@ -20,9 +18,6 @@ use Piwik\Plugins\ImageGraph\API;
 /**
  * A Report Renderer produces user friendly renderings of any given Piwik report.
  * All new Renderers must be copied in ReportRenderer and added to the $availableReportRenderers.
- *
- * @package Piwik
- * @subpackage ReportRenderer
  */
 abstract class ReportRenderer
 {
@@ -36,10 +31,12 @@ abstract class ReportRenderer
 
     const HTML_FORMAT = 'html';
     const PDF_FORMAT = 'pdf';
+    const CSV_FORMAT = 'csv';
 
     static private $availableReportRenderers = array(
         self::PDF_FORMAT,
         self::HTML_FORMAT,
+        self::CSV_FORMAT,
     );
 
     /**
@@ -124,6 +121,16 @@ abstract class ReportRenderer
      */
     abstract public function renderReport($processedReport);
 
+    /**
+     * Get report attachments, ex. graph images
+     *
+     * @param $report
+     * @param $processedReports
+     * @param $prettyDate
+     * @return array
+     */
+    abstract public function getAttachments($report, $processedReports, $prettyDate);
+
     /**
      * Append $extension to $filename
      *
@@ -147,7 +154,7 @@ abstract class ReportRenderer
     protected static function getOutputPath($filename)
     {
         $outputFilename = PIWIK_USER_PATH . '/tmp/assets/' . $filename;
-        $outputFilename = SettingsPiwik::rewriteTmpPathWithHostname($outputFilename);
+        $outputFilename = SettingsPiwik::rewriteTmpPathWithInstanceId($outputFilename);
 
         @chmod($outputFilename, 0600);
         @unlink($outputFilename);
