@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 
 namespace Piwik;
@@ -20,8 +18,6 @@ use Piwik\ScheduledTime;
  * 
  * See the {@link TaskScheduler} docs to learn more about scheduled tasks.
  * 
- * @package Piwik
- * @subpackage ScheduledTask
  *
  * @api
  */
@@ -105,10 +101,10 @@ class ScheduledTask
         }
 
         $namespaced = get_class($_objectInstance);
-        $class = explode('\\', $namespaced);
-        return end($class);
-    }
 
+        return $namespaced;
+    }
+    
     /**
      * Returns the object instance that contains the method to execute. Returns a class
      * name if the method is static.
@@ -205,4 +201,4 @@ class ScheduledTask
     {
         return $className . '.' . $methodName . ($methodParameter == null ? '' : '_' . $methodParameter);
     }
-}
\ No newline at end of file
+}
