@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 
 namespace Piwik;
@@ -22,8 +20,6 @@ use Piwik\ScheduledTime\Weekly;
  * to create ScheduledTime instances.
  *
  * @see \Piwik\ScheduledTask
- * @package Piwik
- * @subpackage ScheduledTime
  */
 abstract class ScheduledTime
 {
@@ -50,6 +46,8 @@ abstract class ScheduledTime
      */
     protected $day = 1;
 
+    protected $timezone = null;
+
     /**
      * @param $period
      * @return Daily|Monthly|Weekly
@@ -73,33 +71,6 @@ abstract class ScheduledTime
         }
     }
 
-    /**
-     * This method takes the websites timezone into consideration when scheduling a task.
-     * @param int $idSite
-     * @param string $period  Eg 'day', 'week', 'month'
-     * @return Daily|Monthly|Weekly
-     * @throws \Exception
-     * @ignore
-     */
-    static public function getScheduledTimeForSite($idSite, $period)
-    {
-        $arbitraryDateInUTC     = Date::factory('2011-01-01');
-        $midnightInSiteTimezone = date(
-                                      'H',
-                                      Date::factory(
-                                          $arbitraryDateInUTC,
-                                          Site::getTimezoneFor($idSite)
-                                      )->getTimestamp()
-                                  );
-
-        $hourInUTC = (24 - $midnightInSiteTimezone) % 24;
-
-        $schedule = self::getScheduledTimeForPeriod($period);
-        $schedule->setHour($hourInUTC);
-
-        return $schedule;
-    }
-
     /**
      * Returns the system time used by subclasses to compute schedulings.
      * This method has been introduced so unit tests can override the current system time.
@@ -145,6 +116,47 @@ abstract class ScheduledTime
         $this->hour = $hour;
     }
 
+    /**
+     * By setting a timezone you make sure the scheduled task will be run at the requested time in the
+     * given timezone. This is useful for instance in case you want to make sure a task runs at midnight in a website's
+     * timezone.
+     *
+     * @param string $timezone
+     */
+    public function setTimezone($timezone)
+    {
+        $this->timezone = $timezone;
+    }
+
+    protected function adjustTimezone($rescheduledTime)
+    {
+        if (is_null($this->timezone)) {
+            return $rescheduledTime;
+        }
+
+        $arbitraryDateInUTC = Date::factory('2011-01-01');
+        $dateInTimezone     = Date::factory($arbitraryDateInUTC, $this->timezone);
+
+        $midnightInTimezone = date('H', $dateInTimezone->getTimestamp());
+
+        if ($arbitraryDateInUTC->isEarlier($dateInTimezone)) {
+            $hoursDifference = 0 - $midnightInTimezone;
+        } else {
+            $hoursDifference = 24 - $midnightInTimezone;
+        }
+
+        $hoursDifference  = $hoursDifference % 24;
+
+        $rescheduledTime += (3600 * $hoursDifference);
+
+        if ($this->getTime() > $rescheduledTime) {
+            // make sure the rescheduled date is in the future
+            $rescheduledTime = (24 * 3600) + $rescheduledTime;
+        }
+        
+        return $rescheduledTime;
+    }
+
     /**
      * Computes the delta in seconds needed to adjust the rescheduled time to the required hour.
      *
@@ -210,4 +222,4 @@ abstract class ScheduledTime
                                   . " 'hourly', 'daily', 'weekly' or 'monthly'.");
         }
     }
-}
\ No newline at end of file
+}
