@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik\ScheduledTime;
 
@@ -17,8 +15,6 @@ use Piwik\ScheduledTime;
  * Monthly class is used to schedule tasks every month.
  *
  * @see ScheduledTask
- * @package Piwik
- * @subpackage ScheduledTime
  *
  */
 class Monthly extends ScheduledTime
@@ -108,6 +104,7 @@ class Monthly extends ScheduledTime
 
         // Adjusts the scheduled hour
         $rescheduledTime = $this->adjustHour($rescheduledTime);
+        $rescheduledTime = $this->adjustTimezone($rescheduledTime);
 
         return $rescheduledTime;
     }
@@ -145,4 +142,4 @@ class Monthly extends ScheduledTime
         $this->dayOfWeek = $_day;
         $this->week = $_week;
     }
-}
\ No newline at end of file
+}
