@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik\ScheduledTime;
 
@@ -17,8 +15,6 @@ use Piwik\ScheduledTime;
  * Weekly class is used to schedule tasks every week.
  *
  * @see ScheduledTask
- * @package Piwik
- * @subpackage ScheduledTime
  *
  */
 class Weekly extends ScheduledTime
@@ -53,6 +49,7 @@ class Weekly extends ScheduledTime
  
         // Adjusts the scheduled hour
         $rescheduledTime = $this->adjustHour($rescheduledTime);
+        $rescheduledTime = $this->adjustTimezone($rescheduledTime);
 
         return $rescheduledTime;
     }
@@ -83,4 +80,4 @@ class Weekly extends ScheduledTime
 
         return date("N", $time);
     }
-}
\ No newline at end of file
+}
