@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 
 namespace Piwik\Settings;
@@ -14,18 +12,24 @@ namespace Piwik\Settings;
 use Piwik\Piwik;
 
 /**
- * Describes a system wide setting. Only the super user can change this type of setting and
+ * Describes a system wide setting. Only the Super User can change this type of setting and
  * the value of this setting will affect all users.
  * 
  * See {@link \Piwik\Plugin\Settings}.
  *
- * @package Piwik
- * @subpackage Settings
  *
  * @api
  */
 class SystemSetting extends Setting
 {
+    /**
+     * By default the value of the system setting is only readable by SuperUsers but someone the value should be
+     * readable by everyone.
+     *
+     * @var bool
+     */
+    public $readableByCurrentUser = false;
+
     /**
      * Constructor.
      * 
@@ -36,7 +40,8 @@ class SystemSetting extends Setting
     {
         parent::__construct($name, $title);
 
-        $this->displayedForCurrentUser = Piwik::isUserIsSuperUser();
+        $this->writableByCurrentUser = Piwik::hasUserSuperUserAccess();
+        $this->readableByCurrentUser = $this->writableByCurrentUser;
     }
 
     /**
@@ -48,4 +53,4 @@ class SystemSetting extends Setting
     {
         return 30;
     }
-}
\ No newline at end of file
+}
