@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 
 namespace Piwik;
@@ -38,7 +36,6 @@ use Piwik\Plugins\SitesManager\API;
  * 
  *     $name = Site::getNameFor($idSite);
  * 
- * @package Piwik
  * @api
  */
 class Site
@@ -98,7 +95,7 @@ class Site
     protected static function setSite($idSite, $infoSite)
     {
         if(empty($idSite) || empty($infoSite)) {
-            throw new Exception("Un unexpected website was found.");
+            throw new Exception("An unexpected website was found, check idSite in the request.");
         }
 
         /**
@@ -444,6 +441,17 @@ class Site
         return self::getFor($idsite, 'name');
     }
 
+    /**
+     * Returns the group of the site with the specified ID.
+     *
+     * @param int $idsite The site ID.
+     * @return string
+     */
+    static public function getGroupFor($idsite)
+    {
+        return self::getFor($idsite, 'group');
+    }
+
     /**
      * Returns the timezone of the site with the specified ID.
      *
@@ -542,4 +550,4 @@ class Site
     {
         return self::getFor($idsite, 'excluded_parameters');
     }
-}
\ No newline at end of file
+}
