@@ -1,17 +1,16 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik\Tracker;
 
 use Piwik\ArchiveProcessor\Rules;
 use Piwik\CacheFile;
+use Piwik\Common;
 use Piwik\Config;
 use Piwik\Option;
 use Piwik\Piwik;
@@ -20,8 +19,6 @@ use Piwik\Tracker;
 /**
  * Simple cache mechanism used in Tracker to avoid requesting settings from mysql on every request
  *
- * @package Piwik
- * @subpackage Tracker
  */
 class Cache
 {
@@ -63,9 +60,9 @@ class Cache
 
         Tracker::initCorePiwikInTrackerMode();
 
-        // save current user privilege and temporarily assume super user privilege
-        $isSuperUser = Piwik::isUserIsSuperUser();
-        Piwik::setUserIsSuperUser();
+        // save current user privilege and temporarily assume Super User privilege
+        $isSuperUser = Piwik::hasUserSuperUserAccess();
+        Piwik::setUserHasSuperUserAccess();
 
         $content = array();
         
@@ -88,9 +85,10 @@ class Cache
          * @param int $idSite The site ID to get attributes for.
          */
         Piwik::postEvent('Tracker.Cache.getSiteAttributes', array(&$content, $idSite));
+        Common::printDebug("Website $idSite tracker cache was re-created.");
 
         // restore original user privilege
-        Piwik::setUserIsSuperUser($isSuperUser);
+        Piwik::setUserHasSuperUserAccess($isSuperUser);
 
         // if nothing is returned from the plugins, we don't save the content
         // this is not expected: all websites are expected to have at least one URL
@@ -118,10 +116,8 @@ class Cache
     {
         $cache = self::getInstance();
         $cacheId = 'general';
-        $expectedRows = 3;
-        if (($cacheContent = $cache->get($cacheId)) !== false
-            && count($cacheContent) == $expectedRows
-        ) {
+
+        if (($cacheContent = $cache->get($cacheId)) !== false) {
             return $cacheContent;
         }
 
@@ -153,6 +149,7 @@ class Cache
          */
         Piwik::postEvent('Tracker.setTrackerCacheGeneral', array(&$cacheContent));
         self::setCacheGeneral($cacheContent);
+        Common::printDebug("General tracker cache was re-created.");
         return $cacheContent;
     }
 
@@ -204,4 +201,4 @@ class Cache
     {
         self::getInstance()->deleteAll();
     }
-}
\ No newline at end of file
+}
