@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik\Tracker;
 
@@ -16,12 +14,13 @@ use Piwik\Config;
 use Piwik\Cookie;
 use Piwik\IP;
 use Piwik\Piwik;
+use Piwik\Plugins\CustomVariables\CustomVariables;
+use Piwik\Registry;
 use Piwik\Tracker;
 
 /**
  * The Request object holding the http parameters for this tracking request. Use getParam() to fetch a named parameter.
  *
- * @package Piwik\Tracker
  */
 class Request
 {
@@ -32,7 +31,9 @@ class Request
 
     protected $forcedVisitorId = false;
 
-    protected $isAuthenticated = false;
+    protected $isAuthenticated = null;
+
+    protected $tokenAuth;
 
     const UNKNOWN_RESOLUTION = 'unknown';
 
@@ -46,6 +47,7 @@ class Request
             $params = array();
         }
         $this->params = $params;
+        $this->tokenAuth = $tokenAuth;
         $this->timestamp = time();
         $this->enforcedIp = false;
 
@@ -60,7 +62,6 @@ class Request
                 $this->params['url'] = $url;
             }
         }
-        $this->authenticateTrackingApi($tokenAuth);
     }
 
     /**
@@ -68,6 +69,10 @@ class Request
      */
     public function isAuthenticated()
     {
+        if (is_null($this->isAuthenticated)) {
+            $this->authenticateTrackingApi($this->tokenAuth);
+        }
+
         return $this->isAuthenticated;
     }
 
@@ -101,9 +106,16 @@ class Request
         if (empty($tokenAuth)) {
             return false;
         }
-        $superUserLogin = Config::getInstance()->superuser['login'];
-        $superUserPassword = Config::getInstance()->superuser['password'];
-        if (md5($superUserLogin . $superUserPassword) === $tokenAuth) {
+
+        Piwik::postEvent('Request.initAuthenticationObject');
+
+        /** @var \Piwik\Auth $auth */
+        $auth = Registry::get('auth');
+        $auth->setTokenAuth($tokenAuth);
+        $auth->setLogin(null);
+        $access = $auth->authenticate();
+
+        if (!empty($access) && $access->hasSuperUserAccess()) {
             return true;
         }
 
@@ -341,10 +353,11 @@ class Request
             return array();
         }
         $customVariables = array();
+        $maxCustomVars = CustomVariables::getMaxCustomVariables();
         foreach ($customVar as $id => $keyValue) {
             $id = (int)$id;
             if ($id < 1
-                || $id > Tracker::MAX_CUSTOM_VARIABLES
+                || $id > $maxCustomVars
                 || count($keyValue) != 2
                 || (!is_string($keyValue[0]) && !is_numeric($keyValue[0]))
             ) {
@@ -368,7 +381,7 @@ class Request
 
     public static function truncateCustomVariable($input)
     {
-        return substr(trim($input), 0, Tracker::MAX_LENGTH_CUSTOM_VARIABLE);
+        return substr(trim($input), 0, CustomVariables::getMaxLengthCustomVariables());
     }
 
     protected function shouldUseThirdPartyCookie()
