@@ -1,16 +1,17 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik\Tracker;
 
+use DeviceDetector\Parser\Bot;
 use Piwik\Common;
+use Piwik\Config;
+use Piwik\DeviceDetectorFactory;
 use Piwik\IP;
 use Piwik\Piwik;
 
@@ -74,9 +75,9 @@ class VisitExcluded
 
         /**
          * Triggered on every tracking request.
-         * 
+         *
          * This event can be used to tell the Tracker not to record this particular action or visit.
-         * 
+         *
          * @param bool &$excluded Whether the request should be excluded or not. Initialized
          *                        to `false`. Event subscribers should set it to `true` in
          *                        order to exclude the request.
@@ -112,6 +113,14 @@ class VisitExcluded
             }
         }
 
+        // Check if Referrer URL is a known spam
+        if (!$excluded) {
+            $excluded = $this->isReferrerSpamExcluded();
+            if ($excluded) {
+                Common::printDebug("Referrer URL is blacklisted as spam.");
+            }
+        }
+
         if (!$excluded) {
             if ($this->isPrefetchDetected()) {
                 $excluded = true;
@@ -140,36 +149,27 @@ class VisitExcluded
      * As a result, these sophisticated bots exhibit characteristics of
      * browsers (cookies enabled, executing JavaScript, etc).
      *
+     * @see \DeviceDetector\Parser\Bot
+     *
      * @return boolean
      */
     protected function isNonHumanBot()
     {
         $allowBots = $this->request->getParam('bots');
 
-        return !$allowBots
-            // Seen in the wild
-        && (strpos($this->userAgent, 'Googlebot') !== false // Googlebot
-            || strpos($this->userAgent, 'Google Web Preview') !== false // Google Instant
-            || strpos($this->userAgent, 'AdsBot-Google') !== false // Google Adwords landing pages
-            || strpos($this->userAgent, 'Google Page Speed Insights') !== false // #4049
-            || strpos($this->userAgent, 'Google (+https://developers.google.com') !== false // Google Snippet https://developers.google.com/+/web/snippet/
-            || strpos($this->userAgent, 'facebookexternalhit') !== false // http://www.facebook.com/externalhit_uatext.php
-            || strpos($this->userAgent, 'baidu') !== false // Baidu
-            || strpos($this->userAgent, 'bingbot') !== false // Bingbot
-            || strpos($this->userAgent, 'YottaaMonitor') !== false // Yottaa
-            || strpos($this->userAgent, 'CloudFlare') !== false // CloudFlare-AlwaysOnline
+        $deviceDetector = DeviceDetectorFactory::getInstance($this->userAgent);
 
-            // Added as they are popular bots
-            || strpos($this->userAgent, 'yandex') !== false // yandex
-            || strpos($this->userAgent, 'exabot') !== false // Exabot
-            || strpos($this->userAgent, 'sogou') !== false // Sogou
-            || strpos($this->userAgent, 'soso') !== false // Soso
+        return !$allowBots
+        && ($deviceDetector->isBot()
             || IP::isIpInRange($this->ip, $this->getBotIpRanges()));
     }
 
-    protected function  getBotIpRanges()
+    protected function getBotIpRanges()
     {
         return array(
+            // Google
+            '66.249.0.0/16',
+            '64.233.172.0/24',
             // Live/Bing/MSN
             '64.4.0.0/18',
             '65.52.0.0/14',
@@ -242,4 +242,24 @@ class VisitExcluded
         }
         return false;
     }
+
+    /**
+     * Returns true if the Referrer is a known spammer.
+     *
+     * @return bool
+     */
+    protected function isReferrerSpamExcluded()
+    {
+        $spamHosts = Config::getInstance()->Tracker['referrer_urls_spam'];
+        $spamHosts = explode(",", $spamHosts);
+
+        $referrerUrl = $this->request->getParam('urlref');
+        foreach($spamHosts as $spamHost) {
+            if( strpos($referrerUrl, $spamHost) !== false) {
+                Common::printDebug('Referrer URL is a known spam: ' . $spamHost);
+                return true;
+            }
+        }
+        return false;
+    }
 }
