@@ -1,17 +1,18 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 namespace Piwik;
 
 use Exception;
+use Piwik\DataTable\Filter\SafeDecodeLabel;
+use Piwik\Period\Range;
 use Piwik\Translate;
+use Piwik\View\RenderTokenParser;
 use Piwik\Visualization\Sparkline;
 use Twig_Environment;
 use Twig_Extension_Debug;
@@ -23,8 +24,6 @@ use Twig_SimpleFunction;
 /**
  * Twig class
  *
- * @package Piwik
- * @subpackage Twig
  */
 class Twig
 {
@@ -39,15 +38,30 @@ class Twig
     public function __construct()
     {
         $loader = $this->getDefaultThemeLoader();
+		$this->addPluginNamespaces($loader);
 
-        $this->addPluginNamespaces($loader);
+		//get current theme
+		$manager = Plugin\Manager::getInstance();
+		$theme   = $manager->getThemeEnabled();
+		$loaders = array();
+		
+		//create loader for custom theme to overwrite twig templates
+		if($theme && $theme->getPluginName() != \Piwik\Plugin\Manager::DEFAULT_THEME) {
+			$customLoader = $this->getCustomThemeLoader($theme);
+			if ($customLoader) {
+				//make it possible to overwrite plugin templates
+				$this->addCustomPluginNamespaces($customLoader, $theme->getPluginName());
+				$loaders[] = $customLoader;
+			}
+		}
 
-        // If theme != default we need to chain
-        $chainLoader = new Twig_Loader_Chain(array($loader));
+		$loaders[] = $loader;
+        
+        $chainLoader = new Twig_Loader_Chain($loaders);
 
         // Create new Twig Environment and set cache dir
         $templatesCompiledPath = PIWIK_USER_PATH . '/tmp/templates_c';
-        $templatesCompiledPath = SettingsPiwik::rewriteTmpPathWithHostname($templatesCompiledPath);
+        $templatesCompiledPath = SettingsPiwik::rewriteTmpPathWithInstanceId($templatesCompiledPath);
 
         $this->twig = new Twig_Environment($chainLoader,
             array(
@@ -64,8 +78,10 @@ class Twig
         $this->addFilter_sumTime();
         $this->addFilter_money();
         $this->addFilter_truncate();
-        $this->addFilter_notificiation();
+        $this->addFilter_notification();
         $this->addFilter_percentage();
+        $this->addFilter_prettyDate();
+        $this->addFilter_safeDecodeRaw();
         $this->twig->addFilter(new Twig_SimpleFilter('implode', 'implode'));
         $this->twig->addFilter(new Twig_SimpleFilter('ucwords', 'ucwords'));
 
@@ -75,6 +91,8 @@ class Twig
         $this->addFunction_postEvent();
         $this->addFunction_isPluginLoaded();
         $this->addFunction_getJavascriptTranslations();
+
+        $this->twig->addTokenParser(new RenderTokenParser());
     }
 
     protected function addFunction_getJavascriptTranslations()
@@ -117,8 +135,17 @@ class Twig
     protected function addFunction_postEvent()
     {
         $postEventFunction = new Twig_SimpleFunction('postEvent', function ($eventName) {
+            // get parameters to twig function
+            $params = func_get_args();
+            // remove the first value (event name)
+            array_shift($params);
+
+            // make the first value the string that will get output in the template
+            // plugins can modify this string
             $str = '';
-            Piwik::postEvent($eventName, array(&$str));
+            $params = array_merge( array( &$str ), $params);
+
+            Piwik::postEvent($eventName, $params);
             return $str;
         }, array('is_safe' => array('html')));
         $this->twig->addFunction($postEventFunction);
@@ -154,12 +181,28 @@ class Twig
         return $themeLoader;
     }
 
+	/**
+	 * create template loader for a custom theme
+	 * @param \Piwik\Plugin $theme
+	 * @return \Twig_Loader_Filesystem
+	 */
+	protected function getCustomThemeLoader(Plugin $theme){
+		if(!file_exists(sprintf("%s/plugins/%s/templates/", PIWIK_INCLUDE_PATH, $theme->getPluginName()))){
+			return false;
+		}
+		$themeLoader = new Twig_Loader_Filesystem(array(
+                                                       sprintf("%s/plugins/%s/templates/", PIWIK_INCLUDE_PATH, $theme->getPluginName())
+                                                  ));
+
+        return $themeLoader;
+	}
+
     public function getTwigEnvironment()
     {
         return $this->twig;
     }
 
-    protected function addFilter_notificiation()
+    protected function addFilter_notification()
     {
         $twigEnv = $this->getTwigEnvironment();
         $notificationFunction = new Twig_SimpleFilter('notification', function ($message, $options) use ($twigEnv) {
@@ -188,6 +231,25 @@ class Twig
         $this->twig->addFilter($notificationFunction);
     }
 
+    protected function addFilter_safeDecodeRaw()
+    {
+        $rawSafeDecoded = new Twig_SimpleFilter('rawSafeDecoded', function ($string) {
+            $string = str_replace('+', '%2B', $string);
+
+            return SafeDecodeLabel::decodeLabelSafe($string);
+
+        }, array('is_safe' => array('all')));
+        $this->twig->addFilter($rawSafeDecoded);
+    }
+
+    protected function addFilter_prettyDate()
+    {
+        $prettyDate = new Twig_SimpleFilter('prettyDate', function ($dateString, $period) {
+            return Range::factory($period, $dateString)->getLocalizedShortString();
+        });
+        $this->twig->addFilter($prettyDate);
+    }
+
     protected function addFilter_percentage()
     {
         $percentage = new Twig_SimpleFilter('percentage', function ($string, $totalValue, $precision = 1) {
@@ -262,7 +324,7 @@ class Twig
 
     private function addPluginNamespaces(Twig_Loader_Filesystem $loader)
     {
-        $plugins = \Piwik\Plugin\Manager::getInstance()->getLoadedPluginsName();
+        $plugins = \Piwik\Plugin\Manager::getInstance()->getAllPluginsNames();
         foreach ($plugins as $name) {
             $path = sprintf("%s/plugins/%s/templates/", PIWIK_INCLUDE_PATH, $name);
             if (is_dir($path)) {
@@ -271,6 +333,22 @@ class Twig
         }
     }
 
+	/**
+	*
+	* Plugin-Templates can be overwritten by putting identically named templates in plugins/[theme]/templates/plugins/[plugin]/
+	*
+	*/
+	private function addCustomPluginNamespaces(Twig_Loader_Filesystem $loader, $pluginName)
+    {
+        $plugins = \Piwik\Plugin\Manager::getInstance()->getAllPluginsNames();
+        foreach ($plugins as $name) {
+            $path = sprintf("%s/plugins/%s/templates/plugins/%s/", PIWIK_INCLUDE_PATH, $pluginName, $name);
+            if (is_dir($path)) {
+                $loader->addPath(PIWIK_INCLUDE_PATH . '/plugins/' . $pluginName . '/templates/plugins/'. $name , $name);
+            }
+        }
+    }
+
     /**
      * Prepend relative paths with absolute Piwik path
      *
