@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 
 namespace Piwik\ViewDataTable;
@@ -77,8 +75,6 @@ use Piwik\Plugins\API\API;
  *         }
  *     }
  *
- * @package Piwik
- * @subpackage Piwik_Visualization
  * @api
  */
 class Config
@@ -163,6 +159,11 @@ class Config
      */
     public $show_goals = false;
 
+    /**
+     * Controls whether the 'insights' footer icon is shown.
+     */
+    public $show_insights = true;
+
     /**
      * Array property mapping DataTable column names with their internationalized names.
      *
@@ -233,6 +234,12 @@ class Config
      */
     public $related_reports = array();
 
+    /**
+     * "Related Reports" is displayed by default before listing the Related reports,
+     * The string can be changed.
+     */
+    public $related_reports_title;
+
     /**
      * The report title. Used with related reports so report headings can be changed when switching
      * reports.
@@ -559,8 +566,11 @@ class Config
         list($module, $action) = explode('.', $relatedReport);
 
         // don't add the related report if it references this report
-        if ($this->controllerName == $module && $this->controllerAction == $action) {
-            return;
+        if ($this->controllerName == $module
+            && $this->controllerAction == $action) {
+            if(empty($queryParams)) {
+                return;
+            }
         }
 
         $url = ApiRequest::getBaseReportUrl($module, $action, $queryParams);
@@ -625,4 +635,4 @@ class Config
             $this->addTranslation($key, $translation);
         }
     }
-}
\ No newline at end of file
+}
