@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 
 /**
@@ -46,7 +44,14 @@ if ($minimumPhpInvalid) {
 					To enjoy Piwik, you need remove <pre>ini_set</pre> from your <pre>disable_functions</pre> directive in php.ini, and restart your webserver.</p>";
     }
 
-    if (!file_exists(PIWIK_INCLUDE_PATH . '/vendor/autoload.php') && !file_exists(PIWIK_INCLUDE_PATH . '/../../autoload.php')) {
+    if (!function_exists('json_encode')) {
+        $piwik_errorMessage .= "<p><strong>Piwik requires the php5-json extension which provides the functions <code>json_encode()</code> and <code>json_decode()</code></strong></p>
+					<p>It appears your PHP has not yet installed the php5-json extension.
+					To use Piwik, please ask your web host to install php5-json or install it yourself, for example on debian system: <code>sudo apt-get install php5-json</code>. <br/>Then restart your webserver and refresh this page.</p>";
+    }
+
+    if (!file_exists(PIWIK_INCLUDE_PATH . '/vendor/autoload.php')
+        && !file_exists(PIWIK_INCLUDE_PATH . '/../../autoload.php')) {
         $composerInstall = "In the piwik directory, run in the command line the following (eg. via ssh): \n\n"
             . "<pre> curl -sS https://getcomposer.org/installer | php \n\n php composer.phar install\n\n</pre> ";
         if (DIRECTORY_SEPARATOR === '\\' /* ::isWindows() */) {
@@ -57,11 +62,14 @@ if ($minimumPhpInvalid) {
                     "<br/>" . $composerInstall.
                     " This will initialize composer for Piwik and download libraries we use in vendor/* directory.".
                     "\n\n<br/><br/>Then reload this page to access your analytics reports." .
+                    "\n\n<br/><br/>For more information check out this FAQ: <a href='http://piwik.org/faq/how-to-install/faq_18271/' target='_blank'>How do I use Piwik from the Git repository?</a>." .
                     "\n\n<br/><br/>Note: if for some reasons you cannot install composer, instead install the latest Piwik release from ".
-                    "<a href='http://builds.piwik.org/latest.zip'>builds.piwik.org</a>.</p>";
+                    "<a href='http://builds.piwik.org/piwik.zip'>builds.piwik.org</a>.</p>";
     }
 }
 
+define('PAGE_TITLE_WHEN_ERROR', 'Piwik &rsaquo; Error');
+
 if (!function_exists('Piwik_ExitWithMessage')) {
     /**
      * Returns true if Piwik should print the backtrace with error messages.
@@ -73,7 +81,7 @@ if (!function_exists('Piwik_ExitWithMessage')) {
     function Piwik_ShouldPrintBackTraceWithMessage()
     {
         $bool = (defined('PIWIK_PRINT_ERROR_BACKTRACE') && PIWIK_PRINT_ERROR_BACKTRACE)
-            || (defined('PIWIK_TRACKER_DEBUG') && PIWIK_TRACKER_DEBUG);
+                || !empty($GLOBALS['PIWIK_TRACKER_DEBUG']);
         return $bool;
     }
 
@@ -102,12 +110,12 @@ if (!function_exists('Piwik_ExitWithMessage')) {
                             </ul>';
         }
         if ($optionalLinkBack) {
-            $optionalLinkBack = '<a href="javascript:window.back();">Go Back</a><br/>';
+            $optionalLinkBack = '<a href="javascript:window.history.back();">Go Back</a><br/>';
         }
-        $headerPage = file_get_contents(PIWIK_INCLUDE_PATH . '/plugins/Zeitgeist/templates/simpleLayoutHeader.tpl');
-        $footerPage = file_get_contents(PIWIK_INCLUDE_PATH . '/plugins/Zeitgeist/templates/simpleLayoutFooter.tpl');
+        $headerPage = file_get_contents(PIWIK_INCLUDE_PATH . '/plugins/Morpheus/templates/simpleLayoutHeader.tpl');
+        $footerPage = file_get_contents(PIWIK_INCLUDE_PATH . '/plugins/Morpheus/templates/simpleLayoutFooter.tpl');
 
-        $headerPage = str_replace('{$HTML_TITLE}', 'Piwik &rsaquo; Error', $headerPage);
+        $headerPage = str_replace('{$HTML_TITLE}', PAGE_TITLE_WHEN_ERROR, $headerPage);
 
         $content = '<p>' . $message . '</p>
                     <p>'
@@ -126,7 +134,7 @@ if (!function_exists('Piwik_ExitWithMessage')) {
             echo $headerPage . $content . $footerPage;
         }
         echo "\n";
-        exit;
+        exit(1);
     }
 }
 
