@@ -127,7 +127,11 @@ if (in_array('mysqli', @get_loaded_extensions()) && !function_exists('mysqli_set
 if(function_exists('parse_ini_file')) {
 	// provide a wrapper
 	function _parse_ini_file($filename, $process_sections = false) {
-		return file_exists($filename) ? parse_ini_file($filename, $process_sections) : false;
+		if(!file_exists($filename)) {
+            return false;
+        }
+
+        return parse_ini_file($filename, $process_sections);
 	}
 } else {
 	// we can't redefine parse_ini_file() if it has been disabled
@@ -608,26 +612,33 @@ function safe_unserialize( $str )
  * @param resource $context
  * @return int the number of bytes read from the file, or false if an error occurs
  */
-function _readfile($filename, $useIncludePath = false, $context = null)
+function _readfile($filename, $byteStart, $byteEnd, $useIncludePath = false, $context = null)
 {
 	$count = @filesize($filename);
 
 	// built-in function has a 2 MB limit when using mmap
-	if (function_exists('readfile') && $count <= (2 * 1024 * 1024)) {
+	if (function_exists('readfile')
+        && $count <= (2 * 1024 * 1024)
+        && $byteStart == 0
+        && $byteEnd == $count
+    ) {
 		return @readfile($filename, $useIncludePath, $context);
 	}
 
 	// when in doubt (or when readfile() function is disabled)
 	$handle = @fopen($filename, SettingsServer::isWindows() ? "rb" : "r");
 	if ($handle) {
-		while(!feof($handle)) {
-			echo fread($handle, 8192);
+        fseek($handle, $byteStart);
+
+        for ($pos = $byteStart; $pos < $byteEnd && !feof($handle); $pos = ftell($handle)) {
+			echo fread($handle, min(8192, $byteEnd - $pos));
+
 			ob_flush();
 			flush();
 		}
 
 		fclose($handle);
-		return $count;
+		return $byteEnd - $byteStart;
 	}
 	return false;
 }
