@@ -1,24 +1,25 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package Piwik_API
  */
 namespace Piwik\Plugins\API;
 
 use Piwik\API\Proxy;
 use Piwik\API\Request;
 use Piwik\Config;
+use Piwik\DataTable;
 use Piwik\DataTable\Filter\ColumnDelete;
 use Piwik\DataTable\Row;
-use Piwik\DataTable;
 use Piwik\Date;
+use Piwik\IP;
 use Piwik\Menu\MenuTop;
 use Piwik\Metrics;
+use Piwik\Period;
+use Piwik\Period\Range;
 use Piwik\Piwik;
 use Piwik\Plugins\CoreAdminHome\CustomLogo;
 use Piwik\Tracker\GoalManager;
@@ -43,7 +44,6 @@ require_once PIWIK_INCLUDE_PATH . '/core/Config.php';
  * The Metadata API is for example used by the Piwik Mobile App to automatically display all Piwik reports, with translated report & columns names and nicely formatted values.
  * More information on the <a href='http://piwik.org/docs/analytics-api/metadata/' target='_blank'>Metadata API documentation page</a>
  *
- * @package Piwik_API
  * @method static \Piwik\Plugins\API\API getInstance()
  */
 class API extends \Piwik\Plugin\API
@@ -58,6 +58,18 @@ class API extends \Piwik\Plugin\API
         return Version::VERSION;
     }
 
+    /**
+     * Returns the most accurate IP address availble for the current user, in
+     * IPv4 format. This could be the proxy client's IP address.
+     *
+     * @return string IP address in presentation format.
+     */
+    public function getIpFromHeader()
+    {
+        Piwik::checkUserHasSomeViewAccess();
+        return IP::getIpFromHeader();
+    }
+
     /**
      * Returns the section [APISettings] if defined in config.ini.php
      * @return array
@@ -532,6 +544,13 @@ class API extends \Piwik\Plugin\API
             $language, $idGoal, $legendAppendMetric, $labelUseAbsoluteUrl);
     }
 
+    public function getLastDate($date, $period)
+    {
+        $lastDate = Range::getLastDate($date, $period);
+
+        return array_shift($lastDate);
+    }
+
     /**
      * Performs multiple API requests at once and returns every result.
      *
@@ -564,7 +583,11 @@ class API extends \Piwik\Plugin\API
      */
     public function getSuggestedValuesForSegment($segmentName, $idSite)
     {
+        if(empty(Config::getInstance()->General['enable_segment_suggested_values'])) {
+            return array();
+        }
         Piwik::checkUserHasViewAccess($idSite);
+
         $maxSuggestionsToReturn = 30;
         $segmentsMetadata = $this->getSegmentsMetadata($idSite, $_hideImplementationData = false);
 
@@ -579,7 +602,12 @@ class API extends \Piwik\Plugin\API
             throw new \Exception("Requested segment not found.");
         }
 
-            $startDate = Date::now()->subDay(60)->toString();
+        // if period=range is disabled, do not proceed
+        if(!Period\Factory::isPeriodEnabledForAPI('range')) {
+            return array();
+        }
+
+        $startDate = Date::now()->subDay(60)->toString();
         $requestLastVisits = "method=Live.getLastVisitsDetails
         &idSite=$idSite
         &period=range
@@ -594,10 +622,10 @@ class API extends \Piwik\Plugin\API
 
         // By default Live fetches all actions for all visitors, but we'd rather do this only when required
         if ($this->doesSegmentNeedActionsData($segmentName)) {
-            $requestLastVisits .= "&filter_limit=500";
+            $requestLastVisits .= "&filter_limit=400";
         } else {
             $requestLastVisits .= "&doNotFetchActions=1";
-            $requestLastVisits .= "&filter_limit=1000";
+            $requestLastVisits .= "&filter_limit=800";
         }
 
         $request = new Request($requestLastVisits);
@@ -613,17 +641,12 @@ class API extends \Piwik\Plugin\API
         $valuesBis = $table->getColumnsStartingWith($segmentName . ColumnDelete::APPEND_TO_COLUMN_NAME_TO_KEEP);
         $values = array_merge($values, $valuesBis);
 
-        // remove false values (while keeping zeros)
-        $values = array_filter($values, 'strlen');
+        $values = $this->getMostFrequentValues($values);
 
-        // we have a list of all values. let's show the most frequently used first.
-        $values = array_count_values($values);
-        arsort($values);
-        $values = array_keys($values);
+        $values = array_slice($values, 0, $maxSuggestionsToReturn);
 
         $values = array_map(array('Piwik\Common', 'unsanitizeInputValue'), $values);
 
-        $values = array_slice($values, 0, $maxSuggestionsToReturn);
         return $values;
     }
 
@@ -642,10 +665,33 @@ class API extends \Piwik\Plugin\API
         $doesSegmentNeedActionsInfo = in_array($segmentName, $segmentsNeedActionsInfo) || $isCustomVariablePage || $isEventSegment;
         return $doesSegmentNeedActionsInfo;
     }
+
+    /**
+     * @param $values
+     * @param $value
+     * @return array
+     */
+    private function getMostFrequentValues($values)
+    {
+        // remove false values (while keeping zeros)
+        $values = array_filter($values, 'strlen');
+
+        // array_count_values requires strings or integer, convert floats to string (mysqli)
+        foreach ($values as &$value) {
+            if (is_numeric($value)) {
+                $value = (string)round($value, 3);
+            }
+        }
+        // we have a list of all values. let's show the most frequently used first.
+        $values = array_count_values($values);
+
+        arsort($values);
+        $values = array_keys($values);
+        return $values;
+    }
 }
 
 /**
- * @package Piwik_API
  */
 class Plugin extends \Piwik\Plugin
 {
@@ -656,40 +702,17 @@ class Plugin extends \Piwik\Plugin
     }
 
     /**
-     * @see Piwik_Plugin::getListHooksRegistered
+     * @see Piwik\Plugin::getListHooksRegistered
      */
     public function getListHooksRegistered()
     {
         return array(
-            'AssetManager.getStylesheetFiles' => 'getStylesheetFiles',
-            'Menu.Top.addItems'               => 'addTopMenu',
+            'AssetManager.getStylesheetFiles' => 'getStylesheetFiles'
         );
     }
 
-    public function addTopMenu()
-    {
-        $apiUrlParams = array('module' => 'API', 'action' => 'listAllAPI', 'segment' => false);
-        $tooltip = Piwik::translate('API_TopLinkTooltip');
-
-        MenuTop::addEntry('General_API', $apiUrlParams, true, 7, $isHTML = false, $tooltip);
-
-        $this->addTopMenuMobileApp();
-    }
-
-    protected function addTopMenuMobileApp()
-    {
-        if (empty($_SERVER['HTTP_USER_AGENT'])) {
-            return;
-        }
-        require_once PIWIK_INCLUDE_PATH . '/libs/UserAgentParser/UserAgentParser.php';
-        $os = \UserAgentParser::getOperatingSystem($_SERVER['HTTP_USER_AGENT']);
-        if ($os && in_array($os['id'], array('AND', 'IPD', 'IPA', 'IPH'))) {
-            MenuTop::addEntry('Piwik Mobile App', array('module' => 'Proxy', 'action' => 'redirect', 'url' => 'http://piwik.org/mobile/'), true, 4);
-        }
-    }
-
     public function getStylesheetFiles(&$stylesheets)
     {
         $stylesheets[] = "plugins/API/stylesheets/listAllAPI.less";
     }
-}
\ No newline at end of file
+}
