@@ -1,21 +1,18 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package Actions
  */
 namespace Piwik\Plugins\Actions;
 
 use Exception;
+use Piwik\API\Request;
 use Piwik\Archive;
-
 use Piwik\Common;
 use Piwik\DataTable;
-
 use Piwik\Date;
 use Piwik\Metrics;
 use Piwik\Piwik;
@@ -36,7 +33,6 @@ use Piwik\Tracker\PageUrl;
  * and an outlink via "getOutlink".
  *
  * Note: pageName, pageUrl, outlinkUrl, downloadUrl parameters must be URL encoded before you call the API.
- * @package Actions
  * @method static \Piwik\Plugins\Actions\API getInstance()
  */
 class API extends \Piwik\Plugin\API
@@ -122,8 +118,7 @@ class API extends \Piwik\Plugin\API
     public function getPageUrls($idSite, $period, $date, $segment = false, $expanded = false, $idSubtable = false,
                                 $depth = false)
     {
-        $dataTable = Archive::getDataTableFromArchive(
-            'Actions_actions_url', $idSite, $period, $date, $segment, $expanded, $idSubtable, $depth);
+        $dataTable = $this->getDataTableFromArchive('Actions_actions_url', $idSite, $period, $date, $segment, $expanded, $idSubtable, $depth);
         $this->filterPageDatatable($dataTable);
         $this->filterActionsDataTable($dataTable, $expanded);
         return $dataTable;
@@ -170,11 +165,11 @@ class API extends \Piwik\Plugin\API
     {
         // Keep only pages which are following site search
         $dataTable->filter('ColumnCallbackDeleteRow', array(
-                                                           'nb_hits_following_search',
-                                                           function ($value) {
-                                                               return $value <= 0;
-                                                           }
-                                                      ));
+            'nb_hits_following_search',
+            function ($value) {
+                return $value <= 0;
+            }
+        ));
     }
 
     /**
@@ -210,7 +205,7 @@ class API extends \Piwik\Plugin\API
 
     public function getPageTitles($idSite, $period, $date, $segment = false, $expanded = false, $idSubtable = false)
     {
-        $dataTable = Archive::getDataTableFromArchive('Actions_actions', $idSite, $period, $date, $segment, $expanded, $idSubtable);
+        $dataTable = $this->getDataTableFromArchive('Actions_actions', $idSite, $period, $date, $segment, $expanded, $idSubtable);
         $this->filterPageDatatable($dataTable);
         $this->filterActionsDataTable($dataTable, $expanded);
         return $dataTable;
@@ -251,7 +246,7 @@ class API extends \Piwik\Plugin\API
 
     public function getDownloads($idSite, $period, $date, $segment = false, $expanded = false, $idSubtable = false)
     {
-        $dataTable = Archive::getDataTableFromArchive('Actions_downloads', $idSite, $period, $date, $segment, $expanded, $idSubtable);
+        $dataTable = $this->getDataTableFromArchive('Actions_downloads', $idSite, $period, $date, $segment, $expanded, $idSubtable);
         $this->filterActionsDataTable($dataTable, $expanded);
         return $dataTable;
     }
@@ -266,7 +261,7 @@ class API extends \Piwik\Plugin\API
 
     public function getOutlinks($idSite, $period, $date, $segment = false, $expanded = false, $idSubtable = false)
     {
-        $dataTable = Archive::getDataTableFromArchive('Actions_outlink', $idSite, $period, $date, $segment, $expanded, $idSubtable);
+        $dataTable = $this->getDataTableFromArchive('Actions_outlink', $idSite, $period, $date, $segment, $expanded, $idSubtable);
         $this->filterActionsDataTable($dataTable, $expanded);
         return $dataTable;
     }
@@ -302,7 +297,7 @@ class API extends \Piwik\Plugin\API
 
     protected function getSiteSearchKeywordsRaw($idSite, $period, $date, $segment)
     {
-        $dataTable = Archive::getDataTableFromArchive('Actions_sitesearch', $idSite, $period, $date, $segment, $expanded = false);
+        $dataTable = $this->getDataTableFromArchive('Actions_sitesearch', $idSite, $period, $date, $segment, $expanded = false);
         return $dataTable;
     }
 
@@ -312,10 +307,10 @@ class API extends \Piwik\Plugin\API
         // Delete all rows that have some results
         $dataTable->filter('ColumnCallbackDeleteRow',
             array(
-                 Metrics::INDEX_SITE_SEARCH_HAS_NO_RESULT,
-                 function ($value) {
-                     return $value < 1;
-                 }
+                Metrics::INDEX_SITE_SEARCH_HAS_NO_RESULT,
+                function ($value) {
+                    return $value < 1;
+                }
             ));
         $dataTable->deleteRow(DataTable::ID_SUMMARY_ROW);
         $dataTable->deleteColumn(Metrics::INDEX_SITE_SEARCH_HAS_NO_RESULT);
@@ -399,7 +394,7 @@ class API extends \Piwik\Plugin\API
 
         if ($table === false) {
             // fetch the data table
-            $table = call_user_func_array(array('Piwik\Archive', 'getDataTableFromArchive'), $callBackParameters);
+            $table = call_user_func_array(array($this, 'getDataTableFromArchive'), $callBackParameters);
 
             if ($table instanceof DataTable\Map) {
                 // search an array of tables, e.g. when using date=last30
@@ -463,7 +458,16 @@ class API extends \Piwik\Plugin\API
             // match found on this level and more levels remaining: go deeper
             $idSubTable = $row->getIdSubDataTable();
             $callBackParameters[6] = $idSubTable;
-            $table = call_user_func_array(array('Piwik\Archive', 'getDataTableFromArchive'), $callBackParameters);
+
+            /**
+             * @var \Piwik\Period $period
+             */
+            $period = $table->getMetadata('period');
+            if (!empty($period)) {
+                $callBackParameters[3] = $period->getDateStart() . ',' . $period->getDateEnd();
+            }
+
+            $table = call_user_func_array(array($this, 'getDataTableFromArchive'), $callBackParameters);
             return $this->doFilterPageDatatableSearch($callBackParameters, $table, $searchTree);
         }
 
@@ -481,20 +485,39 @@ class API extends \Piwik\Plugin\API
         $dataTable->queueFilter('ColumnDelete', array($columnsToRemove));
 
         // Average time on page = total time on page / number visits on that page
-        $dataTable->queueFilter('ColumnCallbackAddColumnQuotient', array('avg_time_on_page', 'sum_time_spent', 'nb_visits', 0));
+        $dataTable->queueFilter('ColumnCallbackAddColumnQuotient',
+            array('avg_time_on_page',
+                  'sum_time_spent',
+                  'nb_visits',
+                  0)
+        );
 
         // Bounce rate = single page visits on this page / visits started on this page
-        $dataTable->queueFilter('ColumnCallbackAddColumnPercentage', array('bounce_rate', 'entry_bounce_count', 'entry_nb_visits', 0));
+        $dataTable->queueFilter('ColumnCallbackAddColumnPercentage',
+            array('bounce_rate',
+                  'entry_bounce_count',
+                  'entry_nb_visits',
+                  0));
 
         // % Exit = Number of visits that finished on this page / visits on this page
-        $dataTable->queueFilter('ColumnCallbackAddColumnPercentage', array('exit_rate', 'exit_nb_visits', 'nb_visits', 0));
+        $dataTable->queueFilter('ColumnCallbackAddColumnPercentage',
+            array('exit_rate',
+                  'exit_nb_visits',
+                  'nb_visits',
+                  0)
+        );
 
         // Handle performance analytics
         $hasTimeGeneration = (array_sum($dataTable->getColumn(Metrics::INDEX_PAGE_SUM_TIME_GENERATION)) > 0);
         if ($hasTimeGeneration) {
             // Average generation time = total generation time / number of pageviews
             $precisionAvgTimeGeneration = 3;
-            $dataTable->queueFilter('ColumnCallbackAddColumnQuotient', array('avg_time_generation', 'sum_time_generation', 'nb_hits_with_time_generation', $precisionAvgTimeGeneration));
+            $dataTable->queueFilter('ColumnCallbackAddColumnQuotient',
+                array('avg_time_generation',
+                      'sum_time_generation',
+                      'nb_hits_with_time_generation',
+                      $precisionAvgTimeGeneration)
+            );
             $dataTable->queueFilter('ColumnDelete', array(array('sum_time_generation')));
         } else {
             // No generation time: remove it from the API output and add it to empty_columns metadata, so that
@@ -543,7 +566,13 @@ class API extends \Piwik\Plugin\API
      */
     private function filterNonEntryActions($dataTable)
     {
-        $dataTable->filter('ColumnCallbackDeleteRow', array('entry_nb_visits', function ($visits) { return !strlen($visits); }));
+        $dataTable->filter('ColumnCallbackDeleteRow',
+            array('entry_nb_visits',
+                  function ($visits) {
+                      return !strlen($visits);
+                  }
+            )
+        );
     }
 
     /**
@@ -553,6 +582,24 @@ class API extends \Piwik\Plugin\API
      */
     private function filterNonExitActions($dataTable)
     {
-        $dataTable->filter('ColumnCallbackDeleteRow', array('exit_nb_visits', function ($visits) { return !strlen($visits); }));
+        $dataTable->filter('ColumnCallbackDeleteRow',
+            array('exit_nb_visits',
+                  function ($visits) {
+                      return !strlen($visits);
+                  })
+        );
+    }
+
+    protected function getDataTableFromArchive($name, $idSite, $period, $date, $segment, $expanded = false, $idSubtable = null, $depth = null)
+    {
+        $skipAggregationOfSubTables = false;
+        if ($period == 'range'
+            && empty($idSubtable)
+            && empty($expanded)
+            && !Request::shouldLoadFlatten()
+        ) {
+            $skipAggregationOfSubTables = false;
+        }
+        return Archive::getDataTableFromArchive($name, $idSite, $period, $date, $segment, $expanded, $idSubtable, $skipAggregationOfSubTables, $depth);
     }
 }
