@@ -1,22 +1,20 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package CoreConsole
  */
 
 namespace Piwik\Plugins\CoreConsole\Commands;
 
 use Piwik\Plugin\ConsoleCommand;
+use Piwik\SettingsPiwik;
 use Symfony\Component\Console\Input\InputInterface;
 use Symfony\Component\Console\Output\OutputInterface;
 
 /**
- * @package CoreConsole
  */
 class WatchLog extends ConsoleCommand
 {
@@ -28,7 +26,9 @@ class WatchLog extends ConsoleCommand
 
     protected function execute(InputInterface $input, OutputInterface $output)
     {
-        $cmd = sprintf('tail -f %s/tmp/logs/*.log', PIWIK_DOCUMENT_ROOT);
+        $path = sprintf('%s/tmp/logs/', PIWIK_DOCUMENT_ROOT);
+        $path = SettingsPiwik::rewriteTmpPathWithInstanceId($path);
+        $cmd = sprintf('tail -f %s*.log', $path);
 
         $output->writeln('Executing command: ' . $cmd);
         passthru($cmd);
