@@ -1,5 +1,5 @@
 /*!
- * Piwik - Web Analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
@@ -70,7 +70,7 @@ DataTable.registerFooterIconHandler = function (id, handler) {
  */
 DataTable.getDataTableByReport = function (report) {
     var result = undefined;
-    $('.dataTable').each(function () {
+    $('div.dataTable').each(function () {
         if ($(this).attr('data-report') == report) {
             result = this;
             return false;
@@ -81,6 +81,10 @@ DataTable.getDataTableByReport = function (report) {
 
 $.extend(DataTable.prototype, UIControl.prototype, {
 
+    _init: function (domElem) {
+        // initialize your dataTable in your plugin
+    },
+
     //initialisation function
     init: function () {
         var domElem = this.$element;
@@ -91,6 +95,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         this.loadedSubDataTable = {};
         this.isEmpty = $('.pk-emptyDataTable', domElem).length > 0;
         this.bindEventsAndApplyStyle(domElem);
+        this._init(domElem);
         this.initialized = true;
     },
 
@@ -110,6 +115,13 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         }
         self.param.filter_offset = 0;
         self.param.filter_sort_column = newColumnToSort;
+
+        if (!self.isDashboard()) {
+            self.notifyWidgetParametersChange(domElem, {
+                filter_sort_column: newColumnToSort
+            });
+        }
+
         self.reloadAjaxDataTable();
     },
 
@@ -117,6 +129,14 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         this.param.columns = columnName;
     },
 
+    isWithinDialog: function (domElem) {
+        return !!$(domElem).parents('.ui-dialog').length;
+    },
+
+    isDashboard: function () {
+        return !!$('#dashboardWidgetsArea').length;
+    },
+
     //Reset DataTable filters (used before a reload or view change)
     resetAllFilters: function () {
         var self = this;
@@ -216,7 +236,6 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         ajaxRequest.setFormat('html');
 
         ajaxRequest.send(false);
-
     },
 
     // Function called when the AJAX request is successful
@@ -228,10 +247,6 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         var idToReplace = workingDivId || $(content).attr('id');
         var dataTableSel = $('#' + idToReplace);
 
-        // keep the original list of related reports
-        var oldReportsElem = $('.datatableRelatedReports', dataTableSel);
-        $('.datatableRelatedReports', content).replaceWith(oldReportsElem);
-
         // if the current dataTable is located inside another datatable
         table = $(content).parents('table.dataTable');
         if (dataTableSel.parents('.dataTable').is('table')) {
@@ -247,6 +262,8 @@ $.extend(DataTable.prototype, UIControl.prototype, {
             dataTableSel.replaceWith(content);
         }
 
+        content.trigger('piwik:dataTableLoaded');
+
         piwikHelper.lazyScrollTo(content[0], 400);
 
         return content;
@@ -260,7 +277,6 @@ $.extend(DataTable.prototype, UIControl.prototype, {
      - such as column sorting, searching in the rows, displaying Next / Previous links, etc.
      - add styles to the cells and rows (odd / even styles)
      - modify some rows to add images if a span img is found, or add a link if a span urlLink is found
-     or truncate the labels when they are too big
      - bind new events onclick / hover / etc. to trigger AJAX requests,
      nice hovertip boxes for truncated cells
      */
@@ -278,16 +294,163 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         self.handleSubDataTable(domElem);
         self.handleConfigurationBox(domElem);
         self.handleColumnDocumentation(domElem);
-        self.handleReportDocumentation(domElem);
         self.handleRowActions(domElem);
 		self.handleCellTooltips(domElem);
         self.handleRelatedReports(domElem);
         self.handleTriggeredEvents(domElem);
         self.handleColumnHighlighting(domElem);
+        self.handleExpandFooter(domElem);
+        self.setFixWidthToMakeEllipsisWork(domElem);
+    },
+
+    setFixWidthToMakeEllipsisWork: function (domElem) {
+        var self = this;
+
+        function isWidgetized()
+        {
+            return -1 !== location.search.indexOf('module=Widgetize');
+        }
+
+        function getTableWidth(domElem)
+        {
+            var totalWidth      = $(domElem).width();
+            var totalWidthTable = $('table.dataTable', domElem).width(); // fixes tables in dbstats, referrers, ...
+
+            if (totalWidthTable < totalWidth) {
+                totalWidth = totalWidthTable;
+            }
+
+            if (!totalWidth) {
+                totalWidth = 0;
+            }
+
+            return parseInt(totalWidth, 10);
+        }
+
+        function setMaxTableWidthIfNeeded (domElem, maxTableWidth)
+        {
+            var tableWidth = getTableWidth(domElem);
+
+            if (tableWidth <= maxTableWidth) {
+                return;
+            }
+
+            if (isWidgetized() || self.isDashboard()) {
+                return;
+            }
+
+            $(domElem).width(maxTableWidth);
+
+            var parentDataTable = $(domElem).parent('.dataTable');
+            if (parentDataTable && parentDataTable.length) {
+                // makes sure dataTableWrapper and DataTable has same size => makes sure maxLabelWidth does not get
+                // applied in getLabelWidth() since they will have the same size.
+                parentDataTable.width(maxTableWidth);
+            }
+        }
+
+        function getLabelWidth(domElem, tableWidth, minLabelWidth, maxLabelWidth)
+        {
+            var labelWidth = minLabelWidth;
+
+            var columnsInFirstRow = $('tr:nth-child(1) td:not(.label)', domElem);
+
+            var widthOfAllColumns = 0;
+            columnsInFirstRow.each(function (index, column) {
+                widthOfAllColumns += $(column).outerWidth();
+            });
+
+            if (tableWidth - widthOfAllColumns >= minLabelWidth) {
+                labelWidth = tableWidth - widthOfAllColumns;
+            } else if (widthOfAllColumns >= tableWidth) {
+                labelWidth = tableWidth * 0.5;
+            }
+
+            var innerWidth = 0;
+            var innerWrapper = domElem.find('.dataTableWrapper');
+            if (innerWrapper && innerWrapper.length) {
+                innerWidth = innerWrapper.width();
+            }
+
+            if (labelWidth > maxLabelWidth
+                && !isWidgetized()
+                && innerWidth !== domElem.width()
+                && !self.isDashboard()) {
+                labelWidth = maxLabelWidth; // prevent for instance table in Actions-Pages is not too wide
+            }
+
+            return parseInt(labelWidth, 10);
+        }
+
+        function getLabelColumnMinWidth(domElem)
+        {
+            var minWidth = 0;
+            var minWidthHead = $('thead .first.label', domElem).css('minWidth');
+
+            if (minWidthHead) {
+                minWidth = parseInt(minWidthHead, 10);
+            }
+
+            var minWidthBody = $('tbody tr:nth-child(1) td.label', domElem).css('minWidth');
+
+            if (minWidthBody) {
+                minWidthBody = parseInt(minWidthBody, 10);
+                if (minWidthBody && minWidthBody > minWidth) {
+                    minWidth = minWidthBody;
+                }
+            }
+
+            return parseInt(minWidth, 10);
+        }
+
+        function removePaddingFromWidth(domElem, labelWidth) {
+            var maxPaddingLeft  = 0;
+            var maxPaddingRight = 0;
+
+            $('tbody tr td.label', domElem).each(function (i, node) {
+                $node = $(node);
+
+                var paddingLeft  = $node.css('paddingLeft');
+                paddingLeft      = paddingLeft ? Math.round(parseFloat(paddingLeft)) : 0;
+                var paddingRight = $node.css('paddingRight');
+                paddingRight     = paddingRight ? Math.round(parseFloat(paddingLeft)) : 0;
+
+                if (paddingLeft > maxPaddingLeft) {
+                    maxPaddingLeft = paddingLeft;
+                }
+                if (paddingRight > maxPaddingRight) {
+                    maxPaddingRight = paddingRight;
+                }
+            });
+
+            labelWidth = labelWidth - maxPaddingLeft - maxPaddingRight;
+
+            return labelWidth;
+        }
+
+        var minLabelWidth = 125;
+        var maxLabelWidth = 440;
+
+        setMaxTableWidthIfNeeded(domElem, 1200);
+        var tableWidth = getTableWidth(domElem);
+        var labelColumnMinWidth = getLabelColumnMinWidth(domElem);
+        var labelColumnWidth    = getLabelWidth(domElem, tableWidth, 125, 440);
+
+        if (labelColumnMinWidth > labelColumnWidth) {
+            labelColumnWidth = labelColumnMinWidth;
+        }
+
+        labelColumnWidth = removePaddingFromWidth(domElem, labelColumnWidth);
+
+        if (labelColumnWidth) {
+            $('td.label', domElem).width(labelColumnWidth);
+        }
+
+        $('td span.label', domElem).each(function () { self.tooltip($(this)); });
     },
 
     handleLimit: function (domElem) {
-        var tableRowLimits = [5, 10, 25, 50, 100, 250, 500],
+            var tableRowLimits = piwik.config.datatable_row_limits,
             evolutionLimits =
             {
                 day: [30, 60, 90, 180, 365, 500],
@@ -381,24 +544,6 @@ $.extend(DataTable.prototype, UIControl.prototype, {
     handleSort: function (domElem) {
         var self = this;
 
-        function getSortImageSrc() {
-            var imageSortSrc = false;
-            if (currentIsSubDataTable) {
-                if (self.param.filter_sort_order == 'asc') {
-                    imageSortSrc = 'plugins/Zeitgeist/images/sort_subtable_asc.png';
-                } else {
-                    imageSortSrc = 'plugins/Zeitgeist/images/sort_subtable_desc.png';
-                }
-            } else {
-                if (self.param.filter_sort_order == 'asc') {
-                    imageSortSrc = 'plugins/Zeitgeist/images/sortasc.png';
-                } else {
-                    imageSortSrc = 'plugins/Zeitgeist/images/sortdesc.png';
-                }
-            }
-            return imageSortSrc;
-        }
-
         if (self.props.enable_sort) {
             $('.sortable', domElem).off('click.dataTableSort').on('click.dataTableSort',
                 function () {
@@ -411,7 +556,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         if (self.param.filter_sort_column) {
             // are we in a subdatatable?
             var currentIsSubDataTable = $(domElem).parent().hasClass('cellSubDataTable');
-            var imageSortSrc = getSortImageSrc();
+            var imageSortClassType = currentIsSubDataTable ? 'sortSubtable' : ''
             var imageSortWidth = 16;
             var imageSortHeight = 16;
 
@@ -422,7 +567,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
             // adding an image and the class columnSorted to the TD
             $("th#" + self.param.filter_sort_column + ' #thDIV', domElem).parent()
                 .addClass('columnSorted')
-                .prepend('<div class="sortIconContainer sortIconContainer' + ImageSortClass + '"><img class="sortIcon" width="' + imageSortWidth + '" height="' + imageSortHeight + '" src="' + imageSortSrc + '" /></div>');
+                .prepend('<div class="sortIconContainer sortIconContainer' + ImageSortClass + ' ' + imageSortClassType + '"><span class="sortIcon" width="' + imageSortWidth + '" height="' + imageSortHeight + '" /></div>');
         }
     },
 
@@ -498,6 +643,10 @@ $.extend(DataTable.prototype, UIControl.prototype, {
                 }
             }
         );
+
+        if (this.isEmpty && !currentPattern) {
+            $('.dataTableSearchPattern', domElem).hide();
+        }
     },
 
     //behaviour for '< prev' 'next >' links and page count
@@ -519,50 +668,53 @@ $.extend(DataTable.prototype, UIControl.prototype, {
                 if (totalRows != 0) {
                     var str = sprintf(_pk_translate('CoreHome_PageOf'), offset + '-' + offsetEndDisp, totalRows);
                     $(this).text(str);
+                } else {
+                    $(this).hide();
                 }
             }
         );
 
+        var $next = $('.dataTableNext', domElem);
+
         // Display the next link if the total Rows is greater than the current end row
-        $('.dataTableNext', domElem)
-            .each(function () {
-                var offsetEnd = Number(self.param.filter_offset)
-                    + Number(self.param.filter_limit);
-                var totalRows = Number(self.param.totalRows);
-                if (self.param.keep_summary_row == 1) --totalRows;
-                if (offsetEnd < totalRows) {
-                    $(this).css('display', 'inline');
-                }
-            })
-            // bind the click event to trigger the ajax request with the new offset
-            .click(function () {
-                $(this).off('click');
-                self.param.filter_offset = Number(self.param.filter_offset) + Number(self.param.filter_limit);
-                self.reloadAjaxDataTable();
-            })
-        ;
+        $next.each(function () {
+            var offsetEnd = Number(self.param.filter_offset)
+                + Number(self.param.filter_limit);
+            var totalRows = Number(self.param.totalRows);
+            if (self.param.keep_summary_row == 1) --totalRows;
+            if (offsetEnd < totalRows) {
+                $(this).css('display', 'inline');
+            }
+        });
+        // bind the click event to trigger the ajax request with the new offset
+        $next.off('click');
+        $next.click(function () {
+            $(this).off('click');
+            self.param.filter_offset = Number(self.param.filter_offset) + Number(self.param.filter_limit);
+            self.reloadAjaxDataTable();
+        });
+
+        var $prev = $('.dataTablePrevious', domElem);
 
         // Display the previous link if the current offset is not zero
-        $('.dataTablePrevious', domElem)
-            .each(function () {
-                var offset = 1 + Number(self.param.filter_offset);
-                if (offset != 1) {
-                    $(this).css('display', 'inline');
-                }
+        $prev.each(function () {
+            var offset = 1 + Number(self.param.filter_offset);
+            if (offset != 1) {
+                $(this).css('display', 'inline');
             }
-        )
-            // bind the click event to trigger the ajax request with the new offset
-            // take care of the negative offset, we setup 0
-            .click(
-            function () {
-                $(this).off('click');
-                var offset = Number(self.param.filter_offset) - Number(self.param.filter_limit);
-                if (offset < 0) { offset = 0; }
-                self.param.filter_offset = offset;
-                self.param.previous = 1;
-                self.reloadAjaxDataTable();
-            }
-        );
+        });
+
+        // bind the click event to trigger the ajax request with the new offset
+        // take care of the negative offset, we setup 0
+        $prev.off('click');
+        $prev.click(function () {
+            $(this).off('click');
+            var offset = Number(self.param.filter_offset) - Number(self.param.filter_limit);
+            if (offset < 0) { offset = 0; }
+            self.param.filter_offset = offset;
+            self.param.previous = 1;
+            self.reloadAjaxDataTable();
+        });
     },
 
     handleEvolutionAnnotations: function (domElem) {
@@ -571,6 +723,9 @@ $.extend(DataTable.prototype, UIControl.prototype, {
             && $('.annotationView', domElem).length > 0) {
             // get dates w/ annotations across evolution period (have to do it through AJAX since we
             // determine placement using the elements created by jqplot)
+
+            $('.dataTableFeatures', domElem).addClass('hasEvolution');
+
             piwik.annotations.api.getEvolutionIcons(
                 self.param.idSite,
                 self.param.date,
@@ -583,16 +738,18 @@ $.extend(DataTable.prototype, UIControl.prototype, {
                         annotationAxisHeight = 30 // css height + padding + margin
                         ;
 
+                    var annotationsCss = {left: 6}; // padding-left of .jqplot-graph element (in _dataTableViz_jqplotGraph.tpl)
+                    if (self.isWithinDialog(domElem)) {
+                        annotationsCss['top'] = -datatableFeatures.height() - annotationAxisHeight + noteSize / 2;
+                    }
+
                     // set position of evolution annotation icons
-                    annotations.css({
-                        top: -datatableFeatures.height() - annotationAxisHeight + noteSize / 2,
-                        left: 6 // padding-left of .jqplot-graph element (in _dataTableViz_jqplotGraph.tpl)
-                    });
+                    annotations.css(annotationsCss);
 
                     piwik.annotations.placeEvolutionIcons(annotations, domElem);
 
                     // add new section under axis
-                    datatableFeatures.append(annotations);
+                    annotations.insertAfter($('.datatableRelatedReports', domElem));
 
                     // reposition annotation icons every time the graph is resized
                     $('.piwik-graph', domElem).on('resizeGraph', function () {
@@ -600,18 +757,19 @@ $.extend(DataTable.prototype, UIControl.prototype, {
                     });
 
                     // on hover of x-axis, show note icon over correct part of x-axis
-                    $('span', annotations).hover(
-                        function () { $(this).css('opacity', 1); },
-                        function () {
-                            if ($(this).attr('data-count') == 0) // only hide if there are no annotations for this note
-                            {
-                                $(this).css('opacity', 0);
-                            }
+                    datatableFeatures.on('mouseenter', '.evolution-annotations>span', function () {
+                        $(this).css('opacity', 1);
+                    });
+
+                    datatableFeatures.on('mouseleave', '.evolution-annotations>span', function () {
+                        if ($(this).attr('data-count') == 0) // only hide if there are no annotations for this note
+                        {
+                            $(this).css('opacity', 0);
                         }
-                    );
+                    });
 
                     // when clicking an annotation, show the annotation viewer for that period
-                    $('span', annotations).click(function () {
+                    datatableFeatures.on('click', '.evolution-annotations>span', function () {
                         var spanSelf = $(this),
                             date = spanSelf.attr('data-date'),
                             oldDate = $('.annotation-manager', domElem).attr('data-date');
@@ -691,6 +849,8 @@ $.extend(DataTable.prototype, UIControl.prototype, {
                     domElem.on('mouseleave', '.annotations', function (e) {
                         runningAnimation = null;
                     });
+
+                    self.$element.trigger('piwik:annotationsLoaded');
                 }
             );
         }
@@ -848,8 +1008,9 @@ $.extend(DataTable.prototype, UIControl.prototype, {
                     var url = $(this).attr('href') + '&token_auth=' + piwik.token_auth;
 
                     var limit = $('.limitSelection>div>span', domElem).text();
-                    if (!limit || 'undefined' === limit) {
-                        limit = $(this).attr('filter_limit');
+                    var defaultLimit = $(this).attr('filter_limit');
+                    if (!limit || 'undefined' === limit || defaultLimit == -1) {
+                        limit = defaultLimit;
                     }
                     url += '&filter_limit=' + limit;
 
@@ -872,11 +1033,17 @@ $.extend(DataTable.prototype, UIControl.prototype, {
                 }
                 var period = self.param.period;
 
-                // RSS does not work for period=range
-                if (format == 'RSS'
+                var formatsUseDayNotRange = piwik.config.datatable_export_range_as_day.toLowerCase();
+                if (formatsUseDayNotRange.indexOf(format.toLowerCase()) != -1
                     && self.param.period == 'range') {
                     period = 'day';
                 }
+
+                // Below evolution graph, show daily exports
+                if(self.param.period == 'range'
+                    && self.param.viewDataTable == "graphEvolution") {
+                    period = 'day';
+                }
                 var str = 'index.php?module=API'
                     + '&method=' + method
                     + '&format=' + format
@@ -886,11 +1053,18 @@ $.extend(DataTable.prototype, UIControl.prototype, {
                     + ( typeof self.param.filter_pattern != "undefined" ? '&filter_pattern=' + self.param.filter_pattern : '')
                     + ( typeof self.param.filter_pattern_recursive != "undefined" ? '&filter_pattern_recursive=' + self.param.filter_pattern_recursive : '');
 
+
                 if (typeof self.param.flat != "undefined") {
                     str += '&flat=' + (self.param.flat == 0 ? '0' : '1');
                     if (typeof self.param.include_aggregate_rows != "undefined" && self.param.include_aggregate_rows) {
                         str += '&include_aggregate_rows=1';
                     }
+                    if (!self.param.flat
+                        && typeof self.param.filter_pattern_recursive != "undefined"
+                        && self.param.filter_pattern_recursive) {
+                        str += '&expanded=1';
+                    }
+
                 } else {
                     str += '&expanded=1';
                 }
@@ -946,7 +1120,6 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         }
 
         var ul = $('div.tableConfiguration ul', domElem);
-
         function hideConfigurationIcon() {
             // hide the icon when there are no actions available or we're not in a table view
             $('div.tableConfiguration', domElem).remove();
@@ -980,7 +1153,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         var generateClickCallback = function (paramName, callbackAfterToggle) {
             return function () {
                 close();
-                self.param[paramName] = 1 - self.param[paramName];
+                self.param[paramName] = (1 - self.param[paramName]) + '';
                 self.param.filter_offset = 0;
                 delete self.param.totalRows;
                 if (callbackAfterToggle) callbackAfterToggle();
@@ -1084,55 +1257,54 @@ $.extend(DataTable.prototype, UIControl.prototype, {
     notifyWidgetParametersChange: function (domWidget, parameters) {
         var widget = $(domWidget).closest('[widgetId]');
         // trigger setParameters event on base element
-        widget.trigger('setParameters', parameters);
+
+        if (widget && widget.length) {
+            widget.trigger('setParameters', parameters);
+        } else {
+
+            var reportId = $(domWidget).closest('[data-report]').attr('data-report');
+
+            var ajaxRequest = new ajaxHelper();
+            ajaxRequest.addParams({
+                module: 'CoreHome',
+                action: 'saveViewDataTableParameters',
+                report_id: reportId
+            }, 'get');
+            ajaxRequest.addParams({
+                parameters: JSON.stringify(parameters)
+            }, 'post');
+            ajaxRequest.setCallback(function () {});
+            ajaxRequest.setFormat('html');
+            ajaxRequest.send(false);
+        }
     },
 
-    truncate: function (domElemToTruncate, truncationOffset) {
-        var self = this;
+    tooltip: function (domElement) {
 
-        domElemToTruncate = $(domElemToTruncate);
+        function isTextEllipsized($element)
+        {
+            return !($element && $element[0] && $element.outerWidth() >= $element[0].scrollWidth);
+        }
 
-        if (typeof domElemToTruncate.data('originalText') != 'undefined') {
-            // truncate only once. otherwise, the tooltip will show the truncated text as well.
+        var $domElement = $(domElement);
+
+        if ($domElement.data('tooltip') == 'enabled') {
             return;
         }
 
-        // make the original text (before truncation) available for others.
-        // the .truncate plugins adds a title to the dom element but the .tooltip
-        // plugin removes that again.
-        domElemToTruncate.data('originalText', domElemToTruncate.text());
+        $domElement.data('tooltip', 'enabled');
 
-        if (typeof truncationOffset == 'undefined') {
-            truncationOffset = 0;
-        }
-        var truncationLimit = 50;
-
-        if (typeof self.param.idSubtable == 'undefined'
-            && self.param.viewDataTable == 'tableAllColumns') {
-            // when showing all columns in a subtable, space is restricted
-            truncationLimit = 25;
+        if (!isTextEllipsized($domElement)) {
+            return;
         }
 
-        truncationLimit += truncationOffset;
-        domElemToTruncate.truncate(truncationLimit);
+        var customToolTipText = $domElement.attr('title') || $domElement.text();
 
-        var tooltipElem = $('.truncated', domElemToTruncate),
-            customToolTipText = domElemToTruncate.attr('title');
-
-        // if there's a title on the dom element, use this as the tooltip instead of
-        // the one set by the truncate plugin
         if (customToolTipText) {
-            // make sure browser doesn't add its own tooltip for the truncated element
-            if (tooltipElem[0]) {
-                tooltipElem.removeAttr('title');
-            }
-
-            tooltipElem = domElemToTruncate;
-            tooltipElem.attr('title', customToolTipText);
+            $domElement.attr('title', customToolTipText);
         }
 
-        // use tooltip (tooltip text determined by the 'title' attribute)
-        tooltipElem.tooltip({
+        $domElement.tooltip({
             track: true,
             show: false,
             hide: false
@@ -1150,8 +1322,61 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         $("td:first-child:even", domElem).addClass('label labelodd');
         $("tr:odd td", domElem).slice(1).addClass('column columnodd');
         $("tr:even td", domElem).slice(1).addClass('column columneven');
+    },
 
-        $('td span.label', domElem).each(function () { self.truncate($(this)); });
+    handleExpandFooter: function (domElem) {
+        if (this.isWithinDialog(domElem)) {
+            return;
+        }
+
+        var footerIcons = $('.dataTableFooterIcons', domElem);
+
+        if (!footerIcons.length) {
+            return;
+        }
+
+        var self = this;
+        function toggleFooter(event)
+        {
+            var icons = $('.dataTableFooterIcons', domElem);
+            $('.dataTableFeatures', domElem).toggleClass('expanded');
+
+            if (event && event.doNotNotifyChange) {
+                return;
+            }
+
+            self.notifyWidgetParametersChange(domElem, {
+                isFooterExpandedInDashboard: icons.is(':visible')
+            });
+        }
+
+        var moveNode = $('.datatableFooterMessage', domElem);
+        if (!moveNode.length) {
+            moveNode = $('.datatableRelatedReports', domElem);
+        }
+
+        footerIcons.after(moveNode);
+
+        $('.expandDataTableFooterDrawer', domElem).after(footerIcons);
+
+        var controls   = $('.controls', domElem);
+        var footerWrap = $('.dataTableFooterWrap', domElem);
+        if (controls.length && footerWrap.length) {
+            $('.dataTableFooterWrap', domElem).before(controls);
+        }
+
+        var loadingPiwikBelow = $('.loadingPiwikBelow', domElem);
+        if (loadingPiwikBelow.length) {
+            loadingPiwikBelow.insertBefore(moveNode);
+        }
+
+        if (this.param.isFooterExpandedInDashboard) {
+            toggleFooter({doNotNotifyChange: true});
+        }
+
+        var $nodes = $('.foldDataTableFooterDrawer, .expandDataTableFooterDrawer', domElem);
+        $nodes.off('click');
+        $nodes.on('click', toggleFooter);
     },
 
     handleColumnHighlighting: function (domElem) {
@@ -1169,13 +1394,13 @@ $.extend(DataTable.prototype, UIControl.prototype, {
 
                 if (!maxWidth[nthChild]) {
                     maxWidth[nthChild] = 0;
-                    rows.find("td:nth-child(" + (nthChild) + ") .value").each(function (index, element) {
+                    rows.find("td:nth-child(" + (nthChild) + ") .column .value").each(function (index, element) {
                         var width    = $(element).width();
                         if (width > maxWidth[nthChild]) {
                             maxWidth[nthChild] = width;
                         }
                     });
-                    rows.find("td:nth-child(" + (nthChild) + ") .value").each(function (index, element) {
+                    rows.find("td:nth-child(" + (nthChild) + ") .column .value").each(function (index, element) {
                         $(element).css({width: maxWidth[nthChild], display: 'inline-block'});
                     });
                 }
@@ -1213,7 +1438,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
     handleSubDataTable: function (domElem) {
         var self = this;
         // When the TR has a subDataTable class it means that this row has a link to a subDataTable
-        this.numberOfSubtables = $('tr.subDataTable', domElem)
+        self.numberOfSubtables = $('tr.subDataTable', domElem)
             .click(
             function () {
                 // get the idSubTable
@@ -1230,7 +1455,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
                         '<tr>' +
                             '<td colspan="' + numberOfColumns + '" class="cellSubDataTable">' +
                             '<div id="' + divIdToReplaceWithSubTable + '">' +
-                            '<span class="loadingPiwik" style="display:inline"><img src="plugins/Zeitgeist/images/loading-blue.gif" />' + _pk_translate('General_Loading') + '</span>' +
+                            '<span class="loadingPiwik" style="display:inline"><img src="plugins/Morpheus/images/loading-blue.gif" />' + _pk_translate('General_Loading') + '</span>' +
                             '</div>' +
                             '</td>' +
                             '</tr>'
@@ -1273,7 +1498,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
 
     // tooltip for column documentation
     handleColumnDocumentation: function (domElem) {
-        if ($('#dashboard').size() > 0) {
+        if (this.isDashboard()) {
             // don't display column documentation in dashboard
             // it causes trouble in full screen view
             return;
@@ -1305,78 +1530,6 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         });
     },
 
-    // documentation for report
-    handleReportDocumentation: function (domElem) {
-        // don't display report documentation in dashboard
-        if ($('#dashboard').size() > 0
-            // or in Widgetize screen
-            || $('.widgetContent').size() > 0
-            // or in Widget export
-            || $('.widget').size() > 0
-            ) {
-            return;
-        }
-        domElem = $(domElem);
-        var doc = domElem.find('.reportDocumentation');
-
-        var h2 = this._findReportHeader(domElem);
-        if (doc.size() == 0 || doc.children().size() == 0) // if we can't find the element, or the element is empty
-        {
-            if (h2 && h2.size() > 0) {
-                h2.find('a.reportDocumentationIcon').addClass('hidden');
-            }
-            return;
-        }
-
-        var icon = $('<a href="#"></a>');
-        var docShown = false;
-
-        icon.click(function () {
-            if (docShown) {
-                doc.stop(true, true).fadeOut(250);
-            }
-            else {
-                var widthOrientation = domElem.find('table, canvas, object').eq(0);
-                if (widthOrientation.size() > 0) {
-                    var width = Math.min(widthOrientation.width(), doc.parent().innerWidth());
-                    doc.css('width', (width - 2) + 'px');
-                }
-                doc.stop(true, true).fadeIn(250);
-            }
-            docShown = !docShown;
-            return false;
-        });
-
-        icon.addClass('reportDocumentationIcon');
-        if (h2 && h2.size() > 0) {
-            // handle previously added icon
-            var existingIcon = h2.find('a.reportDocumentationIcon');
-            if (existingIcon.size() > 0) {
-                existingIcon.replaceWith(icon);
-            }
-            else {
-                // add icon
-                h2.append('&nbsp;&nbsp;&nbsp;');
-                h2.append(icon);
-
-                h2.hover(function () {
-                        $(this).find('a.reportDocumentationIcon').show();
-                    },
-                    function () {
-                        $(this).find('a.reportDocumentationIcon').hide();
-                    })
-                    .click(
-                    function () {
-                        $(this).find('a.reportDocumentationIcon').click();
-                    })
-                    .css('cursor', 'pointer');
-            }
-        }
-        else {
-            //domElem.prepend(icon);
-        }
-    },
-
     handleRowActions: function (domElem) {
         this.doHandleRowActions(domElem.find('table > tbody > tr'));
     },
@@ -1386,7 +1539,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
 			track: true,
 			items: 'span',
 			content: function() {
-				return $(this).data('tooltip');
+				return $(this).parent().data('tooltip');
 			},
 			show: false,
 			hide: false,
@@ -1408,7 +1561,14 @@ $.extend(DataTable.prototype, UIControl.prototype, {
             thisReport = $('.datatableRelatedReports span:hidden', domElem)[0];
 
         hideShowRelatedReports(thisReport);
-        $('.datatableRelatedReports span', domElem).each(function () {
+
+        var relatedReports = $('.datatableRelatedReports span', domElem);
+
+        if (!relatedReports.length) {
+            $('.datatableRelatedReports', domElem).hide();
+        }
+
+        relatedReports.each(function () {
             var clicked = this;
             $(this).unbind('click').click(function (e) {
                 var url = $(this).attr('href');
@@ -1440,11 +1600,6 @@ $.extend(DataTable.prototype, UIControl.prototype, {
                 self.reloadAjaxDataTable(true, function (newReport) {
                     var newDomElem = self.dataTableLoaded(newReport, self.workingDivId);
                     hideShowRelatedReports(clicked);
-
-                    // update header, if we can find it
-                    var h2 = self._findReportHeader(newDomElem);
-                    if (h2)
-                        h2.text($(clicked).text());
                 });
             });
         });
@@ -1606,7 +1761,7 @@ $.extend(DataTable.prototype, UIControl.prototype, {
         }
 
         actions.height(tr.innerHeight() - 2);
-        actions.css('marginLeft', (td.width() + 5 - actions.outerWidth()) + 'px');
+        actions.css('marginLeft', (td.width() + 3 - actions.outerWidth()) + 'px');
     },
 
     _findReportHeader: function (domElem) {
