@@ -1,21 +1,17 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package CustomVariables
  */
 namespace Piwik\Plugins\CustomVariables;
 
 use Piwik\Piwik;
 use Piwik\View;
-use Piwik\ViewDataTable\Factory;
 
 /**
- * @package CustomVariables
  */
 class Controller extends \Piwik\Plugin\Controller
 {
