@@ -1,22 +1,18 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package DBStats
  */
 namespace Piwik\Plugins\DBStats;
 
 use Piwik\MetricsFormatter;
 use Piwik\Piwik;
 use Piwik\View;
-use Piwik\ViewDataTable\Factory;
 
 /**
- * @package DBStats
  */
 class Controller extends \Piwik\Plugin\ControllerAdmin
 {
@@ -29,7 +25,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
      */
     public function index()
     {
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         $view = new View('@DBStats/index');
         $this->setBasicVariablesView($view);
 
@@ -55,7 +51,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
      */
     public function getDatabaseUsageSummary()
     {
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         return $this->renderReport(__FUNCTION__);
     }
 
@@ -66,7 +62,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
      */
     public function getTrackerDataSummary()
     {
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         return $this->renderReport(__FUNCTION__);
     }
 
@@ -78,7 +74,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
      */
     public function getMetricDataSummary()
     {
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         return $this->renderReport(__FUNCTION__);
     }
 
@@ -90,7 +86,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
      */
     public function getMetricDataSummaryByYear()
     {
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         return $this->renderReport(__FUNCTION__);
     }
 
@@ -102,7 +98,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
      */
     public function getReportDataSummary()
     {
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         return $this->renderReport(__FUNCTION__);
     }
 
@@ -114,7 +110,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
      */
     public function getReportDataSummaryByYear()
     {
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         return $this->renderReport(__FUNCTION__);
     }
 
@@ -128,7 +124,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
      */
     public function getIndividualReportsSummary()
     {
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         return $this->renderReport(__FUNCTION__);
     }
 
@@ -142,7 +138,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
      */
     public function getIndividualMetricsSummary()
     {
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         return $this->renderReport(__FUNCTION__);
     }
 
@@ -157,7 +153,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
      */
     public function getAdminDataSummary()
     {
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         return $this->renderReport(__FUNCTION__);
     }
 }
