@@ -1,11 +1,9 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link     http://piwik.org
  * @license  http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @category Piwik_Plugins
- * @package  Dashboard
  */
 namespace Piwik\Plugins\Dashboard;
 
@@ -16,11 +14,11 @@ use Piwik\Piwik;
 use Piwik\Session\SessionNamespace;
 use Piwik\View;
 use Piwik\WidgetsList;
+use Piwik\FrontController;
 
 /**
  * Dashboard Controller
  *
- * @package Dashboard
  */
 class Controller extends \Piwik\Plugin\Controller
 {
@@ -45,7 +43,10 @@ class Controller extends \Piwik\Plugin\Controller
         $view->availableLayouts = $this->getAvailableLayouts();
 
         $view->dashboardId = Common::getRequestVar('idDashboard', 1, 'int');
-        $view->dashboardLayout = $this->getLayout($view->dashboardId);
+
+        // get the layout via FrontController so controller events are posted
+        $view->dashboardLayout = FrontController::getInstance()->dispatch('Dashboard', 'getDashboardLayout',
+            array($checkToken = false));
 
         return $view;
     }
@@ -53,13 +54,13 @@ class Controller extends \Piwik\Plugin\Controller
     public function embeddedIndex()
     {
         $view = $this->_getDashboardView('@Dashboard/embeddedIndex');
-
         return $view->render();
     }
 
     public function index()
     {
         $view = $this->_getDashboardView('@Dashboard/index');
+        $view->dashboardSettingsControl = new DashboardManagerControl();
         $view->dashboards = array();
         if (!Piwik::isUserIsAnonymous()) {
             $login = Piwik::getCurrentUserLogin();
@@ -77,9 +78,11 @@ class Controller extends \Piwik\Plugin\Controller
         return Common::json_encode(WidgetsList::get());
     }
 
-    public function getDashboardLayout()
+    public function getDashboardLayout($checkToken = true)
     {
-        $this->checkTokenInUrl();
+        if ($checkToken) {
+            $this->checkTokenInUrl();
+        }
 
         $idDashboard = Common::getRequestVar('idDashboard', 1, 'int');
 
@@ -222,7 +225,7 @@ class Controller extends \Piwik\Plugin\Controller
     {
         $this->checkTokenInUrl();
 
-        if (!Piwik::isUserIsSuperUser()) {
+        if (!Piwik::hasUserSuperUserAccess()) {
             return '0';
         }
         $login = Piwik::getCurrentUserLogin();
@@ -274,7 +277,7 @@ class Controller extends \Piwik\Plugin\Controller
     {
         $this->checkTokenInUrl();
 
-        if (Piwik::isUserIsSuperUser()) {
+        if (Piwik::hasUserSuperUserAccess()) {
             $layout = Common::unsanitizeInputValue(Common::getRequestVar('layout'));
             $paramsBind = array('', '1', $layout, $layout);
             $query = sprintf('INSERT INTO %s (login, iddashboard, layout) VALUES (?,?,?) ON DUPLICATE KEY UPDATE layout=?',
