@@ -1,43 +1,72 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package Installation
  */
 namespace Piwik\Plugins\Installation;
 
 use Piwik\Common;
+use Piwik\Config;
 use Piwik\FrontController;
-use Piwik\Menu\MenuAdmin;
+use Piwik\Menu\MenuAbstract;
 use Piwik\Piwik;
 use Piwik\Translate;
+use Piwik\View as PiwikView;
 
 /**
  *
- * @package Installation
  */
 class Installation extends \Piwik\Plugin
 {
     protected $installationControllerName = '\\Piwik\\Plugins\\Installation\\Controller';
 
     /**
-     * @see Piwik_Plugin::getListHooksRegistered
+     * @see Piwik\Plugin::getListHooksRegistered
      */
     public function getListHooksRegistered()
     {
         $hooks = array(
             'Config.NoConfigurationFile'      => 'dispatch',
             'Config.badConfigurationFile'     => 'dispatch',
-            'Menu.Admin.addItems'             => 'addMenu',
+            'Db.cannotConnectToDb'            => 'displayDbConnectionMessage',
+            'Request.dispatch'                => 'dispatchIfNotInstalledYet',
             'AssetManager.getStylesheetFiles' => 'getStylesheetFiles',
         );
         return $hooks;
     }
 
+    public function displayDbConnectionMessage($exception = null)
+    {
+        $view = new PiwikView("@Installation/cannotConnectToDb");
+        $view->exceptionMessage = $exception->getMessage();
+
+        Piwik_ExitWithMessage($view->render());
+    }
+
+    public function dispatchIfNotInstalledYet(&$module, &$action, &$parameters)
+    {
+        $general = Config::getInstance()->General;
+
+        if (empty($general['installation_in_progress'])) {
+            return;
+        }
+
+        if ($module == 'Installation') {
+            return;
+        }
+
+        $module = 'Installation';
+
+        if (!$this->isAllowedAction($action)) {
+            $action = 'welcome';
+        }
+
+        $parameters = array();
+    }
+
     public function setControllerToLoad($newControllerName)
     {
         $this->installationControllerName = $newControllerName;
@@ -61,13 +90,10 @@ class Installation extends \Piwik\Plugin
 
         Translate::loadCoreTranslation();
 
-        $step = Common::getRequestVar('action', 'welcome', 'string');
-        $controller = $this->getInstallationController();
-        $isActionWhiteListed = in_array($step, array('saveLanguage', 'getBaseCss'));
-        if (in_array($step, array_keys($controller->getInstallationSteps()))
-            || $isActionWhiteListed
-        ) {
-            echo FrontController::getInstance()->dispatch('Installation', $step, array($message));
+        $action = Common::getRequestVar('action', 'welcome', 'string');
+
+        if ($this->isAllowedAction($action)) {
+            echo FrontController::getInstance()->dispatch('Installation', $action, array($message));
         } else {
             Piwik::exitWithErrorMessage(Piwik::translate('Installation_NoConfigFound'));
         }
@@ -75,17 +101,6 @@ class Installation extends \Piwik\Plugin
         exit;
     }
 
-    /**
-     * Adds the 'System Check' admin page if the user is the super user.
-     */
-    public function addMenu()
-    {
-        MenuAdmin::addEntry('Installation_SystemCheck',
-            array('module' => 'Installation', 'action' => 'systemCheckPage'),
-            Piwik::isUserIsSuperUser(),
-            $order = 15);
-    }
-
     /**
      * Adds CSS files to list of CSS files for asset manager.
      */
@@ -93,4 +108,13 @@ class Installation extends \Piwik\Plugin
     {
         $stylesheets[] = "plugins/Installation/stylesheets/systemCheckPage.less";
     }
+
+    private function isAllowedAction($action)
+    {
+        $controller = $this->getInstallationController();
+        $isActionWhiteListed = in_array($action, array('saveLanguage', 'getBaseCss', 'reuseTables'));
+
+        return in_array($action, array_keys($controller->getInstallationSteps()))
+                || $isActionWhiteListed;
+    }
 }
