@@ -5,4 +5,7 @@ $(function () {
         value: parseInt($('#progressbar').attr('data-progress'))
     });
     $('code').click(function () { $(this).select(); });
+
+    // Focus the first input field in the form
+    $('form:not(.filter) :input:visible:enabled:first').focus();
 });
\ No newline at end of file
