@@ -1,25 +1,23 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package Live
  */
 namespace Piwik\Plugins\Live;
 
 use Exception;
 use Piwik\Common;
 use Piwik\Config;
-use Piwik\DataTable\Row;
 use Piwik\DataTable;
+use Piwik\DataTable\Row;
 use Piwik\Date;
 use Piwik\Db;
 use Piwik\MetricsFormatter;
-use Piwik\Period;
 use Piwik\Period\Range;
+use Piwik\Period;
 use Piwik\Piwik;
 use Piwik\Plugins\Referrers\API as APIReferrers;
 use Piwik\Plugins\SitesManager\API as APISitesManager;
@@ -51,7 +49,6 @@ require_once PIWIK_INCLUDE_PATH . '/plugins/Live/Visitor.php';
  * The method "getCounters" is used to return a simple counter: visits, number of actions, number of converted visits, in the last N minutes.
  *
  * See also the documentation about <a href='http://piwik.org/docs/real-time/' target='_blank'>Real time widget and visitor level reports</a> in Piwik.
- * @package Live
  * @method static \Piwik\Plugins\Live\API getInstance()
  */
 class API extends \Piwik\Plugin\API
@@ -148,8 +145,10 @@ class API extends \Piwik\Plugin\API
             $countVisitorsToFetch = $filter_limit + $filter_offset;
         }
 
+        $filterSortOrder = Common::getRequestVar('filter_sort_order', false, 'string');
+
         Piwik::checkUserHasViewAccess($idSite);
-        $dataTable = $this->loadLastVisitorDetailsFromDatabase($idSite, $period, $date, $segment, $countVisitorsToFetch, $visitorId = false, $minTimestamp);
+        $dataTable = $this->loadLastVisitorDetailsFromDatabase($idSite, $period, $date, $segment, $countVisitorsToFetch, $visitorId = false, $minTimestamp, $filterSortOrder);
         $this->addFilterToCleanVisitors($dataTable, $idSite, $flat, $doNotFetchActions);
 
         return $dataTable;
@@ -407,8 +406,9 @@ class API extends \Piwik\Plugin\API
             return false;
         }
 
-        $visitDetails = $dataTable->getFirstRow()->getColumns();
-        $visitor      = new Visitor($visitDetails);
+        $visitorFactory = new VisitorFactory();
+        $visitDetails   = $dataTable->getFirstRow()->getColumns();
+        $visitor        = $visitorFactory->create($visitDetails);
 
         return $visitor->getVisitorId();
     }
@@ -474,7 +474,7 @@ class API extends \Piwik\Plugin\API
     {
         $today = Date::today();
 
-        $serverDate = $visit->getColumn('serverDate');
+        $serverDate = $visit->getColumn('firstActionTimestamp');
         return array(
             'date'            => $serverDate,
             'prettyDate'      => Date::factory($serverDate)->getLocalized(self::VISITOR_PROFILE_DATE_FORMAT),
@@ -544,22 +544,30 @@ class API extends \Piwik\Plugin\API
             /** @var DataTable $table */
             $actionsLimit = (int)Config::getInstance()->General['visitor_log_maximum_actions_per_visit'];
 
-            $site       = new Site($idSite);
-            $timezone   = $site->getTimezone();
-            $currencies = APISitesManager::getInstance()->getCurrencySymbols();
+            $visitorFactory = new VisitorFactory();
+            $website        = new Site($idSite);
+            $timezone       = $website->getTimezone();
+            $currency       = $website->getCurrency();
+            $currencies     = APISitesManager::getInstance()->getCurrencySymbols();
+
+            // live api is not summable, prevents errors like "Unexpected ECommerce status value"
+            $table->deleteRow(DataTable::ID_SUMMARY_ROW);
 
             foreach ($table->getRows() as $visitorDetailRow) {
                 $visitorDetailsArray = Visitor::cleanVisitorDetails($visitorDetailRow->getColumns());
 
-                $visitor = new Visitor($visitorDetailsArray);
+                $visitor = $visitorFactory->create($visitorDetailsArray);
                 $visitorDetailsArray = $visitor->getAllVisitorDetails();
 
-                $visitorDetailsArray['siteCurrency'] = $site->getCurrency();
-                $visitorDetailsArray['siteCurrencySymbol'] = @$currencies[$site->getCurrency()];
+                $visitorDetailsArray['siteCurrency'] = $currency;
+                $visitorDetailsArray['siteCurrencySymbol'] = @$currencies[$visitorDetailsArray['siteCurrency']];
                 $visitorDetailsArray['serverTimestamp'] = $visitorDetailsArray['lastActionTimestamp'];
+
                 $dateTimeVisit = Date::factory($visitorDetailsArray['lastActionTimestamp'], $timezone);
-                $visitorDetailsArray['serverTimePretty'] = $dateTimeVisit->getLocalized('%time%');
-                $visitorDetailsArray['serverDatePretty'] = $dateTimeVisit->getLocalized(Piwik::translate('CoreHome_ShortDateFormat'));
+                if($dateTimeVisit) {
+                    $visitorDetailsArray['serverTimePretty'] = $dateTimeVisit->getLocalized('%time%');
+                    $visitorDetailsArray['serverDatePretty'] = $dateTimeVisit->getLocalized(Piwik::translate('CoreHome_ShortDateFormat'));
+                }
 
                 $dateTimeVisitFirstAction = Date::factory($visitorDetailsArray['firstActionTimestamp'], $timezone);
                 $visitorDetailsArray['serverDatePrettyFirstAction'] = $dateTimeVisitFirstAction->getLocalized(Piwik::translate('CoreHome_ShortDateFormat'));
@@ -579,7 +587,7 @@ class API extends \Piwik\Plugin\API
         });
     }
 
-    private function loadLastVisitorDetailsFromDatabase($idSite, $period, $date, $segment = false, $countVisitorsToFetch = 100, $visitorId = false, $minTimestamp = false)
+    private function loadLastVisitorDetailsFromDatabase($idSite, $period, $date, $segment = false, $countVisitorsToFetch = 100, $visitorId = false, $minTimestamp = false, $filterSortOrder = false)
     {
         $where = $whereBind = array();
 
@@ -588,8 +596,13 @@ class API extends \Piwik\Plugin\API
         $where[] = $whereClause;
         $whereBind = $idSites;
 
-        $orderBy = "idsite, visit_last_action_time DESC";
-        $orderByParent = "sub.visit_last_action_time DESC";
+        if (strtolower($filterSortOrder) !== 'asc') {
+            $filterSortOrder = 'DESC';
+        }
+
+        $orderBy = "idsite, visit_last_action_time " . $filterSortOrder;
+        $orderByParent = "sub.visit_last_action_time " . $filterSortOrder;
+
         if (!empty($visitorId)) {
             $where[] = "log_visit.idvisitor = ? ";
             $whereBind[] = @Common::hex2bin($visitorId);
@@ -629,7 +642,7 @@ class API extends \Piwik\Plugin\API
                 ) {
                     $processedDate = $processedDate->subDay(1);
                 }
-                $processedPeriod = Period::factory($period, $processedDate);
+                $processedPeriod = Period\Factory::build($period, $processedDate);
             }
             $dateStart = $processedPeriod->getDateStart()->setTimezone($currentTimezone);
             $where[] = "log_visit.visit_last_action_time >= ?";
@@ -682,6 +695,15 @@ class API extends \Piwik\Plugin\API
 
         $dataTable = new DataTable();
         $dataTable->addRowsFromSimpleArray($data);
+       // $dataTable->disableFilter('Truncate');
+
+        if (!empty($data[0])) {
+            $columnsToNotAggregate = array_map(function () {
+                return 'skip';
+            }, $data[0]);
+
+            $dataTable->setMetadata(DataTable::COLUMN_AGGREGATION_OPS_METADATA_NAME, $columnsToNotAggregate);
+        }
 
         return $dataTable;
     }
