@@ -1,8 +1,14 @@
 $(document).ready(function () {
+    // do not apply on the Login page
+    if($('#loginPage').length) {
+        return;
+    }
 
     function initICheck()
     {
-        $('input').iCheck({
+        $('input').filter(function () {
+            return !$(this).parent().is('.form-radio');
+        }).iCheck({
             checkboxClass: 'form-checkbox',
             radioClass: 'form-radio',
             checkedClass: 'checked',
@@ -12,6 +18,7 @@ $(document).ready(function () {
 
     initICheck();
     $(document).bind('ScheduledReport.edit', initICheck);
+    $(broadcast).bind('locationChangeSuccess', initICheck);
 
     $('body').on('ifClicked', 'input', function () {
         $(this).trigger('click');
