@@ -1,45 +1,63 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package MultiSites
  */
 namespace Piwik\Plugins\MultiSites;
-use Piwik\Menu\MenuTop;
+
 use Piwik\Piwik;
 
 
 /**
  *
- * @package MultiSites
  */
 class MultiSites extends \Piwik\Plugin
 {
     public function getInformation()
     {
         $info = parent::getInformation();
-        $info['author'] = 'Piwik PRO';
-        $info['author_homepage'] = 'http://piwik.pro';
+        $info['authors'] = array(array('name' => 'Piwik PRO', 'homepage' => 'http://piwik.pro'));
         return $info;
     }
 
     /**
-     * @see Piwik_Plugin::getListHooksRegistered
+     * @see Piwik\Plugin::getListHooksRegistered
      */
     public function getListHooksRegistered()
     {
         return array(
             'AssetManager.getStylesheetFiles' => 'getStylesheetFiles',
             'AssetManager.getJavaScriptFiles' => 'getJsFiles',
-            'Menu.Top.addItems'               => 'addTopMenu',
             'API.getReportMetadata'           => 'getReportMetadata',
+            'Translate.getClientSideTranslationKeys' => 'getClientSideTranslationKeys',
         );
     }
 
+    public function getClientSideTranslationKeys(&$translations)
+    {
+        $translations[] = 'General_Website';
+        $translations[] = 'General_ColumnNbVisits';
+        $translations[] = 'General_ColumnPageviews';
+        $translations[] = 'General_ColumnRevenue';
+        $translations[] = 'General_TotalVisitsPageviewsRevenue';
+        $translations[] = 'General_EvolutionSummaryGeneric';
+        $translations[] = 'General_AllWebsitesDashboard';
+        $translations[] = 'General_NVisits';
+        $translations[] = 'MultiSites_Evolution';
+        $translations[] = 'SitesManager_AddSite';
+        $translations[] = 'General_Next';
+        $translations[] = 'General_Previous';
+        $translations[] = 'General_GoTo';
+        $translations[] = 'Dashboard_DashboardOf';
+        $translations[] = 'Actions_SubmenuSitesearch';
+        $translations[] = 'MultiSites_LoadingWebsites';
+        $translations[] = 'General_ErrorRequest';
+        $translations[] = 'MultiSites_Pagination';
+    }
+
     public function getReportMetadata(&$reports)
     {
         $metadataMetrics = array();
@@ -59,7 +77,7 @@ class MultiSites extends \Piwik\Plugin
             'metrics'           => $metadataMetrics,
             'processedMetrics'  => false,
             'constantRowsCount' => false,
-            'order'             => 5
+            'order'             => 4
         );
 
         $reports[] = array(
@@ -75,20 +93,17 @@ class MultiSites extends \Piwik\Plugin
         );
     }
 
-    public function addTopMenu()
-    {
-        $urlParams = array('module' => 'MultiSites', 'action' => 'index', 'segment' => false);
-        $tooltip = Piwik::translate('MultiSites_TopLinkTooltip');
-        MenuTop::addEntry('General_MultiSitesSummary', $urlParams, true, 3, $isHTML = false, $tooltip);
-    }
-
     public function getJsFiles(&$jsFiles)
     {
-        $jsFiles[] = "plugins/MultiSites/javascripts/multiSites.js";
+        $jsFiles[] = "plugins/MultiSites/angularjs/dashboard/dashboard-model.js";
+        $jsFiles[] = "plugins/MultiSites/angularjs/dashboard/dashboard-controller.js";
+        $jsFiles[] = "plugins/MultiSites/angularjs/dashboard/dashboard-filter.js";
+        $jsFiles[] = "plugins/MultiSites/angularjs/dashboard/dashboard-directive.js";
+        $jsFiles[] = "plugins/MultiSites/angularjs/site/site-directive.js";
     }
 
     public function getStylesheetFiles(&$stylesheets)
     {
-        $stylesheets[] = "plugins/MultiSites/stylesheets/multiSites.less";
+        $stylesheets[] = "plugins/MultiSites/angularjs/dashboard/dashboard.less";
     }
 }
