@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package Proxy
  */
 namespace Piwik\Plugins\Proxy;
 
@@ -15,14 +13,13 @@ use Piwik\Version;
 /**
  * Proxy services for the UI
  *
- * @package Proxy
  */
 class Proxy extends \Piwik\Plugin
 {
     /**
      * Return information about this plugin.
      *
-     * @see Piwik_Plugin
+     * @see Piwik\Plugin
      *
      * @return array
      */
@@ -30,8 +27,7 @@ class Proxy extends \Piwik\Plugin
     {
         return array(
             'description'          => 'Proxy services',
-            'author'               => 'Piwik',
-            'author_homepage'      => 'http://piwik.org/',
+            'authors'              => array(array('name' => 'Piwik', 'homepage' => 'http://piwik.org/')),
             'version'              => Version::VERSION,
             'translationAvailable' => false,
         );
