@@ -1,25 +1,21 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package Referrers
  */
 namespace Piwik\Plugins\Referrers;
 
 use Piwik\ArchiveProcessor;
 use Piwik\Common;
-use Piwik\Menu\MenuMain;
 use Piwik\Piwik;
 use Piwik\Plugin\ViewDataTable;
-use Piwik\Plugins\CoreVisualizations\Visualizations\HtmlTable\AllColumns;
 use Piwik\Plugins\CoreVisualizations\Visualizations\HtmlTable;
+use Piwik\Plugins\CoreVisualizations\Visualizations\HtmlTable\AllColumns;
 use Piwik\Plugins\CoreVisualizations\Visualizations\JqplotGraph\Pie;
 use Piwik\SettingsPiwik;
-use Piwik\WidgetsList;
 
 /**
  * @see plugins/Referrers/functions.php
@@ -27,27 +23,33 @@ use Piwik\WidgetsList;
 require_once PIWIK_INCLUDE_PATH . '/plugins/Referrers/functions.php';
 
 /**
- * @package Referrers
  */
 class Referrers extends \Piwik\Plugin
 {
     /**
-     * @see Piwik_Plugin::getListHooksRegistered
+     * @see Piwik\Plugin::getListHooksRegistered
      */
     public function getListHooksRegistered()
     {
         $hooks = array(
-            'WidgetsList.addWidgets'          => 'addWidgets',
-            'Menu.Reporting.addItems'         => 'addMenus',
             'Goals.getReportsWithGoalMetrics' => 'getReportsWithGoalMetrics',
             'API.getReportMetadata'           => 'getReportMetadata',
             'API.getSegmentDimensionMetadata' => 'getSegmentsMetadata',
             'ViewDataTable.configure'         => 'configureViewDataTable',
-            'ViewDataTable.getDefaultType'    => 'getDefaultTypeViewDataTable'
+            'ViewDataTable.getDefaultType'    => 'getDefaultTypeViewDataTable',
+            'Insights.addReportToOverview'    => 'addReportToInsightsOverview'
         );
         return $hooks;
     }
 
+    public function addReportToInsightsOverview(&$reports)
+    {
+        $reports['Referrers_getWebsites']  = array();
+        $reports['Referrers_getCampaigns'] = array();
+        $reports['Referrers_getSocials']   = array();
+        $reports['Referrers_getSearchEngines'] = array();
+    }
+
     public function getReportMetadata(&$reports)
     {
         $reports = array_merge($reports, array(
@@ -222,67 +224,38 @@ class Referrers extends \Piwik\Plugin
         );
     }
 
-    /**
-     * Adds Referrer widgets
-     */
-    function addWidgets()
-    {
-        WidgetsList::add('Referrers_Referrers', 'Referrers_WidgetKeywords', 'Referrers', 'getKeywords');
-        WidgetsList::add('Referrers_Referrers', 'Referrers_WidgetExternalWebsites', 'Referrers', 'getWebsites');
-        WidgetsList::add('Referrers_Referrers', 'Referrers_WidgetSocials', 'Referrers', 'getSocials');
-        WidgetsList::add('Referrers_Referrers', 'Referrers_SearchEngines', 'Referrers', 'getSearchEngines');
-        WidgetsList::add('Referrers_Referrers', 'Referrers_Campaigns', 'Referrers', 'getCampaigns');
-        WidgetsList::add('Referrers_Referrers', 'General_Overview', 'Referrers', 'getReferrerType');
-        WidgetsList::add('Referrers_Referrers', 'Referrers_WidgetGetAll', 'Referrers', 'getAll');
-        if (SettingsPiwik::isSegmentationEnabled()) {
-            WidgetsList::add('SEO', 'Referrers_WidgetTopKeywordsForPages', 'Referrers', 'getKeywordsForPage');
-        }
-    }
-
-    /**
-     * Adds Web Analytics menus
-     */
-    function addMenus()
-    {
-        MenuMain::getInstance()->add('Referrers_Referrers', '', array('module' => 'Referrers', 'action' => 'index'), true, 20);
-        MenuMain::getInstance()->add('Referrers_Referrers', 'General_Overview', array('module' => 'Referrers', 'action' => 'index'), true, 1);
-        MenuMain::getInstance()->add('Referrers_Referrers', 'Referrers_SubmenuSearchEngines', array('module' => 'Referrers', 'action' => 'getSearchEnginesAndKeywords'), true, 2);
-        MenuMain::getInstance()->add('Referrers_Referrers', 'Referrers_SubmenuWebsites', array('module' => 'Referrers', 'action' => 'indexWebsites'), true, 3);
-        MenuMain::getInstance()->add('Referrers_Referrers', 'Referrers_Campaigns', array('module' => 'Referrers', 'action' => 'indexCampaigns'), true, 4);
-    }
-
     /**
      * Adds Goal dimensions, so that the dimensions are displayed in the UI Goal Overview page
      */
     public function getReportsWithGoalMetrics(&$dimensions)
     {
         $dimensions = array_merge($dimensions, array(
-                                                    array('category' => Piwik::translate('Referrers_Referrers'),
-                                                          'name'     => Piwik::translate('Referrers_Keywords'),
-                                                          'module'   => 'Referrers',
-                                                          'action'   => 'getKeywords',
-                                                    ),
-                                                    array('category' => Piwik::translate('Referrers_Referrers'),
-                                                          'name'     => Piwik::translate('Referrers_SearchEngines'),
-                                                          'module'   => 'Referrers',
-                                                          'action'   => 'getSearchEngines',
-                                                    ),
-                                                    array('category' => Piwik::translate('Referrers_Referrers'),
-                                                          'name'     => Piwik::translate('Referrers_Websites'),
-                                                          'module'   => 'Referrers',
-                                                          'action'   => 'getWebsites',
-                                                    ),
-                                                    array('category' => Piwik::translate('Referrers_Referrers'),
-                                                          'name'     => Piwik::translate('Referrers_Campaigns'),
-                                                          'module'   => 'Referrers',
-                                                          'action'   => 'getCampaigns',
-                                                    ),
-                                                    array('category' => Piwik::translate('Referrers_Referrers'),
-                                                          'name'     => Piwik::translate('Referrers_Type'),
-                                                          'module'   => 'Referrers',
-                                                          'action'   => 'getReferrerType',
-                                                    ),
-                                               ));
+            array('category' => Piwik::translate('Referrers_Referrers'),
+                  'name'     => Piwik::translate('Referrers_Type'),
+                  'module'   => 'Referrers',
+                  'action'   => 'getReferrerType',
+            ),
+            array('category' => Piwik::translate('Referrers_Referrers'),
+                  'name'     => Piwik::translate('Referrers_Keywords'),
+                  'module'   => 'Referrers',
+                  'action'   => 'getKeywords',
+            ),
+            array('category' => Piwik::translate('Referrers_Referrers'),
+                  'name'     => Piwik::translate('Referrers_SearchEngines'),
+                  'module'   => 'Referrers',
+                  'action'   => 'getSearchEngines',
+            ),
+            array('category' => Piwik::translate('Referrers_Referrers'),
+                  'name'     => Piwik::translate('Referrers_Websites'),
+                  'module'   => 'Referrers',
+                  'action'   => 'getWebsites',
+            ),
+            array('category' => Piwik::translate('Referrers_Referrers'),
+                  'name'     => Piwik::translate('Referrers_Campaigns'),
+                  'module'   => 'Referrers',
+                  'action'   => 'getCampaigns',
+            ),
+        ));
     }
 
     public function getDefaultTypeViewDataTable(&$defaultViewTypes)
@@ -477,14 +450,6 @@ class Referrers extends \Piwik\Plugin
         $view->config->addTranslation('label', Piwik::translate('Referrers_ColumnCampaign'));
 
         $view->requestConfig->filter_limit = 25;
-
-        if (Common::getRequestVar('viewDataTable', false) != 'graphEvolution') {
-            $view->config->show_footer_message = Piwik::translate('Referrers_CampaignFooterHelp',
-                array('<a target="_blank" href="http://piwik.org/docs/tracking-campaigns/">',
-                      '</a> - <a target="_blank" href="http://piwik.org/docs/tracking-campaigns/url-builder/">',
-                      '</a>')
-            );
-        }
     }
 
     private function configureViewForGetKeywordsFromCampaignId(ViewDataTable $view)
