@@ -1,5 +1,5 @@
 /*!
- * Piwik - Web Analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
@@ -46,11 +46,12 @@ DataTable_RowActions_Transitions.prototype.trigger = function (tr, e, subTableLa
     }
 };
 
-DataTable_RowAction.prototype.performAction = function (label, tr, e) {
+DataTable_RowActions_Transitions.prototype.performAction = function (label, tr, e) {
     var separator = ' > '; // LabelFilter::SEPARATOR_RECURSIVE_LABEL
     var labelParts = label.split(separator);
     for (var i = 0; i < labelParts.length; i++) {
-        labelParts[i] = $.trim(decodeURIComponent(labelParts[i]));
+        var labelPart = labelParts[i].replace('@', '');
+        labelParts[i] = $.trim(decodeURIComponent(labelPart));
     }
     label = labelParts.join(piwik.config.action_url_category_delimiter);
     this.openPopover('title:' + label);
@@ -616,7 +617,7 @@ Piwik_Transitions.prototype.renderClosedGroup = function (groupName, side, onlyB
         boxText: self.model.getGroupTitle(groupName),
         boxTextNumLines: 1,
         boxTextCssClass: 'SingleLine',
-        boxIcon: 'plugins/Zeitgeist/images/plus_blue.png',
+        boxIcon: 'plugins/Morpheus/images/plus_blue.png',
         smallBox: true,
         onClick: function () {
             self.unHighlightGroup(groupName, side);
@@ -707,6 +708,11 @@ Piwik_Transitions.prototype.unHighlightGroup = function (groupName, side) {
 
 /** Open a link in a new tab */
 Piwik_Transitions.prototype.openExternalUrl = function (url) {
+    if (url.substring(0, 4) != 'http') {
+        // internal pages don't have the protocol
+        // external links / downloads have the protocol
+        url = 'http://' + url;
+    }
     url = piwik.piwik_url + '?module=Proxy&action=redirect&url=' + encodeURIComponent(url);
     window.open(url, '_newtab');
 };
