@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package UserCountry
  */
 namespace Piwik\Plugins\UserCountry;
 
@@ -16,17 +14,15 @@ use Piwik\DataTable\Renderer\Json;
 use Piwik\Http;
 use Piwik\IP;
 use Piwik\Piwik;
+use Piwik\Plugins\UserCountry\LocationProvider\GeoIp\ServerBased;
+use Piwik\Plugins\UserCountry\LocationProvider\GeoIp;
+use Piwik\Plugins\UserCountry\LocationProvider;
 use Piwik\Plugins\UserCountry\LocationProvider\DefaultProvider;
 use Piwik\Plugins\UserCountry\LocationProvider\GeoIp\Pecl;
-use Piwik\Plugins\UserCountry\LocationProvider;
-use Piwik\Plugins\UserCountry\LocationProvider\GeoIp;
-use Piwik\Plugins\UserCountry\LocationProvider\GeoIp\ServerBased;
 use Piwik\View;
-use Piwik\ViewDataTable\Factory;
 
 /**
  *
- * @package UserCountry
  */
 class Controller extends \Piwik\Plugin\ControllerAdmin
 {
@@ -48,7 +44,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
     public function adminIndex()
     {
         $this->dieIfGeolocationAdminIsDisabled();
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         $view = new View('@UserCountry/adminIndex');
 
         $allProviderInfo = LocationProvider::getAllProviderInfo($newline = '<br/>', $includeExtra = true);
@@ -109,7 +105,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
     public function downloadFreeGeoIPDB()
     {
         $this->dieIfGeolocationAdminIsDisabled();
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         if ($_SERVER["REQUEST_METHOD"] == "POST") {
             $this->checkTokenInUrl();
             Json::sendHeaderJSON();
@@ -195,7 +191,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
     public function updateGeoIPLinks()
     {
         $this->dieIfGeolocationAdminIsDisabled();
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         if ($_SERVER["REQUEST_METHOD"] == "POST") {
             Json::sendHeaderJSON();
             try {
@@ -240,7 +236,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
     public function downloadMissingGeoIpDb()
     {
         $this->dieIfGeolocationAdminIsDisabled();
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         if ($_SERVER["REQUEST_METHOD"] == "POST") {
             try {
                 $this->checkTokenInUrl();
@@ -293,7 +289,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
     public function setCurrentLocationProvider()
     {
         $this->dieIfGeolocationAdminIsDisabled();
-        Piwik::checkUserIsSuperUser();
+        Piwik::checkUserHasSuperUserAccess();
         if ($_SERVER["REQUEST_METHOD"] == "POST") {
             $this->checkTokenInUrl();
 
@@ -403,4 +399,4 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
             throw new \Exception('Geo location setting page has been disabled.');
         }
     }
-}
\ No newline at end of file
+}
