@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package UserCountry
  */
 namespace Piwik\Plugins\UserCountry\LocationProvider\GeoIp;
 
@@ -19,13 +17,17 @@ use Piwik\Plugins\UserCountry\LocationProvider\GeoIp;
  * FIXME: For some reason, if the PECL module is loaded & an organization DB is available, the PHP
  * module won't return organization info. If the PECL module is not loaded, organization info is returned.
  *
- * @package UserCountry
  */
 class Pecl extends GeoIp
 {
     const ID = 'geoip_pecl';
     const TITLE = 'GeoIP (PECL)';
 
+    /**
+     * For tests.
+     */
+    public static $forceDisable = false;
+
     /**
      * Uses the GeoIP PECL module to get a visitor's location based on their IP address.
      *
@@ -108,7 +110,7 @@ class Pecl extends GeoIp
      */
     public function isAvailable()
     {
-        return function_exists('geoip_db_avail');
+        return !self::$forceDisable && function_exists('geoip_db_avail');
     }
 
     /**
