@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package UserCountry
  */
 namespace Piwik\Plugins\UserCountry;
 
@@ -14,16 +12,14 @@ use Piwik\ArchiveProcessor;
 use Piwik\Common;
 use Piwik\Config;
 use Piwik\IP;
-use Piwik\Menu\MenuAdmin;
-use Piwik\Menu\MenuMain;
 use Piwik\Piwik;
+use Piwik\Plugin\Manager;
 use Piwik\Plugin\ViewDataTable;
-use Piwik\Plugins\UserCountry\LocationProvider\DefaultProvider;
-
-use Piwik\Plugins\UserCountry\LocationProvider;
+use Piwik\Plugins\PrivacyManager\Config as PrivacyManagerConfig;
 use Piwik\Plugins\UserCountry\LocationProvider\GeoIp;
+use Piwik\Plugins\UserCountry\LocationProvider;
+use Piwik\Plugins\UserCountry\LocationProvider\DefaultProvider;
 use Piwik\Url;
-use Piwik\WidgetsList;
 
 /**
  * @see plugins/UserCountry/GeoIPAutoUpdater.php
@@ -32,46 +28,39 @@ require_once PIWIK_INCLUDE_PATH . '/plugins/UserCountry/GeoIPAutoUpdater.php';
 
 /**
  *
- * @package UserCountry
  */
 class UserCountry extends \Piwik\Plugin
 {
     /**
-     * @see Piwik_Plugin::getListHooksRegistered
+     * @see Piwik\Plugin::getListHooksRegistered
      */
     public function getListHooksRegistered()
     {
         $hooks = array(
-            'WidgetsList.addWidgets'                 => 'addWidgets',
-            'Menu.Reporting.addItems'                => 'addMenu',
-            'Menu.Admin.addItems'                    => 'addAdminMenu',
             'Goals.getReportsWithGoalMetrics'        => 'getReportsWithGoalMetrics',
             'API.getReportMetadata'                  => 'getReportMetadata',
             'API.getSegmentDimensionMetadata'        => 'getSegmentsMetadata',
             'AssetManager.getStylesheetFiles'        => 'getStylesheetFiles',
             'AssetManager.getJavaScriptFiles'        => 'getJsFiles',
             'Tracker.newVisitorInformation'          => 'enrichVisitWithLocation',
-            'TaskScheduler.getScheduledTasks'        => 'getScheduledTasks',
             'ViewDataTable.configure'                => 'configureViewDataTable',
             'Translate.getClientSideTranslationKeys' => 'getClientSideTranslationKeys',
-            'Tracker.setTrackerCacheGeneral'         => 'setTrackerCacheGeneral'
+            'Tracker.setTrackerCacheGeneral'         => 'setTrackerCacheGeneral',
+            'Insights.addReportToOverview'           => 'addReportToInsightsOverview'
         );
         return $hooks;
     }
 
+    public function addReportToInsightsOverview(&$reports)
+    {
+        $reports['UserCountry_getCountry'] = array();
+    }
+
     public function setTrackerCacheGeneral(&$cache)
     {
         $cache['currentLocationProviderId'] = LocationProvider::getCurrentProviderId();
     }
 
-    public function getScheduledTasks(&$tasks)
-    {
-        // add the auto updater task if GeoIP admin is enabled
-        if($this->isGeoLocationAdminEnabled()) {
-            $tasks[] = new GeoIPAutoUpdater();
-        }
-    }
-
     public function getStylesheetFiles(&$stylesheets)
     {
         $stylesheets[] = "plugins/UserCountry/stylesheets/userCountry.less";
@@ -86,7 +75,9 @@ class UserCountry extends \Piwik\Plugin
     {
         require_once PIWIK_INCLUDE_PATH . "/plugins/UserCountry/LocationProvider.php";
 
-        $ipAddress = IP::N2P(Config::getInstance()->Tracker['use_anonymized_ip_for_visit_enrichment'] == 1 ? $visitorInfo['location_ip'] : $request->getIp());
+        $privacyConfig = new PrivacyManagerConfig();
+
+        $ipAddress = IP::N2P($privacyConfig->useAnonymizedIpForVisitEnrichment ? $visitorInfo['location_ip'] : $request->getIp());
         $userInfo = array(
             'lang' => $visitorInfo['location_browser_lang'],
             'ip' => $ipAddress
@@ -165,46 +156,12 @@ class UserCountry extends \Piwik\Plugin
             $providerValue = $location[LocationProvider::ORG_KEY];
         }
 
-        if (isset($providerValue)) {
+        if (isset($providerValue)
+            && Manager::getInstance()->isPluginInstalled('Provider')) {
             $visitorInfo['location_provider'] = $providerValue;
         }
     }
 
-    public function addWidgets()
-    {
-        $widgetContinentLabel = Piwik::translate('UserCountry_WidgetLocation')
-            . ' (' . Piwik::translate('UserCountry_Continent') . ')';
-        $widgetCountryLabel = Piwik::translate('UserCountry_WidgetLocation')
-            . ' (' . Piwik::translate('UserCountry_Country') . ')';
-        $widgetRegionLabel = Piwik::translate('UserCountry_WidgetLocation')
-            . ' (' . Piwik::translate('UserCountry_Region') . ')';
-        $widgetCityLabel = Piwik::translate('UserCountry_WidgetLocation')
-            . ' (' . Piwik::translate('UserCountry_City') . ')';
-
-        WidgetsList::add('General_Visitors', $widgetContinentLabel, 'UserCountry', 'getContinent');
-        WidgetsList::add('General_Visitors', $widgetCountryLabel, 'UserCountry', 'getCountry');
-        WidgetsList::add('General_Visitors', $widgetRegionLabel, 'UserCountry', 'getRegion');
-        WidgetsList::add('General_Visitors', $widgetCityLabel, 'UserCountry', 'getCity');
-    }
-
-    public function addMenu()
-    {
-        MenuMain::getInstance()->add('General_Visitors', 'UserCountry_SubmenuLocations', array('module' => 'UserCountry', 'action' => 'index'));
-    }
-
-    /**
-     * Event handler. Adds menu items to the MenuAdmin menu.
-     */
-    public function addAdminMenu()
-    {
-        if($this->isGeoLocationAdminEnabled()) {
-            MenuAdmin::getInstance()->add('General_Settings', 'UserCountry_Geolocation',
-                array('module' => 'UserCountry', 'action' => 'adminIndex'),
-                Piwik::isUserIsSuperUser(),
-                $order = 8);
-        }
-    }
-
     public function getSegmentsMetadata(&$segments)
     {
         $segments[] = array(
