@@ -1,33 +1,26 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package VisitFrequency
  */
 namespace Piwik\Plugins\VisitFrequency;
 
-use Piwik\Menu\MenuMain;
 use Piwik\Piwik;
-use Piwik\WidgetsList;
 
 /**
  *
- * @package VisitFrequency
  */
 class VisitFrequency extends \Piwik\Plugin
 {
     /**
-     * @see Piwik_Plugin::getListHooksRegistered
+     * @see Piwik\Plugin::getListHooksRegistered
      */
     public function getListHooksRegistered()
     {
         $hooks = array(
-            'WidgetsList.addWidgets'  => 'addWidgets',
-            'Menu.Reporting.addItems' => 'addMenu',
             'API.getReportMetadata'   => 'getReportMetadata',
         );
         return $hooks;
@@ -57,15 +50,4 @@ class VisitFrequency extends \Piwik\Plugin
             'order'            => 40
         );
     }
-
-    function addWidgets()
-    {
-        WidgetsList::add('General_Visitors', 'VisitFrequency_WidgetOverview', 'VisitFrequency', 'getSparklines');
-        WidgetsList::add('General_Visitors', 'VisitFrequency_WidgetGraphReturning', 'VisitFrequency', 'getEvolutionGraph', array('columns' => array('nb_visits_returning')));
-    }
-
-    function addMenu()
-    {
-        MenuMain::getInstance()->add('General_Visitors', 'VisitFrequency_SubmenuFrequency', array('module' => 'VisitFrequency', 'action' => 'index'));
-    }
 }
