@@ -1,19 +1,17 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package VisitsSummary
  */
 namespace Piwik\Plugins\VisitsSummary;
 
 use Piwik\API\Request;
 use Piwik\Common;
-use Piwik\DataTable\Row;
 use Piwik\DataTable;
+use Piwik\DataTable\Row;
 use Piwik\Piwik;
 use Piwik\Plugins\Actions\API as APIActions;
 use Piwik\Site;
@@ -21,7 +19,6 @@ use Piwik\View;
 
 /**
  *
- * @package VisitsSummary
  */
 class Controller extends \Piwik\Plugin\Controller
 {
@@ -29,7 +26,7 @@ class Controller extends \Piwik\Plugin\Controller
     {
         $view = new View('@VisitsSummary/index');
         $this->setPeriodVariablesView($view);
-        $view->graphEvolutionVisitsSummary = $this->getEvolutionGraph(true, array('nb_visits'));
+        $view->graphEvolutionVisitsSummary = $this->getEvolutionGraph(array(), array('nb_visits'));
         $this->setSparklinesAndNumbers($view);
         return $view->render();
     }
@@ -42,11 +39,13 @@ class Controller extends \Piwik\Plugin\Controller
         return $view->render();
     }
 
-    public function getEvolutionGraph($fetch = false, array $columns = array())
+    public function getEvolutionGraph(array $columns = array(), array $defaultColumns = array())
     {
         if (empty($columns)) {
-            $columns = Common::getRequestVar('columns');
-            $columns = Piwik::getArrayFromApiParameter($columns);
+            $columns = Common::getRequestVar('columns', false);
+            if (false !== $columns) {
+                $columns = Piwik::getArrayFromApiParameter($columns);
+            }
         }
 
         $documentation = Piwik::translate('VisitsSummary_VisitsSummaryDocumentation') . '<br />'
@@ -94,6 +93,10 @@ class Controller extends \Piwik\Plugin\Controller
         $view = $this->getLastUnitGraphAcrossPlugins($this->pluginName, __FUNCTION__, $columns,
             $selectableColumns, $documentation);
 
+        if (empty($view->config->columns_to_display) && !empty($defaultColumns)) {
+            $view->config->columns_to_display = $defaultColumns;
+        }
+
         return $this->renderView($view);
     }
 
@@ -140,43 +143,51 @@ class Controller extends \Piwik\Plugin\Controller
         $dataTableVisit = self::getVisitsSummary();
         $dataRow = $dataTableVisit->getRowsCount() == 0 ? new Row() : $dataTableVisit->getFirstRow();
 
-        $dataTableActions = APIActions::getInstance()->get($idSite, Common::getRequestVar('period'), Common::getRequestVar('date'),
-            \Piwik\API\Request::getRawSegmentFromRequest());
-        $dataActionsRow =
-            $dataTableActions->getRowsCount() == 0 ? new Row() : $dataTableActions->getFirstRow();
 
         $view->nbUniqVisitors = (int)$dataRow->getColumn('nb_uniq_visitors');
         $nbVisits = (int)$dataRow->getColumn('nb_visits');
         $view->nbVisits = $nbVisits;
-        $view->nbPageviews = (int)$dataActionsRow->getColumn('nb_pageviews');
-        $view->nbUniquePageviews = (int)$dataActionsRow->getColumn('nb_uniq_pageviews');
-        $view->nbDownloads = (int)$dataActionsRow->getColumn('nb_downloads');
-        $view->nbUniqueDownloads = (int)$dataActionsRow->getColumn('nb_uniq_downloads');
-        $view->nbOutlinks = (int)$dataActionsRow->getColumn('nb_outlinks');
-        $view->nbUniqueOutlinks = (int)$dataActionsRow->getColumn('nb_uniq_outlinks');
+
         $view->averageVisitDuration = $dataRow->getColumn('avg_time_on_site');
         $nbBouncedVisits = $dataRow->getColumn('bounce_count');
         $view->bounceRate = Piwik::getPercentageSafe($nbBouncedVisits, $nbVisits);
         $view->maxActions = (int)$dataRow->getColumn('max_actions');
         $view->nbActionsPerVisit = $dataRow->getColumn('nb_actions_per_visit');
-        $view->averageGenerationTime = $dataActionsRow->getColumn('avg_time_generation');
 
-        if ($displaySiteSearch) {
-            $view->nbSearches = (int)$dataActionsRow->getColumn('nb_searches');
-            $view->nbKeywords = (int)$dataActionsRow->getColumn('nb_keywords');
+        if(Common::isActionsPluginEnabled()) {
+            $view->showActionsPluginReports = true;
+            $dataTableActions = APIActions::getInstance()->get($idSite, Common::getRequestVar('period'), Common::getRequestVar('date'),
+                \Piwik\API\Request::getRawSegmentFromRequest());
+            $dataActionsRow =
+                $dataTableActions->getRowsCount() == 0 ? new Row() : $dataTableActions->getFirstRow();
+
+            $view->nbPageviews = (int)$dataActionsRow->getColumn('nb_pageviews');
+            $view->nbUniquePageviews = (int)$dataActionsRow->getColumn('nb_uniq_pageviews');
+            $view->nbDownloads = (int)$dataActionsRow->getColumn('nb_downloads');
+            $view->nbUniqueDownloads = (int)$dataActionsRow->getColumn('nb_uniq_downloads');
+            $view->nbOutlinks = (int)$dataActionsRow->getColumn('nb_outlinks');
+            $view->nbUniqueOutlinks = (int)$dataActionsRow->getColumn('nb_uniq_outlinks');
+            $view->averageGenerationTime = $dataActionsRow->getColumn('avg_time_generation');
+
+
+            if ($displaySiteSearch) {
+                $view->nbSearches = (int)$dataActionsRow->getColumn('nb_searches');
+                $view->nbKeywords = (int)$dataActionsRow->getColumn('nb_keywords');
+            }
+
+            // backward compatibility:
+            // show actions if the finer metrics are not archived
+            $view->showOnlyActions = false;
+            if ($dataActionsRow->getColumn('nb_pageviews')
+                + $dataActionsRow->getColumn('nb_downloads')
+                + $dataActionsRow->getColumn('nb_outlinks') == 0
+                && $dataRow->getColumn('nb_actions') > 0
+            ) {
+                $view->showOnlyActions = true;
+                $view->nbActions = $dataRow->getColumn('nb_actions');
+                $view->urlSparklineNbActions = $this->getUrlSparkline('getEvolutionGraph', array('columns' => array('nb_actions')));
+            }
         }
 
-        // backward compatibility:
-        // show actions if the finer metrics are not archived
-        $view->showOnlyActions = false;
-        if ($dataActionsRow->getColumn('nb_pageviews')
-            + $dataActionsRow->getColumn('nb_downloads')
-            + $dataActionsRow->getColumn('nb_outlinks') == 0
-            && $dataRow->getColumn('nb_actions') > 0
-        ) {
-            $view->showOnlyActions = true;
-            $view->nbActions = $dataRow->getColumn('nb_actions');
-            $view->urlSparklineNbActions = $this->getUrlSparkline('getEvolutionGraph', array('columns' => array('nb_actions')));
-        }
     }
 }
