@@ -1,18 +1,14 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik_Plugins
- * @package VisitsSummary
  */
 namespace Piwik\Plugins\VisitsSummary;
 
-use Piwik\Menu\MenuMain;
 use Piwik\Piwik;
-use Piwik\WidgetsList;
 
 /**
  * Note: This plugin does not hook on Daily and Period Archiving like other Plugins because it reports the
@@ -20,19 +16,17 @@ use Piwik\WidgetsList;
  * Day class directly.
  * These metrics can be used by other Plugins so they need to be processed up front.
  *
- * @package VisitsSummary
  */
 class VisitsSummary extends \Piwik\Plugin
 {
     /**
-     * @see Piwik_Plugin::getListHooksRegistered
+     * @see Piwik\Plugin::getListHooksRegistered
      */
     public function getListHooksRegistered()
     {
         return array(
             'API.getReportMetadata'   => 'getReportMetadata',
-            'WidgetsList.addWidgets'  => 'addWidgets',
-            'Menu.Reporting.addItems' => 'addMenu',
+            'AssetManager.getStylesheetFiles' => 'getStylesheetFiles',
         );
     }
 
@@ -60,18 +54,11 @@ class VisitsSummary extends \Piwik\Plugin
         );
     }
 
-    function addWidgets()
+    public function getStylesheetFiles(&$stylesheets)
     {
-        WidgetsList::add('VisitsSummary_VisitsSummary', 'VisitsSummary_WidgetLastVisits', 'VisitsSummary', 'getEvolutionGraph', array('columns' => array('nb_visits')));
-        WidgetsList::add('VisitsSummary_VisitsSummary', 'VisitsSummary_WidgetVisits', 'VisitsSummary', 'getSparklines');
-        WidgetsList::add('VisitsSummary_VisitsSummary', 'VisitsSummary_WidgetOverviewGraph', 'VisitsSummary', 'index');
+        $stylesheets[] = "plugins/VisitsSummary/stylesheets/datatable.less";
     }
 
-    function addMenu()
-    {
-        MenuMain::getInstance()->add('General_Visitors', '', array('module' => 'VisitsSummary', 'action' => 'index'), true, 10);
-        MenuMain::getInstance()->add('General_Visitors', 'General_Overview', array('module' => 'VisitsSummary', 'action' => 'index'), true, 1);
-    }
 }
 
 
